#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/global/file.c,v 2.2 1995/08/02 03:31:39 empire Exp $";
#endif /* not lint */

/*
 * fileglb.c
 *
 * empire selection global structures.
 *
 */

#include <struct.h>
#include "misc.h"
#include "var.h"
#include "xy.h"
#include "loan.h"
#include "nsc.h"
#include "nuke.h"
#include "plane.h"
#include "ship.h"
#include "land.h"
#include "sect.h"
#include "trade.h"
#include "treaty.h"
#include "file.h"
#include "power.h"
#include "news.h"
#include "nat.h"

#include "gamesdef.h"

struct empfile empfile[] = {
	"sect", EMPPATH(data/sector), EFF_COM|EFF_XY|EFF_OWNER,
	     0, sizeof(struct sctstr),
	    0, 0, 0, fldoff(sctstr, sct_nv), fldoff(sctstr, sct_vtype[0]),
	    fldoff(sctstr, sct_vamt[0]), MAXSCTV, 
	    -1, -1, 0, 0, 0, 0, 0,
	"ship", EMPPATH(data/ship), EFF_COM|EFF_XY|EFF_OWNER|EFF_GROUP,
	    0, sizeof(struct shpstr),
	    0, 0, 0, fldoff(shpstr, shp_nv), fldoff(shpstr, shp_vtype[0]),
	    fldoff(shpstr, shp_vamt[0]), MAXSHPV, 
	    -1, -1, 0, 0, 0, 0, 0,
	"plane", EMPPATH(data/plane), EFF_XY|EFF_OWNER|EFF_GROUP,
	     0, sizeof(struct plnstr),
	    0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
	"land", EMPPATH(data/land), EFF_COM|EFF_XY|EFF_OWNER|EFF_GROUP,
	    0, sizeof(struct lndstr),
	    0, 0, 0, fldoff(lndstr, lnd_nv), fldoff(lndstr, lnd_vtype[0]),
	    fldoff(lndstr, lnd_vamt[0]), MAXLNDV, 
	    -1, -1, 0, 0, 0, 0, 0,
	"nuke", EMPPATH(data/nuke), EFF_XY|EFF_OWNER, 0, sizeof(struct nukstr),
	    0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
	"news", EMPPATH(data/news),              0,
	     0, sizeof(struct nwsstr),
	     0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
	"treaty", EMPPATH(data/treaty), 0, 0, sizeof(struct trtstr),
	    0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
	"trade", EMPPATH(data/trade),           0, 0, sizeof(struct trdstr),
	    0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
	"pow", EMPPATH(data/power),     0, 0, sizeof(struct powstr),
	    0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
	"nat", EMPPATH(data/nation),           0, 0, sizeof(struct natstr),
	    0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
	"loan", EMPPATH(data/loan),              0,
	     0, sizeof(struct lonstr),
	     0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
	"map", EMPPATH(data/map),		0, 0, WORLD_X*WORLD_Y/2,
	    0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
	"bmap", EMPPATH(data/bmap),		0, 0, WORLD_X*WORLD_Y/2,
	    0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0,
};
