.TH Introduction "Expert Advice"
.NA Expert "Advice to expert Empire players"
.LV Expert
.ce 3
\*(iFDefense Against Nuclear Attacks
Through the Denial of Information\*(pF
by Tom Tedrick
.s1
A very good defense against nukes is to make
it as difficult as possible for other players to find out
where your country is, and thus to make maps of it.
.s1
Here are some simple steps that you can follow:
.in +\w'MM)\0\0'u
.s1
.L 1)
Shoot down all planes that fly over your airspace.
It helps to have numerous airfields,
say one airfield for every 25 sectors or so.
Every airfield should be within interception distance
of several other airfields,
so that it is more difficult for an enemy to destroy or capture it.
If an airfield is detected and nuked,
you still have backup airfields.
Every important sector should be within interception distance
of several airfields.
.s1
.L 2)
Seal off all entrances to your inland seas by building
bridges and laying mines
(so no enemy ships can penetrate the area for mapping purposes).
.s1
.L 3)
Sink all surface vessels and submarines near your coastline.
Have large fleets of destroyers posted around exposed coastal areas
covering all sea sectors where enemy subs
might try to sneak in for mapping purposes.
Usually two fleets of 30 destroyers each are enough.
Navigate the whole fleet one sector, stop and look for subs,
navigate one more sector, stop and look for subs, and so on,
until the fleet has made a circle and is back in its starting position.
Sink any subs you find, of course.
.s1
There is a maximum number of around 30 ships that can be in a
fleet if you want to maneuver the whole fleet by fleet name
(see \*Qinfo fleetadd\*U).
.s1
.L 4)
Establish alliances under the condition that secrecy is maintained
with respect to map information.
Thus other allied countries can serve as
a buffer zone against enemy countries.
Many players are willing to be good allies.
.s1
.L 5)
Destroy or capture nearby radar stations.
.s1
.L 6)
Destroy or capture enemy air bases
within range of your country.
Until enemy technology gets high enough
to launch against any target world-wide,
they will often try to get someone to let them have an airbase
hidden near your country and launch nuclear strikes from there.
I've always been able to find these if I worked at it.
.s1
.L 7)
Use psychological warfare.
Nukers get tired of nuking you if it seems to have no effect.
For example, have numerous false capitals, so that when,
after great efforts, they manage to find
what they think is your capital, and nuke it, only to
discover that it was a fake, they will get discouraged.
These fake capitals are also very useful as backups in case your
real capital is discovered and destroyed.
.s1
When an enemy gets close to doing real harm,
a counterattack can often divert attention away from the current attack.
Psychologically, attackers seem to underestimate the harm
they are doing to you if you don't give out any information about how
you are being affected,
and they seem to overestimate the danger to themselves
from your counterattack.
.in
.s1
.ce 3
\*(iFShip Networks and the Art of
Transferring Supplies\*(pF
by Tom Tedrick
.s1
Build large quantities of ships.
When they're 100% efficient,
load them with military and food (and civilians) if possible.
Load guns and shells if you have them,
but since they tend to be scarce, only a few ships will have them.
Navigate them one by one as far as they will go.
Leave only one ship in each sector
(this makes it difficult for an enemy to sink very many of them,
due to mobility restrictions
and the problem of locating and identifying them one by one).
On your maps, mark the ship number in the appropriate sector.
Each sea sector thus has at most one ship number.
.s1
Unless there is something in particular you want to do with
a particular ship, leave it sitting in its sector indefinitely.
.s1
As you build more and more ships,
move them out one by one.
If you leave ship \*(iFX\*(pF
in a sector that already contains ship \*(iFY\*(pF,
ship \*(iFY\*(pF should have full mobility by then.
Navigate ship \*(iFY\*(pF as far as it will go,
then leave it sitting until a new ship comes along.
.s1
Every ship in the network is now likely to be within range of
some other ships in the network.
If a ship requires any supplies,
you can load them on a ship in a harbor,
navigate it out, transfer the cargo via tend,
navigate the tended ship,
transfer its cargo, and so on,
until you reach the any ship in the network.
If you need military for assaulting or boarding,
guns and shells for firing, torpedoing or laying mines,
or if you simply want to move stuff into a distant harbor,
you can do it using several tend and navigate operations.
.s1
This has been particularly useful for sinking subs.
I don't have enough guns and shells
to keep all of my 100 or more destroyers fully armed,
but when one of the unarmed destroyers spots a sub,
I can arrange to transfer guns and shells to it from a loaded
ship (or from a harbor).
.s1
It's a very simple system from the player's standpoint,
because all the player has to do is build the ship,
navigate it, mark its number on the map,
and forget about it until a use for it arises.
As more ships are built,
the network automatically expands without requiring any planning.
You don't have to keep anything in memory,
except the ship number on your map.
If any enemy surface ship gets trapped in the network,
it's quite likely you can capture it,
even if all you have is cargo ships
(battleships, landing craft, and carriers could take some work though).
If an enemy sub is spotted by your destroyers,
you can almost always sink it.
If a convenient target for an assault appears,
you can get the necessary military there.
.s1
.ce 3
\*(iFSome Tricks to Use When Fighting\*(pF
by Various People
(Mostly by Tom)
.s1
The trick for boarding destroyers:
you need a bunch of cargo ships,
both to make several boarding attempts and to tend military.
When you try to board a ship, both the attacker and defender
lose the same amount of mobility.
First you have to get the destroyer's mobility to be negative.
Then you just keep trying to board it from one ship after
another until you win.
That's where my ship network method comes in handy.
I usually have swarms of ships I can surround enemy ships with.
.s1
If I have planes, my normal method is to take a sector I can see,
put enough military to hold it,
designate it \*Qe\*U if it has lots of food,
or maybe something else if there is a reason.
Then get information about the adjacent sectors
and take the most promising one.
Without planes it's more of a struggle.
Anyway, I kind of zig-zag into the country taking the most
interesting sectors, ignoring the others.
This really seems to freak people out,
when an enemy takes a path right through the heartland.
.s1
I would use planes (so having numerous airports
each with a fair supply of fighters, spread around
your country, would be the best countermeasure),
ships (having forts loaded with guns and shells
covering all coastlines helps a lot;
also having destroyers and subs spread around your coastal
waters in order to spot and counterattack enemy
ships, also have bombers to bomb enemy ships, and
radar stations to spot them is useful).
.s1
I would invade by land, firing from forts,
(mainly you need to counterattack actively when the enemy takes any
sectors in your area, also forts with guns and shells help a lot).
I would capture islands and build bridges to get into your country
(so watch all offshore islands with bridge span range).
.s1
Have a lot of shells in warehouses ready to be moved to
the front (you can move four for no mobility cost).
.s1
Bombing enemy ships spotted by radar seems to work pretty
well for the most part.
If he has an aircraft carrier you can torpedo it.
.s1
You never know exactly what may happen,
sometimes you get lucky when you think it's hopeless.
Even if a plan has only a small chance of working,
sometimes it's worth a try,
especially if the enemy has to actively do something to stop it.
.in 0
.s1
You should always have at least two capitals sectors, in case you
lose one.
.s1
Just a tip on empire tactics: mobility is the key
to dealing with many empire problems. Its often the
bottleneck which interferes with various things, and
the decisive advantage that gives victory to the attacker.
.s1
.s1
.SA "Overview, Novice, Hints, Introduction"
