.TH Command ANNOUNCE
.NA announce "Send an announcement to all players"
.LV Basic
.SY "announce"
The announce command is a variant of the telegram command.
It sends your message to \fIall\fR of the players in the game.
This convenient service may cost money to provide, depending on
your deity.
.s1
A banner line saying \*QANNOUNCEMENT\*U is prepended to your message
so that announcements won't be confused with telegrams.  In
all other respects, announcements are exactly the same as telegrams.
.s1
For example:
.EX announce
.NF
Enter telegram for everyone; end with ^D
1024 left: 
1023 left:               For Immediate Release
 987 left:                     from
 962 left:                 Groonland Embassy
 928 left: 
 927 left: 
 926 left: HELP!  Curmudgeon just TRASHED our capital!  We had even proposed
 860 left: a very fair treaty, but they did it anyway!  People of the World,
 794 left: UNITE!  Overthrow the slavemasters of Curmudgeon!
 744 left: <EOT>
JoeBlowLand is rejecting your announcements
ZappaLand is rejecting your announcements
.FI
.s1
Note that announcements can be rejected. See info reject for more information.
.s1
.SA "pray, wire, telegram, read, reject, Communication"
