.TH Command BUY
.NA buy "Purchase commodities from the world market"
.LV Expert
.SY "buy <ITEM> <CNUM> <AMOUNT>"
The buy command allows nations to purchase commodities
on the open market.
Not all commodities can be traded -- notably civilians and military.
Prices depend on the \*Qprice multiplier\*U
set by the selling nation with respect to the buying nation.
.s1
Typical output looks like:
.EX buy food
.NF
Trade report : food
 cnum       country   amount  item price
(# 0)           MGM     926    your own lot
(#15)        hodedo      10    5.20
(#17)      Anorexia    2150    2.25
Country number to buy from : 17
Number of food to buy (max 10) : 100
destination sector : -2,0
That just cost you $225.00
.FI
.s1
Note that the first amount was identified as \*Qyour own lot\*U
since you can't buy from yourself.
In addition, the \*Qdestination sector\*U must be a warehouse,
and must be greater than 60% efficient to receive commodities.
.s1
.SA "sell, mult, market, Obsolete"
