static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/global/dir.c,v 2.0 1995/07/27 05:34:36 empire Exp $";

/*
 * dir.c
 *
 * directional orientation descriptions.
 * Must agree with defines in path.h
 *
 */

#include "misc.h"
#include "var.h"
#include "xy.h"

/* must agree with DIR_ defines */
s_char    dirch[] = {
	'h',		/* stop */
	'u',		/* up-right */
	'j',		/* right */
	'n',		/* down-right */
	'b',		/* down-left */
	'g',		/* left */
	'y',		/* up-left */
	'v',		/* view */
	'm',		/* map */
	'\0',
};

/* must agree with dirch[] and DIR_ defines */
int	diroff[][2] = {
	0,0, 1,-1, 2,0, 1,1, -1,1, -2,0, -1,-1, 0,0, 0,0,
};

/* must agree with dirch[] and DIR_ defines */
s_char   *routech[7][2] = {
	"   ",	"$ $",
	"  /",	"$ /",
	"  >",	"$ >",
	"  \\",	"$ \\",
	"/  ",	"/ $",
	"<  ",	"< $",
	"\\  ",	"\\ $"
};
