static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/global/product.c,v 2.0 1995/07/27 05:34:36 empire Exp $";

/*
 * product.c
 *
 * order must agree with P_ defines in product.h
 * 
 */

#include "misc.h"
#include "product.h"
#include "sect.h"
#include "nat.h"
#include "var.h"


struct pchrstr pchr[]  = {
/*       level      cost    nrndx nrdep nlndx   nlmin nllag effic  sname name */
{ 0, { 0 }, { 0 },
0,       0,         0,      0,    0,    0,        0,    0,  0,    
	"unused", "", },
{ 2, { V_LCM, V_HCM}, { 2, 1 },
V_SHELL, -1,        3,      0,    0,    NAT_TLEV, 20,  10, 100, 
	"shells",  "shells", },
{ 3, { V_OIL, V_LCM, V_HCM }, { 1, 5, 10 },
V_GUN,   -1,        30,     0,    0,    NAT_TLEV, 20,  10, 100, 
	"guns",  "guns",},
{ 1, { V_OIL }, { 1 },
V_PETROL,-1,        1,      0,    0,    NAT_TLEV, 20,  10, 1000,
	"petrol",  "petrol",},
{ 0, { 0 }, { 0 },
V_IRON,  -1,        0,OFFSET(sctstr, sct_min),0,    -1,       0,    0,  100,
	"iron ore",  "iron",	},
{ 0, { 0 }, { 0 },
V_DUST,  -1,        0,OFFSET(sctstr, sct_gmin),20,  -1,       0,    0,  100,
	"gold dust",  "dust",},
{ 1, { V_DUST }, { 5 },
V_BAR,   -1,        10,     0,    0,    -1,       0,    0,  100, 
	"gold bars", "bars",},
{ 0, { 0 }, { 0 },
V_FOOD,  -1,        0,OFFSET(sctstr, sct_fertil),0, NAT_TLEV, -10,  10, 900,
	"food", "food",},
{ 0, { 0 }, { 0 },
V_OIL,   -1,        0,OFFSET(sctstr, sct_oil),10,   NAT_TLEV, -10,  10, 100, 
	"oil", "oil",},
{ 1, { V_IRON }, { 1 },
V_LCM,   -1,        0,      0,    0,    NAT_TLEV, -10,  10, 100,
	"light construction materials", "lcm",},
{ 1, { V_IRON }, { 2 },
V_HCM,   -1,        0,      0,    0,    NAT_TLEV, -10,  10, 100,
	"heavy construction materials",  "hcm", },
{3,{V_DUST,V_OIL,V_LCM}, {1,5,10},
0,       NAT_TLEV, 5*ETUS,  0,    0,    NAT_ELEV, 5,    10, 100,
      "technological breakthroughs", "tech",},
{3,{V_DUST,V_OIL,V_LCM }, { 1, 5, 10 },
0,       NAT_RLEV, 90,     0,    0,    NAT_ELEV, 5,    10, 100,
      "medical discoveries", "medical",},
{ 1, { V_LCM }, { 1 },
0,       NAT_ELEV,  9,     0,    0,    -1,       0,    0,  100,
	"a class of graduates",  "edu",},
{ 1, { V_LCM }, { 1 },
0,       NAT_HLEV,  9,     0,    0,    -1,       0,    0,  100,
	"happy strollers",  "happy",},
{ 0, { 0 }, { 0 },
V_RAD, -1,          2,OFFSET(sctstr, sct_uran),35, NAT_TLEV, 40,  10, 100, 
	"radioactive materials",  "rad",},
{ 0, { 0 }, { 0 },
V_DUST,  -1,        0,OFFSET(sctstr, sct_gmin),20,  -1,       0,    0,  75,
	"gold dust",  "dust",},
{ 0, {0}, {0},
0, 0, 0, 0, 0, 0, 0, 0, 0, "", "",}
};

int	prd_maxno   = (sizeof(pchr) / sizeof(struct pchrstr)) - 1;
