/*
 * keyword.h
 *
 * Defines for parsed keyword package
 *
 * $Revision: 2.0 $ $Date: 1995/07/27 05:29:42 $
 */

#ifndef _KEYWORD_H_
#define _KEYWORD_H_

#define CF_VALUE	1
#define CF_TIME		2
#define CF_TIMERANGE	3
#define CF_WEEKDAY	4

extern	s_char *kw_find();
extern	s_char *kw_parse();

#endif /* _KEYWORD_H_ */
