/*
 * io_mask.h
 *
 * describes i/o mask
 *
 */

#ifndef _IO_MASK_H_
#define _IO_MASK_H_

struct io_mask {
	int what;
	int maxfd;
	bit_fdmask readmask;
	bit_fdmask user_readmask;
	bit_fdmask writemask;
	bit_fdmask user_writemask;
};

struct io_mask *iom_create();

#endif /* _IO_MASK_H_ */
