.TH Command UNSAIL
.NA unsail "Stop a ship from sailing"
.LV Expert
.SY "unsail <SHIP/FLEET>"
You use the \*Qunsail\*U command to remove a sailing path from ships.
.s1
.SA "follow, sail, mquota, Ships"
