.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject PLAYING
.in \w'ConceptsXX\0\0\0\0'u
.s1
.L "bye * "
Log out of Empire
.L "country   "
Find out information about deity countries
.L "execute   "
Execute a batch file
.L "info * "
Provide information on various topics
.L "list   "
List commands which are currently legal
.L "players   "
List players currently connected to the game
.L "pray * "
Interacting with the Deity
.L "quit * "
Log out of Empire
.L "version   "
Display parameters of this world
.L "zdone   "
Indicate willingness to have an update
.s1
.L "BTU   "
How BTUs are generated
.L "Selector * "
Selectors you can use in Empire conditionals
.L "Syntax * "
The Empire command syntax
.L "Time   "
Definitions of BTU and ETL
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
