.TH Command COUNTRY
.NA country "Find out information about deity countries"
.LV Expert
.SY "country"

The country command is temporarily out of order.
Please use the 'players' command instead.

The country command displays a list of the countries you specify,
their numb, their last access time, their btu's, and their status.
.s1
If you are \*QNOT\*U a deity, the country command will report on only
deity countries. (So that you can see if a deity is logged on)
Deity countries get the full report.  Note that "Now logged on" is
often incorrect, and deities are recommended to use the new command
"players" to list players currently logged on.
.s1
.EX country *
.NF
Thu Jan 21 07:14:12 1993
  #   last access       time    status           country name
  0   Now logged on     [512]   DEITY            The_Scum
  1  Wed Jan 20 23:07   [512]   Active           Khazad'ur
  2  Thu Jan 21 07:00   [511]   Active           Spectre
.FI
.SA "players, Communication, Playing"
