.TH Command BREAK
.NA break "Break sanctuary and begin to play"
.LV Basic
.SY "break"
In Empire your sectors are initially sanctuaries.
While in sanctuary your people don't eat, work or reproduce.
They also can't be attacked.
.s1
Break removes the sanctuary protection from your country and forces
your people to work for a living.
You can't do any country development commands until you break out
of sanctuary.
.s1
.SA "Sector-types, Nation"
