.TH Command SETSECTOR
.NA setsector "Change stats of a sector"
.LV Expert
.SY "setsector <TYPE> <SECTS> <NUM>"
You can change anything that appears in dump or hidden (I think).
.SA "give, setresource, edit, Deity"
