/*
 * path.h
 *
 * directions, paths, etc.
 *
 * $Revision: 2.1 $ $Date: 1995/09/27 23:16:23 $
 */

#ifndef _PATH_H_
#define _PATH_H_

	/* direction indices */
#define	DIR_STOP	0
#define	DIR_UR		1
#define	DIR_R		2
#define	DIR_DR		3
#define	DIR_DL		4
#define	DIR_L		5
#define	DIR_UL		6
#define	DIR_VIEW	7
#define	DIR_MAP		8
#define	DIR_FIRST	1
#define	DIR_LAST	6

#define	SELL_NOT_DELIV	7                   /* in "_use" field => contract */

extern	int	diroff[][2];
extern	s_char	dirch[];

extern	s_char	*getpath();
extern	s_char	*masktopath();
extern	long	pathtomask();
extern	double	pathtoxy();

extern	double	sector_mcost();
extern	double	ncost();
extern	double	fcost();

#define	P_NONE		0	/* NO destinations allowed */
#define	P_WALKING	1	/* use BestLandPath, only owned */
#define	P_FLYING	2	/* use bestpath, any */
#define	P_SAILING	3	/* use bestpath, any */
#define	P_DISTING	4	/* use BestDistPath, only owned */

#define MAX_PATH_LEN 1024

#endif /* _PATH_H_ */
