.TH Server "How to be a good God"
.NA God "Tips on being God"
.LV Expert
.s1
The following commands act differently or require different
parameters when used as deity:
wire, read, des, zdone, nav, march, transport, move, build, country.
.s1
Comments from Dave Pare
.s1
I've been deity of seven or eight games,
and each time I learn something new about how far I should go,
and how active a role I should take.
.s1
There are several things a deity should take into account.
.in +\w'00)\0\0'u
.s1
.L 1)
Bug policy.
When a player says that a bug bit him, how do you handle it?
Since I used to hack on the game at the same time players would play,
I used to have a \*Qnasty\*U bug policy.
That is, if a bug bites a player, he loses.
It is very difficult to verify if a player
\*Qreally did lose those 1000 gold bars\*U from that bank
because of a bug.
Also, whenever a player had something bad happen to him,
he'd yell \*QBUG\*U.
All too often, the player just did something stupid.
.s1
If a player ever found a \*Qgood\*U bug
(and reported it in a timely fashion),
I'd give him some kind of reward.
The reward was generally material enough
to encourage them to report bugs,
but not too much so the other players complained.
If through use of this bug the player manufactured
\*Qtoo many\*U goodies for himself,
I acted to redress the balance immediately.
.s1
This whole case is only interesting
when the Deity knows the Empire code,
and can identify bugs as such.
.s1
.L 2)
Unskilled players.
It's tough watching your friends lose in an Empire game.
Helping \*Qjust a little\*U by giving information,
or by giving a teensy bit of assistance is BAD.
Empire is NOT a game of socialist care for the needy;
it's more like survival of the fittest.
Players should sink or swim on their own.
If you help a novice, you're deliberately hurting his opponent.
Some players will lose,
and as Deity you'll have to stand by and watch this happen.
.s1
.L 3)
Answering random prayers.
If you DO help someone, help them in relatively minor ways.
Do things like fill in some ocean, etc.
Don't give away commodities -- except perhaps food.
Whatever you do, don't give tech, military hardware,
civilians, military, or any information at all!
The game is very stingy with information, and you should be too.
.s1
.L 4)
Security.
Make SURE that nobody else has access to the data directories.
There are always players who will do anything to win.
If you help them control themselves
by making the data completely unavailable --
watch those dump tapes too --
you'll be doing their moral fiber and everyone else a favor.
.in
.s1
Remember, as Deity your job is to make the game fair.
Don't hose players
(unless they cheat -- and you catch them!)
and don't give out information.
Information is very important in Empire,
and as Deity you've got access to all of it.
Be careful in what you say,
and how you leave your terminal at night!
.s1
Unless you've got nothing else to do,
a Deity should keep player communications to a minimum.
Handling special player requests gets tedious after a while;
make players pay for Deity assistance.
One game I suggested that the only way players could get the Deity
to fill in ocean sectors, zap plague, etc,
was to offer a real-life sacrifice to the deity --
a few bottles of good beer, for example!
I got perhaps a dozen bottles,
and managed to greatly curtail player requests at the same time!
.s1
In summary, an Empire game should be between players.
Any time the Deity helps anyone,
Deity intervention starts becoming a factor in the game.
As a Deity, you absolutely can't go wrong
if you do nothing at all except routine game maintenance.
.SA "Deity"
