.TH Command TREATY
.NA treaty "Listing of all current and pending treaties"
.LV Expert
.SY "treaty <TREATIES>"
The treaty command will report on all outstanding treaties and all
pending treaties. The conditions and durations are displayed.
.s1
A typical treaty report might be:
.s1
.NF
  *** Empire Treaty #7 ***
(proposed)
between Curmudgeon and Urp  expires Mon May  4 00:42:04 1981
   Curmudgeon terms   Urp terms
no attacks on ships   no attacks on ships
                      no shelling ships
no sector attacks     no sector attacks
                      no shelling land
no enlistments
no new land units     no new land units

  *** Empire Treaty #2 ***
between Curmudgeon and East Eden  expires Mon May  4 00:42:59 1981
   Curmudgeon terms   East Eden terms
no attacks on ships   no attacks on ships
no shelling ships     no shelling ships
no sector attacks     no sector attacks
no shelling land      no shelling land
no new land units     no new land units
.FI
.s1
.SA "consider, offer, Obsolete"
