.TH Command PARADROP
.NA paradrop "Attack a sector from the air"
.LV Expert
.SY "paradrop <TRANSPORTS> <ESCORTS> <SECT> route|destination"
The \*Qparadrop\*U command is used to sneak troops behind enemy lines,
or to drop in unawares on lightly-defended enemy islands or outposts.
It represents a complete mission for one or more transports and escorts
taking off from one place and returning to base at the end of the mission.
.s1
<TRANSPORTS> represents a list of planes which can carry commodities.
Only planes which have a transport capacity, belong in a sector which is
stocked with gas and military, and have sufficient mobility will
be successfully selected for the mission. Only planes with the para ability
may be used for paratroop missions.
.s1
<ESCORTS> represent a list of fighter planes which are capable of escorting
the transports all the way to the target.
To be selected, escorts must have fuel and mobility.
.s1
<SECT> represents an assembly point, where all of the planes in the
mission meet before proceeding on to the target sector.
The assembly point must be owned by you, and must not be more than
four sectors away from any of the planes selected for the mission.
.s1
Route is a normal empire path specification. You may also give a 
destination sector on the command line, or at any time while giving
the route, and empire will use the best path from the current sector
to the desired destination sector.
.s1
If the planes manage to fight through enemy air defenses and arrive
on-target, each transport in the mission will be shot at by any
guns present on the ground.
Surviving transports will drop the paratroops they carry, which will
attack any enemy military occupying the target sector.
.s1
See info \*QAttack\*U for the exact procedure. The sector being air-assaulted
will have exactly the same reaction to being conquered as if it were attacked
by land.
.s1
Note that a plane must be at least 40% efficient before it can leave
the ground.
.s1
.SA "bomb, fly, drop, recon, Attack, Mobility, Combat, Planes"
