/* for systems without strdup() define NOSTRDUP */
#ifdef NOSTRDUP

char *strdup(x) 
     char *x;
{
        char *y;

        y=(char *)malloc((sizeof(char)*strlen(x))+1);
        strcpy(y,x);
        return y;
}

#endif /* NOSTRDUP  */

