.TH Command SPY
.NA spy "Snoop on adjacent enemy sectors"
.LV Basic
.SY "spy <SECTS>"
The spy command allows reconnaissance operations to enforce
an oral treaty or as preparation for an attack
(or even for a prayer to the Deity).
.s1
The spy report will reveal, (in round figures), the numbers of troops,
civilians, guns, shells, iron, and planes and the sector designation and
efficiency in neighboring sectors.
.s1
The sectors denoted by <SECTS>
are those from which you are spying,
(see \*Qinfo syntax\*U for format). 
Note: you can only spy from sectors that have military or land units in them.
.s1
Note that the number of BTU's consumed
is dependent upon the number of sectors into which you spy,
e.g., a 5x8 area costs one full BTU.
.s1
If you are spying on an unallied country your spy could be apprehended...
his/her chances are dependent upon the number
of patrolling military in the sector.
.s1
However, having a recon unit in the sector the spy is coming from
enhances your chances of succeeding even if the spy is caught.
.s1
If the other country has declared itself at war with you the spy
will be shot and the other country, (and the rest of the world,
through the news), will be warned that you tried to spy on him...
.s1
If the other country is neutral towards you the spy will be deported.
.s1
.EX "spy 29,3"
SPY report
SPY report
Wed Jul 26 21:10:13 1995
   sect   type own oldown eff  civ  mil  shl gun  pet food bars units planes
  28,4      bf   4      6  90  980  300   40  10    0   60   70     0      0
  29,5      c+   4      4  90  980    0    0   0   20   60    0     2      0
Spies report neutral unit in 29,5:  cavalry #6 (efficiency 98, tech 18)
Spies report neutral unit in 29,5:  if1  infantry 1 #7 (efficiency 98, tech 15)
.s1
.L NOTE
.s1
Spies reporting on the tech level of enemy units are pretty inaccurate.
They can vary by +/- 20 tech or so...
.s1
.SA "census, read, declare, Sectors, Combat, Detection"
