.TH Command ADD
.NA add "Add/Remove a country in the game"
.LV Expert
.SY "add <NAT> <NAME> <REP> <visitor|new|active|god|delete> <check|wipe|ignore>"
.EX add 1 bunky mypass n i
This adds a new player to the game.
.EX add 2 visitor visitor v i
This adds a visitor country to the game.
.EX add 1 bunky mypass d w
This removes bunky and all his sectors & units from the game.
.EX add 1 bunky mypass d c
Just to make sure that bunky doesn't still have any stuff in the game.
.EX add 36 martian outerspace a i
This will add a new country which will be able to send/receive
telegrams but won't have any land.  For example, you could give a
newbie helper a country like this.
.SA "newcap, Deity"
