.TH Command TRADE
.NA trade "Generate a report on ships for sale and perhaps buy some"
.LV Expert
.SY "trade"
The trade report lists
all ships and planes that are being sold and allows you to buy them.
.s1
Typical output looks like:
.EX trade
.NF

     Empire Trade Report
  Fri Feb 17 03:01:01 1989
 lot# cnum   country   price              desc
  0 (# 9)      Gluk    50000.00   tech 532 100% icbm 4 #295(2x500kt fusion)
  1 (# 9)      Gluk     5000.00   tech 212 100% destroyer [s:40 g:4 ] 126
  2 (# 1)  Dog Meat    14000.00   tech 183 100% jet hvy bomber #9 (your own lot)
Which lot to buy : 1
Bought ship 126 for 5000.00
That just cost you $5000.00
.FI
.s1
The cargo of ships is listed in the square brackets, in this case, 4
guns and 40 shells.   The nuclear armament of planes is listed
in parentheses; in this case two 500kt fusion bombs.
.s1
Note that the jet hvy bomber was identified as \*Qyour own lot\*U
which means you cannot buy it!
.s1
.SA "set, Obsolete"
