/*
 * map.h
 *
 * Stuff for map making (map, radmap, satmap, sect, 
 *
 * $Revision: 2.1 $ $Date: 1995/07/09 20:46:52 $
 */

#ifndef _MAP_H_
#define _MAP_H_

#define	MAPWIDTH(persec) ((WORLD_X/2)*(persec + 1)+1)

extern	s_char	*routech[7][2];

extern	int blankfill();
extern	int border();

#define MAP_SHIP	bit(0)
#define MAP_LAND	bit(1)
#define MAP_PLANE	bit(2)
#define MAP_ALL		MAP_SHIP | MAP_LAND | MAP_PLANE

struct	bmpstr {	/* for C_SYNC transmission */
	short	ef_type;
	natid	bmp_own;
	coord	bmp_leftx;
	coord	bmp_rightx;
	coord	bmp_y;
	s_char	bmp_row[WORLD_X/2 + 1];
};

struct	mapstr {
	short	ef_type;
	coord	map_x;
	coord	map_y;
	s_char	map_des;
};

#endif /* _MAP_H_ */
