/*
 * tm.h
 *
 * empire transaction manager
 *
 * Dave Pare, 1986
 * $Revision: 2.1 $ $Date: 1995/10/11 03:11:17 $
 */

/*
 * commands to the server
 */
#define	C_LOCK		1
#define C_UNLOCK	2
#define C_IDENT		3
#define C_NATMOD	4
#define C_NEWS		5
#define C_SYNC		6
#ifdef	DEMANDUPDATE
#define C_WANTUPDATE	7
#endif	/* DEMANDUPDATE */
#define C_CLOSE		8

/*
 * response from the transaction manager
 */
#define TM_MOD		1
#define	TM_OK		2
#define	TM_ERROR	3
#define TM_PANIC	4
#define TM_ABORT	5

/*
 * two types of updates
 */
#define	MOBILITY	1
#define PRODUCE		2

/* For those with unreliable itimers (NeXT)
 * value is in seconds.
 */

#define UPDATE_CHECK    60
