.TH Concept "Unit Types"
.NA Unit-types "Description of the different types of land units"
.LV Basic
Some of the units currently available in Empire are:
.s1
.nf
infantry	The Bloody Infantry. Lotsa guys on foot with guns. They're
		slow, and they carry their supplies in horse-drawn wagons,
		which slows them down even more. Slow. They're also not
		terribly good at scouting. They don't attack very well,
		with a multiplier ranging from 1 to 1.5 or so with better
		tech. However, they really shine on defense, with a multiplier
		from 1.5 to 3.0. If you want to hold a line... use infantry.
		They're fairly resistant to shelling and bombing, with the
		later types of infantry units being better.

cavalry		Empire starts just at the end of the age of cavalry. They're
		quick, and they scout pretty well. They're better at attacking
		than defending. They are pretty easy to kill with shelling or
		bombing. Still, if you want a low-tech unit to go somewhere
		quick, they're the guys.

supply		Supply units range from horse and wagon to truck units. Early
		supply units are slow, but the later supply unit types are
		motorized and are faster. Supply units carry a bunch of stuff,
		but try your best not to get them in combat, because they don't
		enjoy it, and they're REALLY bad at it. Supply units can give
		supplies to land units, as well as forts/ships/sectors. See
		info supply.

lt armor	Armor units may be light, medium, or heavy. Light armor units
armor		have much the same uses as cavalry, although they are a good
hvy armor	bit less fragile. Medium armor is medium-fast, good for general
		attacking, while heavy armor is slow, but good for assaults,
		any situation where you need to destroy a heavily-defended
		fixed point.

		All armor is better at attacking than defending. Higher tech
		types of armor units are better at defending, however. Armor
		gets much of its combat advantage from its mobility, being
		able to attack and move in, severing supply lines & blocking
		reaction & reinforcements.

		Armor is fairly resistant to shelling/bombing.

artillery	Artillery is a long range killer. You can use it to shell
lt artillery	sectors, but it can often be more effective when used as
hvy artillery	support for your attacks. Lt artillery has more mobility,
mech artillery	but less damage. Hvy artillery has less mobility, but more
		damage. Mechanized artillery gives you good damage and good
		mobility, but is very expensive.

		The better the accuracy of the artillery, the better it is
		at assisting your troops or shelling ships. The better the
		damage rating, the better the damage done. High-damage, low
		accuracy artillery is mostly good for shelling sectors, while
		high-accuracy artillery is good at supporting your troops,
		or shooting at ships.

		All artillery is bad at attacking, but can usually defend in
		a not-horrible fashion. Artillery units are, however, pretty
		vulnerable to shelling and bombing. (except for mech artillery)
		
engineers	Engineers are the most versatile unit. They can lay mines,
mech engineers	clear mines, defend well, attack well, work on sectors, etc.
		The drawbacks? Well, they're VERY expensive and not very
		big. Mech engineers have vehicles and are much faster and
		more resistant to damage.

mech infantry	These two types of infantry are faster. Mech infantry is
motor infantry	also more resistant to damage and even better on defense.

marines		These units are like improved infantry, but more expensive and
		harder to make. Their best use is for assaulting beaches, but
		they do make superior infantry if you have to use them that
		way.

security	These units are good at fighting guerrillas, but not for
		much else. They fight about as well as low-tech infantry,
		and their smallish size makes them not worth much.

		They do help you when shooting helpless civs (see info shoot),
		and fight guerrillas during the update. The security troops
		get a chance to 'raid' the guerrillas and kill some of them
		before the guerrillas fight. This will reduce your casualties
		from guerrilla war.

radar units	These units are high-tech. They give you the ability to
		map the enemy easily as you advance. Try not to get them
		into combat, as they're horrible at it, and they're very costly.
		They're generally motorized, so they're pretty fast, and they
		all get shelled/bombed hard.

aa unit		These units are good defensively, and fight planes well. They
		are a mechanized unit, and move & survive pretty well. Only
		units with the FLAK ability can fire AA.

NOTE: The following statistics are out of date.  Use the "show"
      command to see the correct values.

First Generation: Pre-WWI 	(tech 0-19)
                                                s r f                          
                                                p a r                          
Name             $/tech mil att def vul spd vis y d g acc dam amm aaf fc/fu xpl
infantry 1     500/0     50 1.0 1.5  60  23  15 2 1 0   0   0   0   0  0/0   0
supply 1       500/0     25 0.1 0.2 100  15  20 1 0 0   0   0   0   0  0/0   0
cavalry 1      500/0     25 2.0 0.8  80  32  18 4 3 0   0   0   0   0  0/0   0

2nd Generation: WWI		(tech 20-149)
                                                s r f                          
                                                p a r                          
Name             $/tech mil att def vul spd vis y d g acc dam amm aaf fc/fu xpl
infantry 2     500/20    50 1.0 2.0  60  23  15 2 1 0   0   0   1   1  0/0   0
artillery 1    800/20    50 0.1 0.4  70  15  20 1 0 4  50   8   4   1  0/0   0
supply 2       500/20    25 0.1 0.2  90  15  20 1 0 0   0   0   0   0  0/0   0
hvy artillery1 800/100   50 0.0 0.2  60  10  20 1 0 7  99  12   6   1  0/0   0
lt artillery 1 500/100   25 0.2 0.6  60  21  18 1 1 3  10   4   2   1  0/0   0
hvy armor 1    500/120   50 2.0 0.8  50  15  17 1 1 0   0   0   2   1 10/2   0
engineer 1    1000/130   10 1.2 2.4  50  23  14 2 1 0   0   0   1   1  0/0   0

3rd Generation: WWII		(tech 150-249)
                                                s r f                          
                                                p a r                          
Name             $/tech mil att def vul spd vis y d g acc dam amm aaf fc/fu xpl
infantry 3     500/150   50 1.2 2.2  60  23  15 2 1 0   0   0   1   2  0/0   0
hvy armor 2    500/150   50 2.5 1.0  40  23  17 1 1 0   0   0   1   2 10/1   0
artillery 2    800/150   50 0.1 0.4  60  15  20 1 0 5  35   8   4   2  0/0   0
hvy artillery2 800/150   50 0.0 0.2  50  11  20 1 0 7  95  12   6   2  0/0   0
lt armor 1     500/150   25 2.0 1.0  50  42  15 4 4 0   0   0   1   2 25/1   0
engineer 2    1000/165   10 1.5 2.6  50  23  14 2 1 0   0   0   1   4  0/0   0
armor 1        800/170   25 3.0 1.5  40  32  16 2 2 0   0   0   1   2 13/1   0
security       400/170   25 1.0 2.0  60  23  15 2 1 0   0   0   1   1  0/0   0
motor inf 1    600/190   50 1.2 2.2  60  32  17 1 3 0   0   0   2   3 13/1   0
mech inf 1     800/190   50 1.5 2.5  50  32  17 1 3 0   0   0   2   3 13/1   0
marines       1000/190   50 1.4 2.4  60  23  14 2 1 0   0   0   1   2  0/0   0
lt armor 2     600/190   25 2.5 1.5  45  48  14 5 5 0   0   0   2   3 25/1   0
aa unit        800/200   10 0.5 3.0  50  32  17 1 1 0   0   0   2  10 13/1   0
mech arty 1   1000/200   25 0.2 0.6  50  32  17 1 1 5  35   8   6   3 13/1   0
armor 2        900/210   25 4.0 2.0  30  35  15 2 3 0   0   0   2   3 25/2   0
supply 3       500/210   25 0.1 0.2  80  32  20 1 0 0   0   0   0   0 13/1   0

4th Generation: Korea		(tech 250-269)
                                                s r f                          
                                                p a r                          
Name             $/tech mil att def vul spd vis y d g acc dam amm aaf fc/fu xpl
mech inf 2      800/250  50 1.5 2.9  48  32  16 2 3 0   0   0   3   4 25/2   0
lt armor 3      600/250  25 3.0 1.8  40  50  13 5 5 0   0   0   3   4 50/2   0
mech eng 1     1500/260  10 1.8 3.5  45  32  15 3 3 0   0   0   1   5 25/2   0
armor 3         900/265  25 5.0 2.2  25  38  15 3 3 0   0   0   3   4 50/4   0

5th Generation: Vietnam		(tech 270-309)
                                                s r f                          
                                                p a r                          
Name             $/tech mil att def vul spd vis y d g acc dam amm aaf fc/fu xpl
mech inf 3     800/270   50 1.6 3.2  45  38  15 3 4 0   0   0   4   6 36/3   2
radar unit 1  1000/270   10 0.0 0.0  50  32  15 3 0 0   0   0   0   2 25/2   2
mech arty 2   1000/270   50 0.1 0.4  40  40  15 1 2 6  30   8   8   6 36/3   2
aa unit 2     1200/290   10 0.5 2.0  45  32  15 3 1 0   0   0   3  14 36/3   4
armor 4       1000/305   25 6.0 3.0  20  40  15 3 4 0   0   0   4   6 60/5   2

6th Generation: Modern		(tech 310+)
                                                s r f                          
                                                p a r                          
Name             $/tech mil att def vul spd vis y d g acc dam amm aaf fc/fu xpl
mech inf 4    1000/310   50 1.8 3.5  35  40  14 3 5 0   0   0   5   8 50/4   4
mech arty 3   1200/310   50 0.1 0.4  40  40  14 1 2 7  20   8   8   8 50/4   4
radar unit 2  1200/320   10 0.0 0.0  50  32  14 5 0 0   0   0   0   4 25/2   2
armor 5       1200/350   25 8.0 3.5  15  45  14 3 5 0   0   0   5   8 60/4   4
mech inf 5    1200/350   50 2.0 4.0  30  45  14 3 5 0   0   0   5   8 50/4   4
aa unit 3     1500/350   10 0.5 1.5  45  32  14 3 1 0   0   0   2  18 36/3   8
.fi
.s1
These units types differ in their fundamental
capabilities; some can fire guns, some cannot;
each has it's own specific abilities & roles.
The capabilities of each unit are given by the show command.
The headings are as follows. For the building data:
.s1
.EX show land build
.s1
.in \w'shells\0\0'u
.L lcm
The lcm required to build the land unit.
.L hcm
The hcm required to build the land unit.
.L mil
The mil required to build the land unit.
.L guns
The guns required to build the land unit.
.L shells
The shells required to build the land unit.
.L avail
The avail (work) required to build the land unit.
.L tech
The minimum technology required to build the land unit.
.L $
The cost of the land unit.
.in \\n(in
.s1
The headings for the stats listing are
.s1
.EX show land stats
.s1
.in \w'fir\0\0'u
.L att
the attack multiplier of the land unit
.L def
the defensive multiplier of the land unit
.L vul
the vulnerability of the unit to bombing/shelling (1-100)
.L spd
the distance/mu for moving (in relative units)
.L vis
how visible the land unit is, (relative units)
.L spy
how far the land unit can see, (i.e. how good the
reconnaissance equipment is), again in relative units
.L rad
the unit's reaction radius
.L frg
the distance the unit can fire
.L acc
the firing accuracy of the unit (for support)
.L dam
the damage the unit does when firing
.L amm
ammo: the number of shells the unit uses when fighting or firing
.L aaf
the aa fire rating of the unit
.L fc/fu
The land unit's fuel capacity & usage.
(see info fuel) (If the FUEL option is enabled)
.L xpl
The number of extra-light planes the land unit can carry.
(If the XLIGHT option is enabled)
.in
.s1
Each land unit can carry a certain amount of products and has certain
capabilities. These are listed under the cargoes & abilities section.
The cargoes give the number of each product that can be carried.
The abilities are as follows.
.s1
.EX show land capabilities
.s1
.in \w'engineer\0\0'u
.L xlight
the unit can carry xlight planes. (If the XLIGHT option is used)
.L engineer
the unit can lay/sweep mines, work on sectors/fortifications/etc.
.L supply
the unit can supply other units
.L security
the unit is good at fighting guerrillas and shooting helpless civilians
.L light
the unit can be carried on ships (note that any unit, even
units that are not 'light', can be 
carried by a non-submarine supply ship that is otherwise
able to carry units)
.L marine
the unit is good at assaulting
.L recon
the unit is good at gathering intelligence. It will do better at llook,
and will report enemy units in batter better.
.L radar
the unit has radar capability
.L assault
the unit may be used in assaults
.L
.in
.s1
Some examples of the output:
.s1
.EX show land build
.NF
                          lcm hcm mil guns shells avail tech  $
War band                    5   0 100    0      0     1    0  $500
Supply Wagon                5   5  50    0      0     2    0  $500
GPG Commandos              15  15  25    1      2     5  150  $800
artillery 1                40  60  70   20     40    17  100  $1000
Jump infantry              35  25 100    5     10     9  400  $3000
marines 1                  20  10 100    2      4     5  200  $2000
.FI
.s1
.EX show land stats
.NF
                                       s  v  s  r  f  a  d  a  a        x
                                       p  i  p  a  r  c  a  m  a  f  f  p
                          att def vul  d  s  y  d  g  c  m  m  f  c  u  l
War band                  1.3 1.0  99 23  5  1  1  0  0  0  0  0  0  0  0
Supply Wagon              0.1 0.2 100 15  6  1  0  0  0  0  0  0  0  0  0
GPG Commandos             1.0 1.0  70 30  1  2  1  0  0  0  5  1 10  1  0
artillery 1               0.0 0.5  50 15  6  1  0  6 40  4  5 15  0  0  0
Jump infantry             5.0 6.0  20 55  1  4  4  0  0  0  5 35 10  1  5
marines 1                 1.0 2.0  70 23  3  3  2  0  0  0  5  5  0  0  2
.FI
.s1
.EX show land cap
.NF
                          capabilities
War band                   5f engineer light recon
Supply Wagon               50s 5g 100f 200l 100h 100r 200d 10b 100i supply light
GPG Commandos              5f security
artillery 1                5f 10g 20s
Jump infantry              5f 2g 10s xlight
marines 1                  5f 10s xlight light marine
.FI
.s1
Note that unlike planes, land ratings do not change with tech. For example,
in the example above, a War band would always have a 1.3 attack multiplier, 
regardless of the tech it is built at. The only things that improve over
the listed value are firing range for artillery, which behaves similarly
to forts & ships (See info fire for more info), and movement speed, which
behaves similarly as ships. (See info march for more information on movement
costs)
.s1
.SA "land, LandUnits"
