/*
 * com.h
 *
 * things having to do with empire command parsing
 *
 * from PSL Empire, 1985
 * $Revision: 2.1 $ $Date: 1995/05/30 18:46:14 $
 */

#ifndef _COM_H_
#define _COM_H_

struct	comstr {
	s_char	*c_form;	/* prototype of command */
	int	c_cost;		/* btu cost of command */
	int	(*c_addr)();	/* core addr of appropriate routine */
	int	c_flags;
	int	c_permit;	/* who is allowed to "do" this command */
};

#define C_MOD		0x1	/* modifies database */

/* variables associated with this stuff */

extern	struct comstr coms[];

#endif /* _COM_H_ */
