.TH Concept Populace
.NA Citizens "Work, starvation, and general management of your citizens"
.LV Basic
.s1
Taxation of the civilian populace is one of the main providers of income
to an Empire nation (gold bars in banks, trade ships, and taxes from
uws being the only other sources of income in the game).
Also, only friendly civilians can be enlisted into the army, navy and
air force.
.s1
The loyalty of a given sector,
also known as the willingness of the civilian population to work,
is initially 100% -- that is, all of the people are working.
In the event that the sector is captured, starves,
or falls victim to revolutionary subversion,
the work of the sector will decrease.
This will be shown by the work % decreasing.
.s1
If people starve in a sector, the amount of work they do drops to 0
(because they are too weak to work).
.s1
If a sector is a conquered sector,
a star \*Q*\*U will be shown in the appropriate column
on the census report.
Friendly sectors allow enlistment of military,
as well as the ability to move the civilians freely about.
Occupied civilians will not move,
and friendly civilians cannot enter these sectors.
In addition, occupied civilians will not serve in the armed forces.
.s1
If the thought of not being able
to move conquered populace bothers you,
then you have the option of converting these conquered people
into uncompensated workers,
involving the expenditure of BTU's and money
(for the paperwork).
If all the conquered people in one sector are converted to uw's,
then the sector is then marked as yours.
.s1
If the people in a sector are unhappy
(due to starvation, subversion, or lack of happiness)
they can go on strike and cease working.
You can get them back to work by heavy-handed military control
(placing one military for each 20 striking civilians).
.s1
Finally, your populace requires happiness to keep their enthusiasm
for work going.  As technology and education increase,
your work force expects to share in the increased levels
by getting more consumer items (VCR's, BMW's, etc)
represented by happy strollers.
If you don't have at least one happiness point
per two units of education,
and a point for each forty units of tech,
your people will not be happy.
.s1
.SA "attack, Happiness, Populace, Occupation"
