/*
 * XXX cheap hack; this depends on the fact
 * that units are all the same starting from the top.
 * If you change the units, DON'T CHANGE the tops to
 * be non-identical. Also, if you change types of
 * parts of the tops, be sure to change this file!
 */

#ifndef _GENITEM_H_
#define _GENITEM_H_

struct genitem {
	short	ef_type;
        natid	own;
        short	uid;
        coord	x;
	coord	y;
        s_char	type;
        s_char	effic;
        s_char	mobil;
        short	sell;
        short	tech;
        s_char	group;
	coord	opx,opy;
	short	mission;
	short	radius;
};

struct genobject {
	short	ef_type;
        natid	own;
};

struct genchrstr {
	u_char	nv;	/* current number of variables */
	u_char	vtype[MAXCHRNV];
	u_short	vamt[MAXCHRNV];
};

#endif /* _GENITEM_H_ */
