.TH Command DISARM
.NA disarm "Remove a nuclear warhead from a plane or missile"
.LV Expert
.SY "disarm <PLANE>"
The \*Qdisarm\*U command removes nuclear warheads from
delivery systems such as planes or missiles.
.s1
.s1
.SA "arm, transport, Planes"
