.TH Concept Taxes
.NA Taxes "How taxes are calculated"
.LV Expert
.s1
Civilians exist in Empire to work and provide cash to the government.
Simply by existing,
they generate revenue to their host country
in proportion to the efficiency of the sector
in which they work.
.s1
The military-industrial complex exists
in order to siphon off hard-earned tax dollars.
Military cost (in general) about ten times as much
as a civilian pays in taxes.
.s1
In addition, \*Qfinal goods and services\*U cost money to produce.
Ships, land units, planes, guns and shells are all examples of the costs
inflicted upon a helpless government by the military-industrial complex.
Also, \*Qservices\*U such as technology research, medical research,
and even happiness (money and lcm's can buy happiness here...)
cost something to create.
Consumer items such as food, lcm, hcm, and all other \*Qintermediate
goods\*U (or raw materials) cost nothing other than the hard work of
the oppressed citizenry.
.s1
Note that it takes ten civilians to keep one soldier in the field.
Note also that the only way to make money is either to be pacifistic
and let your nation accumulate wealth by having a small standing army,
or by selling products to other nations. Also, land units can multiply
the strength of each mil, making them perhaps more economical, if you
already have made the technological investment.
.SA "Update, Nation"
