#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/common/mailbox.c,v 2.0 1995/07/09 21:32:08 empire Exp $";
#endif

/*
 * mailbox.c
 *
 * return string containing mail box name
 *
 * from PSL Empire, 1985
 */

#include "misc.h"
#include "tel.h"
#include <stdio.h>

s_char *
mailbox(buf, cn)
	s_char	*buf;
	natid	cn;
{
	(void) sprintf(buf, "%s%d", telfil, cn);
	return buf;
}

s_char *
syncbox(buf, cn)
	s_char	*buf;
	natid	cn;
{
	(void) sprintf(buf, "%s%d", syncfil, cn);
	return buf;
}

