.TH Concept "Bridges"
.NA Bridges "Building and destroying bridges"
.LV Expert
.s1
BRIDGES
.s1
Normally bridges can only be built from bridge-heads. (See info
\*QSector-types\*U). If the EASY_BRIDGES option is in use,
bridges can be built from any sector
that has enough hcm (heavy construction materials) and
workforce (see \*Qinfo show\*U and the \*Qshow\*U command),
providing you have enough money, and your technology level is high enough.
.s1
Bridges can only be built over water sectors.
.s1
If the EASY_BRIDGES option is in use,
you do not need to use bridgehead sectors (although the sector you
build from must still be at least 60% efficient), and
the sector the bridge span is to be built in must be adjacent to
at least 1 non-sea, non-bridge span sector. Note that you do not have to
OWN the sector is will be adjacent to, it just has to exist. This means that
you can build, for example, a 2 sector bridge out to an unowned island.
.s1
To find out the required amounts of materials, workforce, and money
use the show command.
.s1
Bridge spans cannot be re-designated.
A bridge span will collapse when it is below 20% in efficiency,
so shelling will destroy one, as will nuclear weapons and bombing.
.s1
If the EASY_BRIDGES option is NOT in use, a bridge will also collapse
if its bridge-head sector goes below 20% or is re-designated.
.s1
.SA "build, Technology, show, Sectors"
