static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/global/path.c,v 2.1 1995/07/09 21:43:00 empire Exp $";

/*
 * path.c
 *
 * Path initializations needed outside of
 * the file initialization tables.
 *
 */

#include "gamesdef.h"
#include "misc.h"

s_char	*gamedir	= EMPPATH(.);
s_char	*infodir	= EMPPATH(info.nr);
s_char	*datadir	= EMPPATH(data);
s_char	*teldir		= EMPPATH(data/tel);
s_char	*syncdir	= EMPPATH(data/sync);

s_char	*upfil		= EMPPATH(data/up);
s_char	*downfil	= EMPPATH(data/down);
s_char	*disablefil	= EMPPATH(data/disable);
s_char	*telfil		= EMPPATH(data/tel/tel);
s_char	*annfil		= EMPPATH(data/ann);
s_char	*syncfil	= EMPPATH(data/sync/sync);
s_char	*commfil	= EMPPATH(data/comm);
s_char	*hoursfil	= EMPPATH(data/hours);
s_char	*banfil		= EMPPATH(data/ban);
s_char	*authfil	= EMPPATH(data/auth);

s_char	*playerbin	= EMPPATH(bin/emp_player);
s_char	*updatebin	= EMPPATH(bin/emp_update);
s_char	*loginport	= EMP_PORT;
