.TH Command MOTD
.NA motd "Print the message of the day"
.LV Expert
.SY "motd"
This command will print out the login message (what gets printed to
your screen when you login to the game).  It is
here so that you don't have to logout and in again if you want to read
the login message again.
.SA "Communication"
