#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/gen/scthash.c,v 2.0 1995/07/27 05:56:17 empire Exp $";
#endif

/*
 * scthash.c
 *
 * create a hash function based on the
 * sector x-y mod table size.
 *
 * Dave Pare, 1986
 */

int
scthash(x, y, tsize)
	register int x;
	register int y;
	int	tsize;
{
	if (x < 0)
		x = -x;
	if (y < 0)
		y = -y;
	return ((x*10 + y) % tsize);
}
