
/* module: workspace */


/* module: /lib/libc.sa.1.8 */


/* module: /home/chainsaw4/ts/E/update/age.c */

int age_levels(int);

/* module: /home/chainsaw4/ts/E/update/control.c */

int military_control(struct sctstr *);

/* module: /home/chainsaw4/ts/E/update/deliver.c */

int deliver(struct sctstr *, struct ichrstr *, int, int, int, int);

/* module: /home/chainsaw4/ts/E/update/distribute.c */

int dodistribute(struct sctstr *, int *, int, char *, double, double);
int assemble_dist_paths(char *(*)[64], double (*)[64], double (*)[64]);
int free_dist_paths(char *(*)[64]);
char *ReversePath(char *);

/* module: /home/chainsaw4/ts/E/update/finish.c */

int finish_sects(void);

/* module: /home/chainsaw4/ts/E/update/human.c */

int feed_people(int *, int);
int grow_people(int *, int, double);
int infect_people(struct natstr *, int *, unsigned int, int);
int plague_people(struct natstr *, int *, int *, int);

/* module: /home/chainsaw4/ts/E/update/land.c */

int prod_land(int, int, int);
int upd_land(struct lndstr *, int, int, struct natstr *, int);
int landrepair(struct lndstr *, int *, struct natstr *, int);
int feed_land(struct lndstr *, int *, int);
int plague_land(struct lndstr *, struct natstr *, int *, int *, int);
int total_mil(struct lndstr *);

/* module: /home/chainsaw4/ts/E/update/landgun.c */

double landgun(int, int);
double seagun(int, int);
double landunitgun(int, int);
int landdef(int);
int seadef(int);
int landunitdef(int);
int shelldam(double, int);
int roundrange(double);

/* module: /home/chainsaw4/ts/E/update/main.c */

int main(int, char **);
int tm_exit(int);
int do_prod(int, int, int, int *, int *, int *, int *, int *, int *);

/* module: /home/chainsaw4/ts/E/update/mobility.c */

int mob_sect(int);
int mob_ship(int);
int mob_land(int);
int mob_plane(int);

/* module: /home/chainsaw4/ts/E/update/move_sat.c */


/* module: /home/chainsaw4/ts/E/update/nat.c */

double logx(double, double);
double limit_level(double, int, int);
int prod_nat(int);
int share_incr(double *, double *);

/* module: /home/chainsaw4/ts/E/update/nav_ship.c */

int nav_ship(struct shpstr *);

/* module: /home/chainsaw4/ts/E/update/nav_util.c */

char *nav_nameship(struct shpstr *, struct mchrstr *);
int check_nav(struct sctstr *);
int nav_chkdir(char, int, int);
int nav_shiprad(struct shpstr *, int, int);

/* module: /home/chainsaw4/ts/E/update/nxtitemp.c */

char *nxtitemp(struct nstr_item *);

/* module: /home/chainsaw4/ts/E/update/nxtsctp.c */

struct sctstr *nxtsctp(struct nstr_sect *);

/* module: /home/chainsaw4/ts/E/update/plane.c */

int prod_plane(int, int, int);

/* module: /home/chainsaw4/ts/E/update/populace.c */

double populace(struct natstr *, struct sctstr *, int *, int);
int starvation(struct sctstr *);
double total_work(struct sctstr *, int *);

/* module: /home/chainsaw4/ts/E/update/prepare.c */

int prepare_sects(int);
int prep_update(struct sctstr *, int, struct natstr *, int *);

/* module: /home/chainsaw4/ts/E/update/produce.c */

int produce(struct natstr *, struct sctstr *, int *, int);
int materials_cost(struct pchrstr *, int *, int *);
int materials_charge(struct pchrstr *, int *, int);

/* module: /home/chainsaw4/ts/E/update/removewants.c */

int update_removewants(void);

/* module: /home/chainsaw4/ts/E/update/revolt.c */

int revolt(struct sctstr *);
int guerrilla(struct sctstr *);
int take_casualties(struct sctstr *, int);

/* module: /home/chainsaw4/ts/E/update/sail.c */

int sail_ship(void);

/* module: /home/chainsaw4/ts/E/update/sect.c */

int prod_sect(int);
int update(struct sctstr *, int, struct natstr *, int *);
int dodeliver(struct sctstr *, int *);
int buildeff(struct sctstr *, int, int *);
int growfood(struct sctstr *, int *, int, int);
int enlist(int *, int);
int produce_sect(int, int, int);

/* module: /home/chainsaw4/ts/E/update/ship.c */

int prod_ship(int, int, int);
int upd_ship(struct shpstr *, int, int, struct natstr *, int);
int shiprepair(struct shpstr *, int *, struct natstr *, int);
int feed_ship(struct shpstr *, int *, int);

/* module: /home/chainsaw4/ts/E/update/supply.c */

int resupply_all(struct lndstr *);
int resupply_commod(struct lndstr *, int);
int supply_commod(int, int, int, int, int);
int try_supply_commod(int, int, int, int, int);
int s_commod(int, int, int, int, int, int);
char *itemname(int);
int at_minimum(struct lndstr *, int);
int get_minimum(struct lndstr *, int);
double supply_mob(int, int, double, double);

/* module: /home/chainsaw4/ts/E/update/wu.c */

int wu(unsigned char, unsigned char, char *);
int flushwu(void);
