.TH Introduction Hints
.NA Hints "Hints to help you play Empire better"
.LV Expert
.s1
Military and the Demobilization of Same
.in +0.3i
.s1
It's generally a good idea to put
demobilized military on active reserve.
You should also consider whether you need an enlistment center
to generate more military.
You can't enlist more military than you have military reserves.
The \*Qnation\*U command will tell you how many military you have.
Be careful, as many players have lost their countries
through carelessness with their military
at the start of the game.
.s1
Actually, the enlist command cannot activate more military than
you have on reserve.
Even then they have to be in sectors
with an efficiency of 60% or greater.
Enlistment sectors can produce as many military as they are capable of,
but will never produce more than one-half
of the civilian populace there.
So you need to keep moving them out, or demobilizing them, etc.
Also, the more military you have in an enlistment center,
the more military get trained per update.
.s1
Any civilian may be enlisted
(no restriction on the efficiency of the sector).
No more may be enlisted than the number of reserves.
Enlistment costs mobility whereas
while demobilization costs cash.
Military can only be demobilized in sectors
with a 60% efficiency or greater.
No more than one-half the number of civilians in a sector
may be enlisted in one \*Qenlist\*U command,
but if it is issued many times,
virtually all civilians in a sector may be enlisted.
.s1
One thousand reserves is enough for now,
although I figure I always put them on reserve when I demobilize,
at least up to 10,000.
.s1
So you don't need to push for more reserves now,
but might as well put all demobilized military on reserve.
.s1
You make back the cost of demobilizing military in just
two or three days I think,
so I generally demobilize the military I don't have any use for,
and put them on reserve.
.s1
Depends on how you want to use them, I guess.
I figure with 200 jet transports at 127 mobility,
I can land 20,000 military in an enemy country in one night,
so I'd say 20,000 is a safe upper limit for reserves.
I've never needed more than that.
.in
.s1
Distribution Hints
.in +0.3i
.s1
When distributing stuff to a warehouse,
set the thresholds in the sector that is sending to or receiving
from the warehouse to the amount that you want left in that sector.
Don't set thresholds for the warehouse itself
(unless its also distributing to another warehouse)
.s1
The minimum threshold for distribution is one.
A threshold of 0 means no distribution of that commodity
will take place.
.in
.s1
Something to Remember about Technology
.in +0.3i
.s1
An education level of five is required to build technology.
After "easy tech", the tech you build is put through a
logorithm with "tech log base" (see version).
.in
.s1
War Zones
.in +0.3i
.s1
It makes it much easier if the player doesn't
have to do anything to keep his country running,
but can instead do the things that are of interest.
There's also the problem of what to do in an invasion.
I guess if invaded I just accept the damage,
and don't try to fix it until the war ends.
.s1
In a war zone I generally follow one of two basic plans.
If I'm the invader, I either leave the sectors as they are
and let the country being invaded fall apart,
or if I can do something to make it worse for the enemy,
I sometimes do that.
I sometimes designate conquered sectors to agribusinesses
if they need food, banks to reduce shelling damage,
enlistment centers for military,
forts for firing and attacking, harbors to get ships in,
warehouses to collect, move, and distribute supplies,
airbases for planes and bridge heads for easy movement.
.s1
When being invaded, I also generally postpone any
long term development and just concentrate on the
basic sectors types for combat (a,b,c,e,f,h,w,#,*)
.s1
I've found it's a mistake to worry about long term
development in a war zone, until the battle is over.
I will let a war zone be completely wrecked in order to achieve victory.
So you need to keep your home area away from any war zones.
.s1
So far the method of treating war zones and
peaceful zones differently and keeping them separated
has worked pretty well.
The mistake I made in the past was to try to develop a war zone
before the fight was over.
Now I'm willing to completely wreck the area to win,
and in fact you pretty much have to.
The guerrillas take several days to get rid of even when
the war is over.
.s1
I mostly turn the sectors in the front lines into forts, enlistment
centers, banks, and bridgeheads.
Then maybe some warehouses, airports, and harbors
within range of the front lines.
And maybe some radar stations.
.in
.s1
Work Percentages are Important!
.in +0.3i
.s1
I've found it good policy to produce a large surplus
of food and aim to have at least 100 food in each sector,
when I have enough. Actually I now put 990 food in each
sector, except for aggies (100) and warehouses (9990).
.s1
Before moving civilians,
check the work in the sector the civilians are in.
If it's less than 100%, DON'T move any of them out.
The reason: work in the destination sector will drop to
the same level as the starting sector.
.s1
It's a good idea to check after every update,
to see if any sectors have work less than 100%.
\*Qcen\ #0\ ?work<100\*U is what I use.
If work is less than 100%, workers won't work at full efficiency,
and if it gets very low,
the civilians may revolt and you'll lose the sector.
Build lots of happiness, and keep extra mil in sectors with
work less than 100%.
That seems to help.
.in
.s1
Definitions and a Good Thing to Remember
.in +0.3i
.s1
\*QWorld tech\*U and \*Qworld research\*U refers
to the technology and research made by other countries
which will automatically leak to the less developed countries.
.s1
If you let education get higher than happiness,
then find work going to 0% in your sectors,
don't say you weren't warned....
.in
.s1
On Nuclear Devices
.in +0.3i
.s1
Just a note on nukes: in this version, there is
a nice balance between nukes and economics.
A player can do a lot of damage with nukes, but it costs a LOT.
So it's rare that a country is completely annihilated
by a nuclear attack,
as used to be the case in PSL Empire.
.in
.SA "Overview, Introduction"
