/*
 * power.h
 *
 * things having to do with the power report.
 *
 * from PSL Empire, 1985
 * $Revision: 2.0 $ $Date: 1995/07/27 05:29:42 $
 */

#ifndef _POWER_H_
#define _POWER_H_

struct powstr {
	natid	p_nation;
	float	p_sects;
	float	p_effic;
	float	p_civil;
	float	p_milit;
	float	p_shell;
	float	p_guns;
	float	p_petrol;
	float	p_iron;
	float	p_dust;
	float	p_food;
	float	p_oil;
	float   p_bars;
	float	p_planes;
	float	p_ships;
	float	p_units;
	float	p_money;
	float	p_power;
};

#define getpower(n, p) \
	ef_read(EF_POWER, n, (caddr_t)p)
#define putpower(n, p) \
	ef_write(EF_POWER, n, (caddr_t)p)
#define getpowerp(n) \
	(struct powstr *) ef_ptr(EF_POWER, n)

#endif /* _POWER_H_ */
