#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/gen/minmax.c,v 2.0 1995/07/27 05:56:17 empire Exp $";
#endif

/*
 * minmax.c
 *
 * from PSL Empire, 1985
 */

double
dmax(n1, n2)
	double	n1;
	double	n2;
{
	if (n1 > n2)
		return n1;
	return n2;
}

double
dmin(n1, n2)
	double	n1;
	double	n2;
{
	if (n1 < n2)
		return n1;
	return n2;
}

int
max(n1, n2)
	int	n1;
	int	n2;
{
	if (n1 > n2)
		return n1;
	return n2;
}


int
min(n1, n2)
	int	n1;
	int	n2;
{
	if (n1 < n2)
		return n1;
	return n2;
}
