static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/global/item.c,v 2.0 1995/07/27 05:34:36 empire Exp $";

/*
 * item.c
 *
 * item characteristics -- one entry per movable item
 *
 * must be in same order as defines in var.h
 *
 */

#include "misc.h"
#include "var.h"
#include "item.h"

struct  ichrstr ichr[I_MAX+2]  = {
/*      mnem vtype     val sell  lbs rg,wh,ur,bnk  name */
	'?', 0,         0,   0,   0, 0, 0, 0, 0, "unused",
	'c', V_CIVIL,   1,   0,   1, 1, 4,10, 1, "civilians",
	'm', V_MILIT,   0,   0,   1, 1, 1, 1, 1, "military",
	's', V_SHELL,   5,   1,   1, 1,10, 1, 1, "shells",
	'g', V_GUN,     60,  1,   10,1,10, 1, 1, "guns",
	'p', V_PETROL,  4,   1,   1, 1,10, 1, 1, "petrol",
	'i', V_IRON,    2,   1,   1, 1,10, 1, 1, "iron ore",
	'd', V_DUST,    20,  1,   5, 1,10, 1, 1, "dust (gold)",
	'b', V_BAR,     280, 1,   50,1, 5, 1, 4, "bars of gold",
	'f', V_FOOD,    0,   1,   1, 1,10, 1, 1, "food",
	'o', V_OIL,     8,   1,   1, 1,10, 1, 1, "oil",
	'l', V_LCM,     2,   1,   1, 1,10, 1, 1, "light products",
	'h', V_HCM,     4,   1,   1, 1,10, 1, 1, "heavy products",
	'u', V_UW,      1,   1,   2, 1, 2, 1, 1, "uncompensated workers", 
	'r', V_RAD,	150, 1,   8, 1,10, 1, 1, "radioactive materials",
  	 0,  0,         0,   0,   0, 0, 0, 0, 0, 0,
};

int	itm_maxno   = (sizeof(ichr) / sizeof(struct ichrstr)) - 1;
