.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject COMMODITIES
.in \w'commodityXX\0\0\0\0'u
.s1
.L "census * "
Report contents of sectors
.L "commodity * "
Report commodities in sectors
.L "drop   "
Use planes to drop commodities in your own sectors
.L "grind   "
Grind bars back into dust
.L "move * "
Transport ore, civilians, guns, etc
.L "test   "
Check the effect of a proposed move
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
