#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/gen/plur.c,v 2.0 1995/07/27 05:56:17 empire Exp $";
#endif

/*
 * plur.c
 *
 * from PSL Empire, 1985
 */

#include "misc.h"

s_char *
plur(n, no, yes)
	int	n;
	s_char	*no;
	s_char	*yes;
{
	return (n == 1 ? no : yes);
}

s_char *
splur(n)
	int	n;
{
	return (n == 1 ? "" : "s");
}

s_char *
esplur(n)
	int	n;
{
	return (n == 1 ? "" : "es");
}

s_char *
iesplur(n)
	int	n;
{
	return (n == 1 ? "y" : "ies");
}
