.TH Concept Happiness
.NA Happiness "How happiness is calculated at the update"
.LV Expert
.s1
Happiness is required for countries which have any sort of technology
or education at all, with greater levels being required as
the expectation (and tech/edu levels) of the populace increases.
A country with an unhappy population can expect a decrease in the
\*Qwork\*U of some sectors.
.s1
Also, the morale of your land units is determined by the happiness
of your people. The morale of a unit can be set by the player, but
the minimum level allowable is determined by happiness:
.ti 3
75 - happiness
.s1
Thus, a nation with a happiness of 20 would have a minimum allowable 
morale level of 55%
.s1
The \*Qnation\*U command will display, among other things, your current
happiness level.
.s1
The procedure determining happiness level is exactly the same for
happiness as it is for education (see "info Education") except for the
fact that "happiness log base" is always 6.0 and "easy happiness" is
always 5.0.  New happiness is averaged with old happiness in the same
way that education is averaged except that happiness averaging has its
own line in the "version" output:
  Happiness is averaged over 48 time units.
.s1
.SA "Education, Innards, nation, Products, Research, Technology, attack, Nation, Production, Update"
