static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/global/plane.c,v 2.6 1995/10/16 17:50:53 empire Exp $";

/*
 * plane.c
 *
 * plane characteristics
 * flags indicate capabilities of craft...
 * P_T: tactical, P_F: fighter/interceptor, P_B: bomber,
 * P_C: cargo, P_G: glider, P_V: vtol, P_M: (one-shot) missile
 * P_L: light, can land on carriers.
 * P_O: orbits (sat's & anti-sats), P_N: nuke killer (SDI)
 * P_X: stealthy
 * P_E: Extra light
 * P_K: Chopper
 * P_P: Can paratroop
 * P_A: ASW plane, can find subs when reconning, can bomb subs
 * P_R: recon plane, gets some info
 * P_I: Image capability (advanced spying)
 * 
 * Note if a plane is P_M (a missile) then it will automatically be made
 * P_V (vtol) in init_global()
 */

#include "misc.h"
#include "plane.h"

struct plchrstr plchr[] = {

"f1  fighter 1",     8,  2,  400,  90, 90, 1,  4,4,    7,  1,  1,
                                                                     0, 
                                                                    P_V|P_T|P_F,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"f2  fighter 2",     9,  3,  600, 150, 60, 1,  7,7,    9,  1,  1,
                                                                     0, 
                                                                    P_T|P_F,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"f3  fighter 3",    10,  3,  800, 200, 45, 1, 10,10,  11,  2,  2,
                                                                     0, 
                                                                    P_T|P_F|P_L,


/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"nf1 naval fighter 1",8, 2,  500, 100, 80, 1,  3,3,    7,  1,  1,
                                                                     0, 
                                                                    P_L|P_T|P_F,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"nf2 naval fighter 2",9, 3,  600, 150, 60, 1,  6,6,    9,  1,  1,
                                                                     0, 
                                                                    P_L|P_T|P_F,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jf1 jet fighter 1",12,  4, 1000, 220, 45, 1, 13,13,   7,  2,  3,
                                                                     0, 
                                                                        P_T|P_F,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jf2 jet fighter 2",14,  4, 1000, 250, 45, 2, 13,13,  11,  2,  3,
                                                                     0, 
                                                                    P_T|P_F|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jf3 jet fighter 3",15,  5, 1100, 280, 45, 2, 18,18,  16,  2,  4,
                                                                     0, 
                                                                    P_T|P_F|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jf4 jet fighter 4",15,  5, 1200, 310, 45, 3, 23,23,  20,  2,  4,
                                                                     0, 
                                                                P_T|P_F|P_V|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"sf  stealth fighter",15,5, 1500, 390, 45, 3, 19,19,  20,  2,  4,
                                                                     80, 
                                                                    P_T|P_F|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"es  escort",        9,  3,  700, 150, 60, 1,  5,5,   15,  1,  2,
                                                                     0, 
                                                                      P_ESC|P_T,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"lb1 lt bomber 1",  10,  3,  550, 100, 50, 2,  0,3,    7,  1,  1,
                                                                     0, 
                                                                    P_V|P_T|P_B,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"lb2 lt bomber 2",  11,  4,  750, 150, 35, 2,  0,4,    9,  2,  2,
                                                                     0, 
                                                                    P_T|P_B|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jl1 jet lt bomber 1",14,4, 1000, 250, 25, 3,  0,9,   11,  2,  3,
                                                                     0, 
                                                                    P_T|P_B|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jl2 jet lt bomber 2",15,5, 1100, 280, 20, 4,  0,11,  13,  2,  3,
                                                                     0, 
                                                                    P_T|P_B|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jl3 jet lt bomber 3",15,5, 1200, 310, 20, 5,  0,13,  17,  2,  3,
                                                                     0, 
                                                                    P_T|P_B|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"mb1 medium bomber 1",14,5, 1000, 150, 45, 4,  0,5,   14,  3,  3,
                                                                     0, 
                                                                    P_T|P_B,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"mb2 medium bomber 2",15,5, 1200, 200, 40, 5,  0,6,   17,  3,  3,
                                                                     0, 
                                                                    P_T|P_B,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jmb jet med bomber",20,10, 1500, 280, 30, 8,  0,11,  25,  5,  5,
                                                                     0, 
                                                                        P_T|P_B,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"hb1 hvy bomber 1", 20,  6, 1100, 110, 90, 5,  0,4,   15,  2,  2,
                                                                     0, 
                                                                    P_B,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"hb2 hvy bomber 2", 22,  8, 1500, 180, 90, 6,  0,7,   17,  4,  4,
                                                                     0, 
                                                                    P_B,
/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"hb3 hvy bomber 3", 24, 10, 1800, 220, 90, 8,  0,7,   21,  5,  5,
                                                                     0, 
                                                                            P_B,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"hb4 hvy bomber 4", 24, 10, 2000, 250, 80,10,  0,11,  25,  5,  5,
                                                                     0, 
                                                                    P_B,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jhb jet hvy bomber",26,13, 2200, 280, 80,12,  0,11,  31,  5,  6,
                                                                     0, 
                                                                            P_B,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"sb  stealth bomber",15, 5, 2000, 390, 15, 8,  0,15,  17,  2,  3,
                                                                     80, 
                                                                        P_T|P_B,


/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"ac1 attack chopper 1",8,2,  800, 280,  5, 1,  0,9,   11,  2,  2,
                                                                     40, 
                                                                        P_V|P_T,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"ac2 attack chopper 2",8,2, 1000, 310,  5, 2,  0,11,  13,  2,  2,
                                                                     50, 
                                                                    P_V|P_T|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"as1 anti-sub plane 1",10,3, 550, 110, 85, 2,  0,3,   15,  2,  2,
                                                                     0, 
                                                                    P_T|P_A,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"as2 anti-sub plane 2",14,5,1000, 150, 75, 2,  0,4,   17,  2,  2,
                                                                     0, 
                                                                        P_T|P_A,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"np1 naval plane 1",15,  5, 1200, 250, 65, 2,  0,4,   25,  2,  2,
                                                                     0, 
                                                             P_MINE|P_C|P_T|P_A,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"np2 naval plane 2",15,  5, 1200, 280, 55, 2,  0,4,   25,  2,  2,
                                                                     0, 
                                                         P_MINE|P_C|P_T|P_A|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"np3 naval plane 3",15,  5, 1200, 310, 45, 2,  0,4,   31,  2,  2,
                                                                     0, 
                                                         P_MINE|P_C|P_T|P_A|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"np4 naval plane 4",15,  5, 1200, 390, 35, 2,  0,4,   31,  2,  2,
                                                                     0, 
                                                         P_MINE|P_C|P_T|P_A|P_L,


/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"nc1 naval chopper 1",8, 2,  800, 250, 55, 2,  0,3,   11,  2,  2,
                                                                     0, 
                                                        P_V|P_SWEEP|P_T|P_A|P_K,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"nc2 naval chopper 2",8,2,   900, 280, 45, 2,  0,4,   13,  2,  2,
                                                                     5, 
                                                        P_V|P_SWEEP|P_T|P_A|P_K,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"nc3 naval chopper 3",8, 2, 1000, 310, 35, 2,  0,5,   13,  2,  2,
                                                                    10, 
                                                        P_V|P_SWEEP|P_T|P_A|P_K,


/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"nc4 naval chopper 4",8, 2, 1000, 390, 15, 2,  0,5,   15,  2,  2,
                                                                    10, 
                                                        P_V|P_SWEEP|P_T|P_A|P_K,


/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"tr1 transport 1",  14,  5, 1000, 150,  0, 4,  0,2,   15,  3,  3,
                                                                     0, 
                                                                        P_C|P_P,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"tr2 transport 2",  15,  5, 1000, 200,  0, 6,  0,3,   17,  3,  3,
                                                                     0, 
                                                                        P_C|P_P,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"tr3 transport 3",  15,  5, 1200, 250,  0, 8,  0,5,   21,  3,  3,
                                                                     0, 
                                                                        P_C|P_P,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jt  jet transport",18,  5, 1500, 280,  0,12,  0,9,   25,  3,  4,
                                                                     0, 
                                                                        P_C,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"tc1 transport chopper 1",8,2,800,280,  0, 4,  0,3,   11,  2,  2,
                                                                     40, 
                                                                P_V|P_C|P_P|P_L,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"tc2 transport chopper 2",8,2,1000,310, 0, 8,  0,5,   13,  2,  2,
                                                                     50, 
                                                                P_V|P_C|P_P|P_K,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"Zeppelin",          6,  2, 1000,  70, 60, 2,  0,-3,  15,  3,  2,
                                                                     0, 
                                                                P_S|P_V|P_T|P_C,
#ifdef RECON
/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"re1 recon 1",      12,  4,  800, 180,  0, 0,  0,9,   15,  2,  2,
                                                                    20, 
                                                                    P_R,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"jr1 jet recon 1",  15,  5, 1000, 260,  0, 0,  0,11,  15,  2,  4,
                                                                    40, 
                                                                    P_R,
#endif
/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"landsat",          20, 20, 2000, 290,  0, 0,  0,3,   41,  0,  9,
                                                                     0, 
                                                                            P_O,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"sp1 spyplane 1",   15,  5, 2000, 290,  0, 0,  0,11,  23,  2,  5,
                                                                    50, 
                                                                            P_S,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"sp2 spyplane 2",   15,  5, 2200, 310,  0, 0,  0,15,  31,  2,  5,
                                                                    70, 
                                                                            P_S,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"ss1 spysat 1",     20, 20, 4000, 330,  0, 0,  0,3,   61,  0,  9,
                                                                     0, 
                                                                        P_O|P_S,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"ss2 spysat 2",     20, 20, 3000, 390,  0, 0,  0,3,   81,  0,  9,
                                                                     0, 
                                                                    P_I|P_O|P_S,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"mi1 missile 1",     8,  2,  300, 270, 60, 6,  0,5,    6,  0,  0,
                                                                     0, 
                                                                    P_L|P_T|P_M|P_MAR,
/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"mi2 missile 2",     8,  2,  300, 310, 50, 8,  0,10,   8,  0,  0,
                                                                     0, 
                                                                    P_L|P_T|P_M|P_MAR,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"mi3 missile 3",    10,  3,  400, 390, 40,10,  0,15,   10,  0,  0,
                                                                     0, 
                                                                    P_L|P_T|P_M|P_MAR,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"sm1 sam 1",         3,  1,  200, 280,  0, 0,  0,18,  2,  0,  0,
                                                                     0, 
                                                            P_L|P_F|P_E|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"sm2 sam 2",         3,  1,  200, 310,  0, 0,  0,23,  3,  0,  0,
                                                                     0, 
                                                            P_L|P_F|P_E|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"sm3 sam 3",         3,  1,  200, 390,  0, 0,  0,26,  4,  0,  0,
                                                                     0, 
                                                                    P_F|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"srbm",             20, 20, 1000, 240, 60, 6,  0,5,    9,  0,  0,
                                                                     0, 
                                                                            P_T|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"irbm",             20, 20, 1500, 270, 60, 8,  0,10,   15,  0,  0,
                                                                     0, 
                                                                           P_T| P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"icbm",             20, 20, 2000, 350, 60,10,  0,15,   41,  0,  0,
                                                                     0, 
                                                                            P_T|P_M,
/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"sl1 slbm 1",       20, 20, 1500, 280, 60, 8,  0,6,   23,  0,  0,
                                                                     0, 
                                                                        P_T|P_L|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"sl2 slbm 2",       20, 20, 2000, 350, 60, 8,  0,11,   41,  0,  0,
                                                                     0, 
                                                                        P_T|P_L|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"at1 a-sat 1",          20, 20,  500, 350, 60, 6,  0,7,   13,  0,  4,
                                                                     0, 
                                                                        P_O|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"at2 a-sat 2",          20, 20,  500, 410, 30, 8,  0,7,   21,  0,  4,
                                                                     0, 
                                                                        P_O|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"ab1 abm 1",        10,  4,  500, 310, 60, 0,  0,31,  17,  0,  0,
                                                                     0, 
                                                                        P_N|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"ab2 abm 2",        10,  4,  500, 390, 50, 0,  0,42,  17,  0,  0,
                                                                     0, 
                                                                        P_N|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"ab3 abm 3",        10,  4,  500, 410, 40, 0,  0,51,  19,  0,  0,
                                                                     0, 
                                                                        P_N|P_M,

/* name            lcm hcm   $$$  tch acc ld  at/df  ran mil gas stlth  flags */
"ab4 abm 4",        10,  4,  500, 430, 30, 0,  0,61,  21,  0,  0,
                                                                     0, 
                                                                        P_N|P_M,

"",                  0,  0,    0,   0,  0, 0,  0,0,    0,  0,  0,
                                                                     0, 
                                                                              0,
};

int	pln_maxno   = (sizeof(plchr) / sizeof(struct plchrstr)) - 1;
