.TH Command HARDEN
.NA harden "Place missiles into protective silos"
.LV Expert
.SY "harden <PLANES> <LEVEL>"
The \*Qharden\*U command is used to install missiles
into protective silos which can prevent their destruction
during a nuclear or non-nuclear
attack.
Each successive \*Qharden\*U command
will add to the current hardness level of the missile in question.
.s1
Each point of hardening uses one unit of heavy construction materials,
and costs $5.
.s1
Once a missile has been placed in a silo
(hardened to a level greater than 0)
it can no longer be moved.
.s1
.SA "launch, Nuke-types, Plane-types, Planes"
