#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/gen/inet.c,v 2.0 1995/07/27 05:56:17 empire Exp $";
#endif

/*
 * Convert network-format internet address
 * to base 256 d.d.d.d representation.
 */

#include <sys/types.h>
#include <netinet/in.h>
#include "misc.h"

#ifndef NeXT
s_char *
inet_ntoa(addr)
	struct in_addr addr;
{
	static	s_char str[18];
	register u_char *p;

	p = (u_char *)&addr;
	sprintf(str, "%d.%d.%d.%d", p[0], p[1], p[2], p[3]);
	return str;
}
#endif /* NeXT */
