.TH Command HEADLINES
.NA headlines "Summarize the weeks events (part of \*Qnews\*U)"
.LV Expert
.SY "headlines [days]"
The headlines command lets you read just the important,
subjective, summary part of the news
without boring you with the confusing details.
.s1
If you include a number in the command,
it will print headlines based on the news from that many previous days.
.s1
The headline \*QRelative Calm Prevails\*U appears
whenever the reporters haven't been able to dig up
any interesting tidbits to give the news analysts.
.s1
The headlines are produced by the editorial staff of the
Empire News who are solely responsible for their lack of content.
.s1
.SA "newspaper, Communication"
