.TH Command GIVE
.NA give "Give(take) Commodities"
.LV Expert
.SY "give <COMM> <SECT> <NUM>"
To get a list of which commodities you can change, type "give" with no arguments.
.SA "setsector, setresource, edit, Deity"
