.TH Command ATTACK
.NA attack "Sector vs sector combat"
.LV Basic
.SY "attack <SECT> [<forts?> <ships?> <arty?> <planes?>]"
.s1
The attack command is used to attack a sector from neighbouring sectors.
For more details, see "info Attack".
.s1
.SA "Attack, Combat, LandUnits"
