#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/gen/getstring.c,v 2.0 1995/07/27 05:56:17 empire Exp $";
#endif

/*
 * getstring.c
 *
 * get string, printing a prompt if there is one.
 *
 * from PSL Empire, 1985
 */

#include "misc.h"

s_char *
getstring(prompt, buf)
	s_char *prompt;
	s_char	buf[1024];
{
	*buf = '\0';
	if (prmptrd(prompt, buf, 1024) < 0)
		return 0;
	return buf;
}
