.TH Command SET
.NA set "Establish price for a ship"
.LV Expert
.SY "set <type> <SHIP/UNIT/PLANE> <PRICE>"
The set price command allows you to set the prices on ships/units/planes
for sale.
.s1
<type> is the type of unit you are putting on sale,
either ship, plane, or land.
<SHIP/UNIT/PLANE> is the unit #, and
<PRICE> is the cost.
.s1
If you don't supply the price on the command line the program
will ask the selling price.
.s1
Negative prices can't be used (no more Crazy Eddie).
.s1
You may withdraw an offer by setting the price to zero.
.s1
The nation multipliers will provide inflated prices to nations you
do not with to sell to, and discounts for those to whom you wish
to give a break.
Note that ships are not \*Qdelivered\*U to the purchaser,
but planes and units are.
.sp
.SA "trade, Obsolete"
