.TH Introduction "New Players"
.NA Newplayers "Things that new players should know"
If you are new to empire you should look into these info files.
.s1
Overview, Introduction, Hints, break, commands.
.s1
To learn and play this game will take a lot of time and effort.
Do not expect to win this game if its your first time out.
Its very possible to play this game, get very good at it, and
still never win a game.
.s1
The first 3 info files above will give you a nice general
introduction to Empire.  Read them carefully cause they hold
valuable information on how to play the game.
.s1
In addition to those files everyone should read the
CHANGES.CHAINSAW.x.x files.  These files contain a list
of the changes made to empire code over the years, bugfixes,
and explanations of the options you will see listed
in the version output.

In this game we have a lot of people and I'm expecting to receive
a high number of questions from many players.  You will find
that you can save both the Deities and yourself some time
by reading the docs.  Please try to do a little research into
any problem before sending it off to Tom or I.  Most of the
time we will end up pointing you to a info file.  Of course
not every detail is covered in them and I don't mind answering
questions should you have any problems.  Please send your
questions to me (Rad_Zone) first.  Should the problem stump
me then I will contact Tom.  The main reason this game has 2 Deities
is that Tom has enough stuff to do in one day and I have very
little to do so bug me first.
.s1
Rad_Zone
.s1
.SA "Introduction"
