#include <X11/copyright.h>

/* $XConsortium: GraphP.h,v 1.2 88/10/25 17:37:59 swick Exp $ */
/* Copyright	Massachusetts Institute of Technology	1987, 1988 */

#ifndef _GraphP_h
#define _GraphP_h

/* include superclass private header file */
#include <X11/IntrinsicP.h>
#include <X11/CoreP.h>

#include "Graph.h"

/* define unique representation types not found in <X11/StringDefs.h> */

#define XtRGraphResource		"GraphResource"

#ifndef TRUE
#define TRUE        1
#endif
#ifndef FALSE 
#define FALSE       0
#endif
#define OutOfMemmory   1

typedef struct {
    int    empty;
} GraphClassPart;

typedef struct _GraphClassRec {
    CoreClassPart	core_class;
    GraphClassPart	graph_class;
} GraphClassRec;

extern GraphClassRec graphClassRec;

typedef struct {
    /*resources */
    int empty;
    Pixel  foreground,
	   background,
	   fghold,bghold;

    GC       XGPgc;
} GraphPart;


typedef struct _GraphRec {
    CorePart		core;
    GraphPart    	graph;
} GraphRec;

#endif  _GraphP_h
