.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject PLANES
.in \w'InterceptionXX\0\0\0\0'u
.s1
.L "arm   "
Load nuclear weapons onto planes or missiles
.L "bomb * "
Dispose of inconvenient enemy assets with airpower.
.L "build * "
Build ships, planes, bridges, land units or nuclear weapons
.L "disarm   "
Remove a nuclear warhead from a plane or missile
.L "drop   "
Use planes to drop commodities in your own sectors
.L "fly * "
Fly planes from sector/ship to sector/ship and bomb or snoop
.L "harden   "
Place missiles into protective silos
.L "launch   "
Launch missiles or satellites
.L "mission * "
Assign a mission to a ship/plane/unit
.L "nuke   "
List all nuclear \*Qdevices\*U in a given area
.L "paradrop   "
Attack a sector from the air
.L "plane * "
Report status of plane, wing or planes in a give area
.L "pmap   "
Get a map around a plane
.L "range   "
Edit the range of a plane
.L "recon   "
Use planes to take a look around
.L "satellite   "
Download data from a reconnaissance satellite
.L "scrap * "
Scrap a ship, plane, or unit
.L "scuttle * "
Destroy a ship, plane, or unit
.L "show * "
Stats for building ships, planes, units, or bridges
.L "sweep   "
Use planes to remove mines from sea sectors
.L "transport * "
Move planes or nuclear devices around
.L "wingadd   "
Designate members of a \*Qwing\*U
.s1
.L "Interception   "
How plane interdiction works
.L "Maintenance   "
The cost to maintain ships, planes, and land units.
.L "Mobility   "
How much mobility stuff costs
.L "Nuke-types   "
Description of different kinds of nuclear weapons
.L "Plane-types * "
Description of different kinds of planes
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
