.TH Server "Differences from Old Empire"
.NA Old-empire "Differences from 1.2 to UCB Empire"
.LV Expert
.s1
.ce
\*(bFUCB Empire Version 0.9.24 - Update for Version 1.2 Players\*(pF
.s1
So you want to try the New Empire Huh?
.s1
Okay, I have written this document with YOU in mind!
Welcome to the University of California at Berkeley's Empire!
(From now on called UCB Empire).
There are a whole bunch of changes in the game 
since we last played, so I need to bring you up to date.
.s1
Our OLD EMPIRE game was Version 1.2 -
written way back in the 70's by Peter Langston,
when he was going to College like we are!
But Empire has come along way since then -
and what many have considered the REAL EMPIRE was released in 1985 -
containing the final version of Peter Langston's Empire game.
It still is considered the \*QStandard\*U.
But in 1986 the \*Qcomputer brains\*U at Berkeley
decided to play around with the Source Code
and create their own \*Qenhanced\*U version of the game.
Hence \*QBerkeley Empire\*U was created....
.s1
.ce
\*(bFChanges from Version 1.2\*(pF
.s1
(Please keep in mind that these are only a FEW on the changes -
you're going to have to read the Manual and use the INFO command
to get a REAL good idea on what you should read up on -
DON'T depend on this list to tell you everything you need to know)
.s1
There is an \*Qannounce\*U command -
this command sends a Telegram to EVERYONE in the game -
and you can make an \*Qannouncement\*U to the World.
.s1
In the OLD game -
you simply dug up ORE and sent it to the Shell, Defense, etc.
factory to have it processed into something else
(make guns, shells, etc).  
.s1
But in the NEW game - sectors are a lot more complex.
For one thing curtain sectors CAN'T even PRODUCE
until your country has reached a given TECH level.
These sectors are currently:
.s1
Shell Factories  (need at least 20 TECH)
Gun Factories  (need at least 20 TECH)
Petroleum Plants [ for Airplane Fuel ] (need at least 20 TECH)
Uranium Mines   (need at least 40 TECH)
.s1
Other sectors can produce normally,
even though your TECH level is still 0.
Keep in mind that you CAN DESIGNATE the ABOVE sectors -
but they won't produce until you reach the desired TECH LEVEL. 
.s1
Also, it takes more \*QMaterials\*U
to make 1 Unit of a finished product.
By this I mean that to make approximately \*Q1 SHELL\*U
at your shell factory, you'd have to have:
3 Dollars (in the treasury),
2 LCM, 1 HCM, and at least 20 TECH Level.
.s1
LCM is Light Construction Materials,
HCM is Heavy Construction Materials,
and I discussed the TECH Level problem (above).
To fully understand this concept -
please see \*Qinfo Products\*U and \*Qinfo Sector-types\*U.
.s1
FORTS - have been improved.
It used to be in OLD Empire that you had to use the DEFEND command
to say which sectors you wanted to DEFEND with the guns from your fort.
But in the NEW Empire -
your forts will fire on ANY enemy attacker
as long as the attacker is within the guns'
range when the \*Qattack\*U was made.
Hence - no more DEFEND command.
.s1
FOOD - In the OLD Empire you didn't have to worry about it -
the people fed themselves.
But in the NEW Empire -
there is a new sector designation called \*Qa\*U for agribusiness.
These are farms that make food and you have to transport that food
to other sectors that don't grow food or those sectors will starve.
**NOTE** that in the \*QFERTILITY\*U rating in the \*QCENSUS\*U report -
only those with HIGH Fertility ratings can successfully grow food.
If the FERTILITY rating is in the 10-30% - BE CAREFUL - they
may not be able to grow enough food to sustain even themselves!
Food is also a great Commodity to \*QSELL\*U (hint,hint!)
.s1
WEATHER - There ISN'T ANY!
(no more rainy days :-)
Although judging from the way Berkeley has been improving the game -
it won't be long till they do fix it.
Can you imagine what weather will be like if they update it
like the did the \*Qplanes\*U!
Thunderstorms, tornadoes, hurricanes, earthquakes, volcanos, etc.
BUT FOR NOW - THERE IS NO WEATHER - Atmosphere is stuck at
\*Q0\*U - clear days!
.s1
NEXT UPDATE (how will I know when it is supposed to Happen?) -
EMPIRE will always tell you when the NEXT UPDATE is scheduled
by using the VERSION command.
VERSION will also tell you how much food will grow per-update and
also things like - how much food you people eat per update - etc.
.s1
MAP CHANGES -
in the OLD Empire you could move u)p, l)eft, r)ight, d)own, etc -
but now you have to move in DIAGONALS -
you'll get used to it -
the world is set up like this so the game can handle
more SECTORS per world.
Basically means that the MAP display is more condensed -
and you'll be able to see more sectors on a MAP display
than ever before.
.NF +0.2i
A few new SECTOR-DESIGNATIONS have been added:

    BASICS                   INDUSTRIES                MILITARY / SCIENTIFIC
    .  sea                   d  defense plant          t  technical center
    ^  mountain              i  shell industry         f  fortress
    s  sanctuary             m  mine                   r  research lab
    /  wasteland             g  gold mine              n  nuclear plant
    -  wilderness            h  harbor                 l  library/school
    c  capital               w  warehouse              e  enlistment center
    p  park                  u  uranium mine           !  headquarters
    COMMUNICATIONS           *  airfield               FINANCIAL
    +  highway               a  agribusiness           b  bank
    )  radar installation    o  oil field
                             j  light manufacturing
    #  bridge head           k  heavy manufacturing
    =  bridge span           %  refinery
.FI
PLEASE!
Fully READ the \*Qinfo Sector-types\*U
.s1
I haven't got time to go through all of them -
but I will point out a few of them that might be unfamiliar to you.
.s1
PARKS - these are special because they convince your people that
they should ENLIST and go out and fight for you!
Lots of fun - gotta have one of these to keep the ENLISTMENT rate high.
.s1
URANIUM MINE - I forgot to add this above with the other Commodities -
with the Commodities \*QFERTILITY\*U, \*QOIL\*U, \*QGOLD\*U,
\*QMINE\*U -
there is also \*QURANIUM\*U.
Uranium is the most UNCOMMON natural resource
and hence those that have a deposit of it
should be careful to guard it well.
When URANIUM is dug up it becomes \*Qradioactive Matter\*U -
you then deliver the Radioactive Matter to the Nuclear Plant
and have it converted into - you guessed it - NUKES!
Be aware, however, that you must have a HIGH Tech level
to make nukes -
and it is going to take you a LONG TIME to get to this point.
.s1
REFINERY SECTORS: These are where the OIL you make
is turned into PETROL(-eum) for your various AIRPLANE needs.
Planes run on PETROL and the refinery sectors make PETROL out of OIL.
You then have to deliver the PETROL to your Airports for use...
.s1
LIBRARY/SCHOOL:  Obviously your people aren't very smart :-)
As it is your going to need to educated them.
Education will increase CROP yields and also help with TECHNOLOGY.
see \*Qinfo education\*U.
.s1
.ce 1
\*(bFWorld Updates\*(pF
.s1
In the OLD EMPIRE - updates weren't handled in a FAIR way.
If you created a 0% FORT before you logged out of Empire -
it would REMAIN a 0% FORT until you logged back into Empire -
and if your on a LONG weekend that could have meant
that you would be WIPED OUT!!!!
.s1
In the NEW EMPIRE -
updates are handled by an independent program
called the \*QTransaction Manager\*U.
This program runs independently of EMPIRE
and runs at 4 hours intervals,
updating the game constantly.
That means that you enemies will be updated just as often as you ARE -
and may make them think a little more carefully about attacking you.
The CURRENT update times are:
.s1
2am, 6am, 10am, 2pm, 6pm, 10pm (In the local time zone)
.s1
NO OTHER UPDATES ARE POSSIBLE - except at these times.
What is updated is all Mobility, Food Production,
Shell & Factory Production, Ship Plane and Sector Efficiency,
and EVERYTHING that \*Qupdate\*U used to do.
(hence there is NO Update Command).
Everyone is updated at the SAME TIME!
.s1
.ce
\*(bFOther Things That Might be of Interest\*(pF
.s1
Terrorists!  -
(real trouble makers, but great for setting on your enemies -
they blow up things and convert followers!)
.s1
SHOOT - it is now possible to SHOOT your civilians
(captured enemy ones) or your own :-)
God knows why you would but...
sometimes the conquered people are REAL radical
and it DOES become necessary
.s1
SELL - you can sell your goods on the OPEN Market -
and set PRICE MULTIPLIERS so that your enemies
HAVE to buy at a BIG mark up -
but your friends can still buy your good cheap!
.s1
Okay - you've been waiting for it - so here it is!
The new line of Ships, Planes and Nukes for Empire:
.ce
\*(bFThe Ships\*(pF
.NF
    $$$  lcm hcm tec def spd vis spy rng fir
    350   20  10  40  30  50  10   4   1   1 patrol boat
    200   25  15   0  10  20  15   2   0   0 fishing boat
    550   25  25  20  60  30  20   3   1   1 minesweep
   1100   25  35  20  80  35  20   4   3   2 destroyer
   2200   40  30  70  30  25   2   3   2   2 submarine
   4000   40  40  50  40  25  60   3   0   0 tanker
   3000   40  50  40 100  30  30   5   6   3 heavy cruiser
    600   60  40   0  50  25  35   3   0   0 cargo ship
   2000   50  50 120  20  10  80   4   0   0 oil derrick
   4400   70  65  60  80  30  35   8   2   2 aircraft carrier
   4000   55  65  50 127  30  35   6   8   4 battleship
   1500   60  30 120  15  40  15   5   0   0 fishing trawler
   4000   90  60 320  30  40   1   3   0   8 nuclear sub
   1200   40  40  70  30  30  30   2   0   0 landing ship
   2500   40  40 220  20  70  17   5   0   0 hydrofoil
   6000   80  30 280  20  30  20  10   0   0 radar center
.FI
.s1
.NF
   food civ mil  sh gun pln dst pet oil
     30   0  10  10   2   0   0   0   0 patrol boat
    100  30   5   0   0   0   0   0   0 fishing boat
     25   0  25  60   2   0   0   0   0 minesweep
     80   0  80  40   4   0   0   0   0 destroyer
     25   0  25  25   4   0   0   0   0 submarine
    200  30   5   0   0   0   0 990 990 tanker
    100   0 120  60   6   0   0   0   0 heavy cruiser
    900  50  50 300  50   0 900   0   0 cargo ship
    300  80  80   0   0   0   0   0 200 oil derrick
    180   0 350 350   4   8   0 500   0 aircraft carrier
    300   0 200 100   8   0   0   0   0 battleship
    120  25   5   0   0   0 100  25   0 fishing trawler
    500  30  30  25   4   8   0  60   0 nuclear sub
    300   0 400   0   0   0   0   0   0 landing ship
     20  60  30   0   0   0   0   0   0 hydrofoil
     60   0  20   0   0   0   0   0   0 radar center
.FI
.s1
The column headings have the following meanings:
.in \w'food\0\0'u
.L $$$
money required to build it
.L lcm
light construction materials required to build it
.L hcm
heavy construction materials required to build it
.L tec
technology required to build it
.L def
defensive armament of the ship
.L spd
the distance/mu for moving (in relative units)
.L vis
how visible the ship is, (relative units)
.L spy
how far the ship can see,
(i.e. how good the communication equipment is),
again in relative units
.L rng
twice the distance the guns can fire,
(assuming  a  high  technology level)
.L fir
the number of guns the ship can fire at once
.L food
the amount of food the ship can carry
.L civ
the number of civilians the ship can carry
.L mil
the number of military the ship can carry
.L sh
the number of shells the ship can carry
.L gun
the number of guns the ship can carry
.L pln
the number of planes the ship can carry
.L dst
the amount of gold dust the ship can carry
.L pet
the amount of petrol the ship can carry
.L oil
the amount of oil the ship can carry
.L aml
the amount of lcms the ship can carry
.L amh
the amount of hcms the ship can carry
.in
.s1
Note that some ship differences are not listed in these tables.
.s1
Only fishing boats and fishing trawlers accumulate food by fishing.
.s1
Only oil derricks accumulate oil at sea.
.s1
Only destroyers will drop depth charges,
and only destroyers can see and fire at submarines.
.s1
Only submarines can fire torpedos.
.s1
Only destroyers and heavy cruisers can lay mines.
.s1
Only minesweeps can reclaim mines from the sea.
.s1
Only nuclear submarines can carry nuclear missiles.
.s1
Only aircraft carriers can launch and retrieve air strikes.
.s1
Only cargo ships can carry lcms (1400) and hcms (900).
.s1
.SA "coastwatch, fire, load, lookout, mine, navigate, tend, torpedo, fly, Server"
