.TH Command NEWSPAPER
.NA newspaper "The yellow press"
.LV Basic
.SY "newspaper <DAYS>"
The news command prints a copy of the local newspaper published by
The Empire News.
.s1
This \*Qmorning after\*U daily recounts financial exploits,
the telegram traffic between countries,
and political maneuvering
in addition to the chronicling of such mundanities as shelling,
attacking, and nuclear testing.
.s1
It's great breakfast reading!
.s1
Normally your edition of the news will only contain events that have
occurred since you last read the news.
You can specify what time period you'd like it to cover
with the optional <DAYS> argument in the command line as in:
.s1
.EX news 2
Which will print the news for the last two days.
.s1
You can select which news to see or not see with the ?actor or 
?victim selectors.
Activities are:
.nf
     1)  Successful Sector attack            29) Alliance dissolving
     2)  Unsuccessful attack                 30) War ending
     3)  Spy shot                            31) Plague outbreaks
     4)  Telegram sent                       32) Plague deaths
     5)  Treaty signing                      33) Name changes
     6)  Loan made                           34) Starvation
     7)  Loan repaid                         35) Rioting (from dissolving)
     8)  Goods sold                          36) Air to air combat
     9)  Airspace violated                   37) Nukes going off
     10) Artillery fire on sectors           38) Terrorists
     11) Artillery fire on ships             39) Shooting civs & uw's
     12) Attacking unowned land              40) Satellite launches
     13) Ship torpedoed                      41) ASAT attacks
     14) Gunners firing in self-defense      42) Deity giving things
     15) Breaking sanctuary                  43) Deity aids country
     16) Planes bombing sectors              44) Deity hurts country
     17) Planes bombing ships                45) Deity taking things
     18) Successful boarding actions         46) ABM interceptions
     19) Unsuccessful boarding actions       47) Missile firing on sectors
     20) AA fire                             48) Missile firing on ships
     21) Collecting on loans                 49) Trade between countries
     22) Considering treaty violation        50) Pirates fence loot
     23) Actual treaty violation             51) Pirates keep loot
     24) Country dissolving                  52) Ship torps ship
     25) Ships hitting mines                 53) Sub bombed by ASW plane
     26) Alliance declaration	             54) Assault defeated
     27) Neutrality declaration              55) Unit bombed
     28) War declarations                    56) Unit hits land mine
     57) Fortress artillery supports attack
     58) Land unit artillery supports attack
     59) Naval artillery supports attack
     60) Capital sacking
     61) Upgrades relations to friendly
     62) Downgrades relations to friendly
     63) Upgrades relations to neutral
     64) Downgrades relations to friendly
     65) Upgrades relations to hostile
     66) Downgrades relations to friendly
     67) Missile hits sector
     68) Missile hits ship
     69) Settles on a new island
     70) ABM interception
     71) Missile hits units
     72) Sub-launched missile hits units
     73) Successful assault
     74) Successful paradrop
     75) Paradrop into unoccuppied land
     76) Failed assault
     77) Failed paradrop
.fi
.s1
.SA "headlines, Communication"
