.TH Command TURN
.NA turn "Allow/disallow logins. Change login message."
.LV Expert
.SY "turn <on|off|mess>"
Use "turn on" or "turn off" to enable/disable logins.  If you just
want to change the login message, then use "turn mess".  In all three
cases, you will be put into the telegram prompter to enter a new motd
(message of the day) which is printed when the player logs in.
.SA "Deity"
