.TH Command UPGRADE
.NA upgrade "Update the tech of a ship to the current tech level"
.LV Expert
.SY "upgrade <SHIP/FLEET>"
The upgrade command allows a country to set the tech level
of its ships to the country's current tech level.
.s1
Each ship to be upgraded must be in one of the country's harbors
that is at least 60% efficient and has an available workforce
of at least half the size it would take to build the ship from scratch.
To be upgraded, a ship must be at least 60% efficient.
.s1
Refitting a ship costs half as much as building a new one
from scratch and reduces the efficiency of the ship by 35%.
.s1
.SA "build, ship, Technology, Ships"
