.TH Command MARKET
.NA market "Report current selling prices in the world market"
.LV Expert
.SY "market"
The market report displays the lowest-priced commodity of each
item type on the market which is not on sale by you, the selling
nation, the number of units on sale, and the price per unit.
.s1
If a product argument is given, then a list of the prices of
that product is printed in the same way as buy.
.s1
Note that this takes into account the multiplier from the selling
nation to your country, so the market price may vary from country
to country.
.s1
.EX market
.NF
      -= World Commodity Market Report =-
            Mon Oct  6 10:22:09 1986
 item        cnum      country    qty     $/unit
shells       (# 3)           Oz     219  500.00
iron ore     (#12)       Idiots     696    5.00
dust (gold)  (#14)          Zyf      20  120.00
food         (# 7)        Vixen     500    0.15
light produc (# 3)           Oz     175  200.00
.FI
.s1
.SA "buy, sell, mult, Obsolete"
