/*
 * event.h
 *
 * Something happened; send an event to a user.
 *
 * $Revision: 2.0 $ $Date: 1995/07/27 05:28:09 $
 */

#ifndef _EVENT_H_
#define _EVENT_H_

/* country #1's battleship #2 hit your battleship #3 for 30% damage */
/* actor's from_type #from_id hit your to_type #to_id for data% damage */
struct event {
	short verb;
	natid actor;
	natid victim;
	short from_type;
	short data;
	int from_id;
	short to_type;
	int to_id;
	time_t time;
};

#endif /* _EVENT_H_ */
