.TH Concept Guerrilla
.NA Guerrilla "Guerrilla warfare"
.LV Expert
.s1
Guerrillas are created in several ways;
when a sector is captured by an enemy,
or when civilians riot for one reason or another
(starvation, no happiness, etc).
.s1
Guerrillas have a generally detrimental effect
on the well-being of your country.
Depending on the amount of military in the sector they \*Qinfest\*U,
they will either attack the military there
(but only if they have a good chance of winning),
blow up things (lowering sector efficiency),
or, if they are too badly outnumbered,
they will try and move to a different sector.
.s1
If there are no military in the \*Qinfested\*U sector
at the end of the update to break up guerrilla recruitment drives,
your civilians' loyalty will suffer.
If the sector is only occupied --
not completely owned by you, that is --
then it will revert back to the old owner,
renouncing the conqueror and returning to their old allegiance.
The guerrillas will then move on to \*Qconvert\*U more sectors.
Particular guerrilla bands will fight to the death,
or until you dissolve in disgust.
.s1
Guerrillas will attempt to \*Qrecruit\*U new followers
from semi-loyal sectors and from the uncompensated worker population.
Loyal civilians will resist these recruiting drives,
but uncompensated workers will always flock to the banner
of the guerrilla warrior.
.s1
The renowned guerrilla fighter Colonel (later Captain) Batguano
gave a talk to the special forces, which was later made into an
Armed Forces Technical Manual.
In it he states,
.s1
.in +0.8i
.ev 2
.ll 5.5i
The first thing you learn is that the che are hardier than cockroaches,
eat like birds, and are simply invulnerable to gunfire and napalm.
They hide in the sewers.
There are two ways to handle the guerrilla problem;
one way requires high yield fusion weapons,
and then they only die when everything else in the sector is destroyed.
Unfortunately, collateral damage to civilian assets renders this
strategy negatory ... \* Col. Batguano then launches into
a tirade against the \*Qwimpy-assed liberals\*U which interfere with the
proper guerrilla suppression techniques \* ...
Almost every fully-populated area we moved into
had a few dozen of the little monsters,
and troop levels of 50-100 per sector were found to adequately
pacify the region.
Of course, depopulating the area prior to takeover often had a salutary
effect on the number of che we later found...
.ll 6.5i
.ev
.in
.s1
You will be notified of the varying civil disturbances
by \*Qproduction\*U telegrams showing a body count of guerrillas killed,
a sector being subverted by revolutionary propaganda,
or a sector lost to guerrilla activities!
.s1
Land units present in a sector help to fight them, fighting without
any multiplier, either offensive or defensive and without any
fortification bonus. Any units with the
\*Qsecurity\*U ability will also kill some che before anything else is
done (commando raids).
.SA "Populace, Occupation, Update"
