.TH Introduction "Empire2 Compatable Clients"
.NA Clients "Clients which communicate well with the Empire2 Server"
.LV Basic
.NF
What follows is a list of clients which support the new Empire2
protocol.  All of these clients may be found on the Planet's Empire
Archives located at:
  http://www.empire.net/~children/
or
  ftp://ftp.empire.net/pub/empire/

pei2.3          - full support
empclient-2.5   - full support
wse20           - full support
xemp5.1         - full support

If you are using one of these four clients, then you should type
"toggle inform" once you have broken sanctuary.  These four clients
are fully asynchronous, which means that they are able to respond
immediately when an unexpected message arrives from the server.  So,
for example, if someone sends you a "flash" message, then the message
will be printed on your screen immediately.  Similarly, with "inform"
toggled on, you will be informed the moment a telegram arrives.  Note,
the server remembers your toggle flags when you log out, so you do not
have to type "toggle inform" again the next time you connect.


eif2.5          - partial support

Unfortunately, eif is not an asynchronous client--it only checks for
data from the server after you have typed an Empire command.  So if
someone sends you a flash message, then you won't see it until the
next time you send a command to the server.  Because of this, eif
users are encouraged to keep the "inform" flag toggled off.


other clients   - no support

Most other clients should work fine with the Empire2 server, however
they may get confused if a flash message comes in.  Users of other
clients should keep the "inform" flag toggled off, and ask a friend to
send them a "flash" message to see how the client handles it (note,
you must declare friendly relations towards them in order to receive
the flash message).  If the flash message confuses your client, then I
recommend you type "toggle flash" to turn flash mode off.
.FI
.SA "toggle, Empire2, Communication, Introduction"
