.TH Server "The HIDDEN Option"
.NA Hidden "The HIDDEN option"
.LV Expert
.s1
The following commands are restricted when the HIDDEN option is
in play:
.NF
power:  Will only display your country's power. Other nations never show up.
report: Will only report on contacted countries, and no status (active/flux).
relat:  Will only display contacted countries.
news:   Will only show news about contacted countries (except for headlines).
accep:  Will only display contacted countries.
tele:   Only allowed with contacted and deity countries.
.FI
.s1
A country is 'contacted' with a successful spy, look, coastwatch,
or recon, when an attack is made, or when you are the victom of an attack
or if you receive a telegram.
.s1
It possible for contact to be one sided. If you contact someone, they must
also contact you in order to obtain information from you. If you want someone
to be able to contact you, you can send them a telegram.
.s1
Tech and research bleed only comes from contacted countries, so it's in your
best interest to explore as much as possible.
.s1
Because of the difficulty of tracking past news, news cannot be used
with an argument under this option. Once the news is read, it cannot be
read again. This may change in the future.
.s1
If the LOSE_CONTACT option is in play, contact is lost after three
update of no contact. Contact can be maintained by the same methods described
above. It's important to note, however, that contact is retained by RECEIVING
a telegram, not sending one.

.SA "Options, Server"
