.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject UPDATE
.in \w'UpdateMsequenceXX\0\0\0\0'u
.s1
.L "budget * "
Look at a national balance sheet & set priorities
.L "neweff   "
Find out what the efficiency of a sector will be after the next update
.L "production * "
Predicts production of sectors at the next update
.L "start * "
Turn sector production on
.L "stop   "
Stop sector production
.L "update * "
Find out when the next update will be
.s1
.L "Autofeed   "
How to use fishing boats to automatically feed your civs
.L "Autonav   "
Giving ships automatic sailing orders
.L "Education   "
How Education is calculated at the update
.L "Food   "
How much people eat at the update
.L "Guerrilla   "
Guerrilla warfare
.L "Happiness   "
How happiness is calculated at the update
.L "Maintenance   "
The cost to maintain ships, planes, and land units.
.L "Plague   "
The Plague
.L "Products * "
Formulas for the production of commodities
.L "Research   "
How Research level is calculated each update
.L "Taxes   "
How taxes are calculated
.L "Technology   "
How technology level is calculated each update
.L "Update-sequence   "
The order of events at the update
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
