.TH Command PRAY
.NA pray "Interacting with the Deity"
.LV Basic
.s1
There is one country in the game that has no material possessions yet
owns everything...
That country is country #0 (often called \*QThe Deity\*U).
The power of this ethereal country is unbounded --
it can do anything from creating a civilian
(as was the case with the first civilian),
to literally moving mountains.
.s1
Despite this great power The Deity keeps his hands out of the game
and country #0 only gets involved when there is a problem with
the source code, or prohibited activity is suspected.
The most common form of prayer
is the telegram; if you should be in need of aid type:

.EX pray

When the program requests your message for The Deity,
state it simply:
.NF
Enter telegram for your Gracious Deity; end with ^D
<512> I can't do anything!!!!
<488> HELP!!
<481> .
.FI
If this doesn't get helpful results then you should send a
second prayer with more specific details. e.g.
.NF
<512> Every time I type any command which requires a BTU
<461> I get dumped out of the game.  Can you help me?
<413> .
.FI
.s1
This last message is sure to move the compassionate Deity to
provide help.
.s1
In general, when you encounter problems, be as specific about them
as possible. Include a transcript of the output of the problem,
if available. The more information you provide, the easier it is
for the deity to give you a quick & fair fix for the problem.
.s1
.SA "telegram, Communication, Playing"
