.TH Command DUMP
.NA dump "Dump raw sector information"
.LV Expert
.SY "dump <SECTS>"
The dump command displays all information on
some or all of the sectors you occupy. 
dump is a combination of census, commodity, cutoff and level.
Each sector's information is printed on one very long line.
Fields are separated by a single space.
.s1
This command is designed to be used for input to an empire tool
such as \*Qve\*U.
.s1
In the syntax of the dump command
<SECTS> is the area on which you wish information,
(see \*Qinfo Syntax\*U).
.s1
A typical usage might be:
.EX dump #5
which would list data for all sectors in realm #5.
.s1
A dump lists each of your sectors in the specified area.
The header line is a list of fields that correspond
to the order that dump prints the sector info.
.FI
.s1
.SA "census, commodity, cutoff, level, Sectors"
