/*
 * options.h
 *
 * Define which "optional" features should be enabled.
 *
 */

/* Stuff from KSU & Greyhelm --ts */
#define SNEAK_ATTACK	/* Allows sneak attacks */
#define WIRE		/* Splits teles and annos */
/* #define BAN */
#define BANFILE EMPPATH(data/ban)   /* file with banned users */
#define AUTHFILE EMPPATH(data/auth) /* file with users authorized to be deity */
#define MOVEMAP		/* Show explore-style map for move */
#define NEWREPORT	/* Doesn't show visitors, sancts */
/*#define BLITZ*/		/* Sets a couple of things. BTU's always max when you
			   log in.. changing name doesn't take any btus or $$
			   enables BLITZ updates, also turns on NOFOOD, below */

#define	START_UNITS	2 /* How many free start units you get. Types are
			     specified in lib/global/constants.c */

/* These are from ts */
/*#define NONUKES		/* eliminates nukes */
#define DAVYJONES	/* Nuking water affects 1 hex, sanct/waste no effect */
#define SWEEP_PLANES	/* Planes that can sweep mines */
#define MINE_PLANES	/* Planes that can lay mines */
#define RETREAT		/* retreat paths for ships/fleets */
#define OWNASSAULT	/* can assault your own sects to reinforce */
#define ALLYHARBORWORK	/* Allies work on your ships */
#define ALLYUPGRADE	/* Allies can upgrade your ships */
#define WING_LOAD	/* can load an entire wing of planes at once */
#define PARAFLAG	/* only planes with the para flag can paratroop */
#define STEALTHV	/* Give each plane a stealth rating */
#define HARBOR_POLICE	/* allow boarding of enemy ships in your harbors */
#define ASW_PLANES	/* planes that kill subs */
#define SHIPTORP	/* Allows ships to torp ships */
#define REALM_IN_NAT	/* have realms in nation command */
#define NEWFISH		/* fishing is 10x as good */
#define FUEL		/* Ships use fuel to move */
#define TRADESHIPS
#define NEWPOWER	/* Better power formula */
#define SHIPCHOPPERS	/* Some non-carriers can carry choppers */
#define XLIGHT	 	/* some planes are extra-light, can be on non-carriers*/
#define SEMILAND	/* enable semi-landing ships */
#define NOMOBCOST	/* No mob cost for firing from ships */
#define GODNAMES	/* Attach deity name to telegrams (for multiple gods) */
#define TACARGO		/* Allow cargo ships to bomb if they also are tactical*/
#define NOGODS		/* Deity countries don't appear in power reports */
/* #define BABY_NUKES    /* Nukes only affect 1 hex */
#define SUPER_BARS    /* Bars can't be destroyed by fire */
#define EASY_BRIDGES  /* Bridges can be built anywhere */
#define BETTERARMOR   /* Ships armor affect shelling */
#define ALL_BLEED     /* Tech bleeds to everyone */
#define DRNUKE        /* Need research to make nukes */
/*#define SLOW_WAR      /* Declaring war takes time */
#define CARRIER_WORK	/* mil on carriers work on damaged planes */
/* #define NO_PLAGUE	/* Plague is disabled */
#define NEW_STARVE	/* UW's starve, then civs, then mil */
#define NEW_WORK	/* Work is changed in proportion to the # of civs mvd */
#define STOP		/* Can start/stop work in a sector */
#define RES_POP		/* population is limited by research */
/*#define GRAB_THINGS	/* units will grab things they need to build */


#define	ALLYHARBOR	/**/
#define	SHOWPLANE	/**/
#define	DROPANY	/**/
#define	REJECTS	/**/
#define	BMAP	/**/
#define	AUTONAV	/**/
#define	SCUTTLE	/**/
#define	CONVASAT	/**/
/* #define	ORBIT	/**/
#define	ABM	/**/
#define	GRIND	/**/
#define	PINPOINTMISSILE	/**/
/* #define	FALLOUT	/**/
#define	SAIL	/**/
#define	NUKEFAILDETONATE	/**/
/* #define	MISSINGMISSILES	/**/
#define	SHIPNAMES	/**/
/* #define	NEUTRON	/**/
#define	NONUKESUB	/**/
/*#define	BETTERABM	/* ABM's will be launched to intercept ANY */
				/* non-allied nuke in range */
#define	RANGEEDIT	/**/
#define	MISSDEF	/**/
#define	SHIPSAM	/**/
#define	UPDATESCHED /**/
#ifdef UPDATESCHED
#define	DEMANDUPDATE /* NOTE! Depends on UPDATESCHED! Don't use without it! */
#endif /* UPDATESCHED */
#ifdef BLITZ
#define NOFOOD			/* automatically have no food for blitzes */
#endif /* BLITZ */
/*#define	NOFOOD /**/
#define	BIND	/**/

#define	MERC

#ifdef TRADESHIPS
#endif /* TRADESHIPS */


#ifndef SLOW_WAR
#undef SNEAK_ATTACK	/* SNEAK_ATTACK is only useful with SLOW_WAR */
#endif /* SLOW_WAR */
