#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/gen/same.c,v 2.0 1995/07/27 05:56:17 empire Exp $";
#endif

/*
 * same.c
 *
 * return true if strings are the same.
 *
 * from PSL Empire, 1985
 */

#include "misc.h"

int
same(s1, s2)
	register s_char *s1;
	register s_char *s2;
{
	while (*s1 == *s2++) {
		if (*s1++ == 0)
			return 1;
	}
	return 0;
}
