.TH Command SCRAP
.NA scrap "Scrap a ship, plane, or unit"
.LV Basic
.SY "scrap <s|l|p> <SHIPS | UNITS | PLANES>"
This command allows you to scrap planes/units/ships when you no longer
need them.
.s1
Ships may only be scrapped friendly 60% harbours.
Planes may only be scrapped in 60% airfields.
Units may be scrapped in any sector.
.s1
When scrapping a unit, plane or ship, you receive materials equal to 2/3
the amount used to build it. The materials are put in the sector where
the scrapping occurs.
.s1
When scrapping a unit, you also get the military that the unit represents
as mil in the sector. (Example: a unit that takes 100 mil to build is
at 50%, and is scrapped. 50 mil will be added to the sector) Units on 
ships cannot be scrapped.
.s1
If you scrap a ship or unit that has planes on board, the planes will
be transferred to the sector.
.s1
.SA "scuttle, build, ship, land, plane, Ships, Planes, LandUnits"
