/*
 * struct.h
 *
 * access to information relating to the fields of a structure
 *
 * @(#)struct.h 1.5 88/02/07 SMI; from UCB 4.1 83/05/03
 * $Revision: 2.0 $ $Date: 1995/07/27 05:29:42 $
 */

#ifndef _STRUCT_H_
#define _STRUCT_H_

#define	fldoff(str, fld)	((int)&(((struct str *)0)->fld))
#define	fldsiz(str, fld)	(sizeof(((struct str *)0)->fld))
#define	strbase(str, ptr, fld)	((struct str *)((s_char *)(ptr)-fldoff(str, fld)))

#endif /* _STRUCT_H_ */
