
/* module: /net/midway/a/mr-frog/empire/CS3.4/server/idle.c */

void player_kill_idle(int, char **);

/* module: /net/midway/a/mr-frog/empire/CS3.4/server/main.c */

int main(int, char **);
int init_files(void);
int close_files(void);
int panic(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/server/update.c */

void update_sched(int, char **);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/as/as_costcomp.c */

int as_costcomp(struct as_node **, struct as_node **);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/as/as_delete.c */

void as_reset(struct as_data *);
void as_delete(struct as_data *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/as/as_extend.c */

struct as_queue *as_extend(struct as_data *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/as/as_hash.c */

struct as_coord {
    int x;
    int y;
} ;
struct as_queue *as_iscinq(struct as_data *, struct as_coord);
void as_setcinq(struct as_data *, struct as_coord, struct as_queue *);
void as_free_hashtab(struct as_data *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/as/as_init.c */

struct as_data *as_init(int, int, int (*)(), int (*)(), double (*)(), double (*)(), double (*)(), char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/as/as_merge.c */

struct as_queue *as_merge(struct as_data *, struct as_queue *, struct as_node **);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/as/as_search.c */

int as_search(struct as_data *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/as/as_stats.c */

int as_stats(struct as_data *, struct _iobuf *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/as/as_winnow.c */

int as_winnow(struct as_data *, struct as_coord *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/acce.c */

int acce(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/add.c */

int add(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/arm.c */

int arm(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/army.c */

int army(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/assa.c */

int assa(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/atta.c */

int atta(void);
int take_attacker_casualty(struct qelem *);
int take_defender_casualty(struct qelem *, unsigned char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/bdes.c */

int bdes(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/best.c */

int best(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/bmap.c */

int bmap(void);
int bmnxtsct(struct nstr_sect *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/boar.c */

int boar(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/bomb.c */

int bomb(void);
int lflak_planedamage(struct plnstr *, unsigned char, int, unsigned char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/brea.c */

int brea(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/budg.c */

int budg(void);
int calc_all(int *, int *, int *, int *, int *, int *, int *, int *, int *, int *, int *, int *, int *, int *, int *, int *, int *, int *);
int calc_prod(int *, int *, int *, int *, int *, int *, int);
int calc_ships(int *, int *, int *, int);
int calc_shiprepair(struct shpstr *, int *, struct natstr *, int, int *);
int calc_units(int *, int *, int *, int);
int calc_landrepair(struct lndstr *, struct natstr *, int, int *);
int calc_planes(int *, int *, int *, int);
int goodsect(char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/buil.c */

int buil(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/buy.c */

int buy(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/capi.c */

int capi(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/carg.c */

int carg(void);
int lcarg(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/cede.c */

int cede(void);
int cede_sect(struct nstr_sect *, unsigned char);
int grab_sect(struct sctstr *, unsigned char);
int cede_ship(struct nstr_item *, unsigned char);
int grab_ship(struct shpstr *, unsigned char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/cens.c */

int cens(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/chan.c */

int chan(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/coas.c */

int coas(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/coll.c */

int coll(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/comm.c */

int comm(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/cons.c */

int cons(void);
int cons_choose(struct ltcomstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/conv.c */

int conv(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/coun.c */

int coun(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/cuto.c */

int cuto(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/decl.c */

int decl(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/deli.c */

int deli(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/demo.c */

int demo(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/desi.c */

int desi(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/disa.c */

int disa(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/diss.c */

int diss(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/dist.c */

int dist(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/drop.c */

int drop(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/dump.c */

int dump(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/edit.c */

int edit(void);
int errcheck(int, int);
int getin(char **, char **, int *);
int doland(char, int, struct sctstr *);
int docountry(char, int, char *, double, unsigned char, struct natstr *);
int doship(char, int, char *, struct shpstr *);
int dounit(char, int, char *, struct lndstr *);
int doplane(char, int, char *, struct plnstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/enab.c */

int enab(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/enli.c */

int enli(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/expl.c */

int expl(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/fina.c */

int fina(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/flee.c */

int flee(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/fly.c */

int fly(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/foll.c */

int foll(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/forc.c */

int force(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/fort.c */

int fort(void);
int is_engineer(int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/fuel.c */

int fuel(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/give.c */

int give(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/grin.c */

int grin(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/hard.c */

int hard(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/head.c */

int head(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/hidd.c */

int hidd(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/info.c */

int info(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/land.c */

int land(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/laun.c */

int laun(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/ledg.c */

int ledg(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/leve.c */

int leve(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/load.c */

int load(void);
int lload(void);
int gift(int, int, char *, int, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/look.c */

int look(void);
int llook(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/lten.c */

int ltend(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/mail.c */

int mail(void);
int read_telegrams(struct _iobuf *, int);
int print_headers(int);
int write_telegrams(char *);
int prompt(void);
int print_message(int);
int process_delete(char *, int, int);
int count_teles(void);
struct qelem *find_message(int);
int mail_help(void);
int inseque(struct qelem *, struct qelem *);
int scopy(char *, char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/map.c */

int map(void);
int bitinit2(struct nstr_sect *, unsigned char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/marc.c */

int march(void);
int sweep_landmines(struct lndstr *);
int hit_landmine(struct lndstr *);
int check_landmines(struct lndstr *, int *, int, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/mark.c */

int mark(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/mfir.c */

int multifire(void);
enum targ_type {
     targ_land=0,
     targ_ship=1,
     targ_sub=2,
     targ_unit=3,
     targ_bogus=4
 } ;
int defend(struct qelem *, struct qelem *, enum targ_type, enum targ_type, struct sctstr *, struct sctstr *, struct shpstr *, struct shpstr *, int, int, int, int *);
int do_defdam(struct qelem *, double);
int quiet_bigdef(int, struct qelem *, unsigned char, unsigned char, int, short, short, int *);
int use_ammo(struct qelem *);
int add_to_fired_queue(struct qelem *, struct qelem *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/mine.c */

int mine(void);
int landmine(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/miss.c */

int mission(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/mobq.c */

int mobq(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/mora.c */

int morale(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/move.c */

int move(void);
int would_abandon(struct sctstr *, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/mult.c */

int mult(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/name.c */

int name(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/nati.c */

int nati(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/navi.c */

int navi(void);
int nav_map(int, int, char);
int sweep_mines(struct shpstr *);
int hit_mine(struct shpstr *);
int check_mines(struct shpstr *, int *, int, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/new.c */

int new(void);
int deity_build_land(int, short, short, unsigned char, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/newe.c */

int newe(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/news.c */

int news(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/nuke.c */

int nuke(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/offe.c */

int offe(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/offs.c */

int offs(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/orde.c */

int orde(void);
int qorde(void);
int sorde(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/orig.c */

int orig(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/para.c */

int para(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/path.c */

int path(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/payo.c */

int payo(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/plan.c */

int plan(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/powe.c */

int powe(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/prod.c */

int prod(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/rada.c */

int rada(void);
int lrada(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/rang.c */

int range(void);
int lrange(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/rea.c */

int rea(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/real.c */

int real(void);
int dreal(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/reco.c */

int reco(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/reje.c */

int reje(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/rela.c */

int rela(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/repa.c */

int repa(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/repo.c */

int repo(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/reso.c */

int reso(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/retr.c */

int retr(void);
int lretr(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/rout.c */

int rout(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/sail.c */

int sail(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/sate.c */

int sate(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/scra.c */

int scra(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/scut.c */

int scut(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/sect.c */

int sct(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/sell.c */

int sell(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/set.c */

int set(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/setres.c */

int setres(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/setsect.c */

int setsector(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/shi.c */

int shi(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/shoo.c */

int shoo(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/show.c */

int show(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/sona.c */

int sona(void);
int plane_sona(struct qelem *, int, int, struct shiplook *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/spy.c */

int spy(void);
int prunits(int, int);
int num_units(int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/star.c */

int start(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/stop.c */

int stop(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/strv.c */

int starve(void);
int feed_people(int *, int, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/supp.c */

int supp(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/surv.c */

int surv(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/tele.c */

int tele(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/tend.c */

int tend(void);
int tend_nxtitem(struct nstr_item *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/terr.c */

int terr(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/thre.c */

int thre(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/torp.c */

int torp(void);
int anti_torp(int, int, int);
int canshoot(struct shpstr *, struct shpstr *);
int cantorp(struct shpstr *, struct shpstr *);
int candchrg(struct shpstr *, struct shpstr *);
int fire_dchrg(struct shpstr *, struct shpstr *, int, int);
int fire_torp(struct shpstr *, struct shpstr *, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/trad.c */

int trad(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/tran.c */

int tran(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/trea.c */

int trea(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/turn.c */

int turn(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/upda.c */

int upda(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/upgr.c */

int upgr(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/vers.c */

int vers(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/wai.c */

int wai(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/wing.c */

int wing(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/wipe.c */

int wipe(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/work.c */

int work(void);
int buildeff(struct sctstr *, int, double *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/commands/zdon.c */

int zdon(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/bestpath.c */

char *bestpath(char *, int, int, int, int, char *);
int navigable(int, int, char *);
char *bestownedpath(char *, char *, int, int, int, int, char *, int, int);
int owned_and_navigable(char *, int, int, char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/bridgefall.c */

int bridgefall(struct sctstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/damage.c */

int shipdamage(struct shpstr *, int);
int landdamage(struct lndstr *, int);
int planedamage(struct plnstr *, int);
int nukedamage(struct nchrstr *, int, int);
int damage(int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/file.c */

int ef_open(int, int, int);
int ef_close(int);
int ef_flush(int);
char *ef_ptr(int, int);
int ef_read(int, int, char *);
int ef_nbread(int, int, char *);
int ef_write(int, int, char *);
int ef_nbwrite(int, int, char *);
int ef_zapcache(int);
struct castr *ef_cadef(int);
int ef_nelem(int);
int ef_flags(int);
int ef_lock(int);
int ef_unlock(int);
int ef_mtime(int);
int ef_vars(int, char *, unsigned char **, unsigned char **, unsigned short **);
int ef_byname(char *);
char *ef_nameof(int);
int ef_check(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/fsize.c */

int fsize(int);
int blksize(int);
int fdate(int);
int filetruncate(char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/getvar.c */

int getvar(int, char *, int);
int getvec(int, int *, char *, int);
int putvar(int, int, char *, int);
int putvec(int, int *, char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/hours.c */

int gamehours(int, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/keyword.c */

int kw_read(struct _iobuf *);
char *kw_find(char *);
char *kw_parse(int, char *, int *);
char *weekday(char *, int *);
char *get_time(char *, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/land.c */

int has_units(short, short, unsigned char);
int has_units_with_mob(short, short, unsigned char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/log.c */

int loginit(void);
/*VARARGS*/
int logerror(int);
/*VARARGS*/
int filelogerror(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/mailbox.c */

char *mailbox(char *, unsigned char);
char *wirebox(char *, unsigned char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/move.c */

double sector_mcost(int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/nat.c */

char *cname(unsigned char);
char *relatename(struct natstr *, unsigned char);
char *rejectname(struct natstr *, unsigned char);
char *natstate(struct natstr *);
int getrel(struct natstr *, unsigned char);
int getrejects(unsigned char, struct natstr *);
int putrel(struct natstr *, unsigned char, int);
int putreject(struct natstr *, unsigned char, int, int);
int isallied(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/nstr_subs.c */

int nstr_exec(struct nscstr *, int, char *, int);
int decode(int, char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/path.c */

char *bp_init(void);
int best_path(struct sctstr *, struct sctstr *, char *);
char *BestDistPath(char *, struct sctstr *, struct sctstr *, double *);
char *BestLandPath(char *, struct sctstr *, struct sctstr *, double *);
double pathcost(struct sctstr *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/res_pop.c */

int max_pop(double);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/sectdamage.c */

int sectdamage(struct sctstr *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/snxtit_subs.c */

int snxtitem_area(struct nstr_item *, int, struct range *);
int snxtitem_dist(struct nstr_item *, int, int, int, int);
int snxtitem_xy(struct nstr_item *, int, short, short);
int snxtitem_all(struct nstr_item *, int);
int snxtitem_group(struct nstr_item *, int, char);
int snxtitem_rewind(struct nstr_item *);
int snxtitem_list(struct nstr_item *, int, int *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/snxtsct_subs.c */

int snxtsct_all(struct nstr_sect *);
int snxtsct_area(struct nstr_sect *, struct range *);
int snxtsct_rewind(struct nstr_sect *);
int snxtsct_dist(struct nstr_sect *, short, short, int);
int xysize_range(struct range *);
int xydist_range(short, short, int, struct range *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/stmtch.c */

int stmtch(char *, char *, int, int);
int mineq(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/tfact.c */

double tfact(unsigned char, double);
double techfact(int, double);
double reltech(int, int, double);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/type.c */

int typematch(char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/vlist.c */

int vl_find(int, unsigned char *, unsigned short *, int);
int vl_set(int, unsigned int, unsigned char *, unsigned short *, unsigned char *, int);
int vl_damage(int, unsigned char *, unsigned short *, int);
int vl_getvec(unsigned char *, unsigned short *, int, int, int *);
int vl_setvec(unsigned char *, unsigned short *, unsigned char *, int, int, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/wantupd.c */

int demand_update_want(int *, int *, int);
int demandupdatecheck(void);
int update_maxmissed(void);
int update_between(void);
int updatetime(int *);
int demand_update_info(int *, int *, int *, int *);
int next_update_time(int *, int *, int *);
int next_update_check_time(int *, int *, int *);
int updates_disabled(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/common/xy.c */

char *xyas(short, short, unsigned char);
char *ownxy(struct sctstr *);
int prxy(char *, short, short, unsigned char);
short xrel(struct natstr *, short);
short yrel(struct natstr *, short);
int xyrelrange(struct natstr *, struct range *, struct range *);
int xyabsrange(struct natstr *, struct range *, struct range *);
int inputxy(short *, short *, unsigned char);
short xabs(struct natstr *, short);
short yabs(struct natstr *, short);
int sctoff(short, short);
short xnorm(short);
short ynorm(short);
int xyinrange(short, short, struct range *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/atoip.c */

int atoip(char **);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/atopi.c */

int atopi(char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/bit.c */

unsigned int *bit_newfdmask(void);
int bit_zero(unsigned int *);
int bit_not(unsigned int *);
int bit_copy(unsigned int *, unsigned int *);
int bit_or(unsigned int *, unsigned int *);
int bit_or3(unsigned int *, unsigned int *, unsigned int *);
int bit_and(unsigned int *, unsigned int *);
int bit_and3(unsigned int *, unsigned int *, unsigned int *);
int bit_fd(unsigned int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/chance.c */

int chance(double);
int roll(int);
int roundavg(double);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/copy.c */

char *copy(char *, char *);
int blankfill(char *, struct range *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/disassoc.c */

int disassoc(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/dtable.c */

int setfdtablesize(int, int);
int getfdtablesize(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/getstarg.c */

char *getstarg(char *, char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/getstring.c */

char *getstring(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/hpux.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/iceil.c */

int iceil(double);
int ifloor(double);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/inet.c */

struct in_addr {
    union /* unnamed */ {
        struct /* unnamed */ {
            unsigned char s_b1;
            unsigned char s_b2;
            unsigned char s_b3;
            unsigned char s_b4;
        } S_un_b;
        struct /* unnamed */ {
            unsigned short s_w1;
            unsigned short s_w2;
        } S_un_w;
        unsigned int S_addr;
    } S_un;
} ;
char *inet_ntoa(struct in_addr);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/io.c */

int io_init(void);
struct iop *io_open(int, int, int, int (*)(), char *);
int io_close(struct iop *);
int io_input(struct iop *);
int io_inputwaiting(struct iop *);
int io_outputwaiting(struct iop *);
int io_output(struct iop *);
int io_select(struct timeval *);
int io_flush(void);
int io_peek(struct iop *, char *, int);
int io_read(struct iop *, char *, int);
int io_write(struct iop *, char *, int);
int io_gets(struct iop *, char *, int);
int io_puts(struct iop *, char *);
int io_shutdown(struct iop *, int);
int io_noblocking(struct iop *, int);
int io_conn(struct iop *);
int io_error(struct iop *);
int io_eof(struct iop *);
int io_fileno(struct iop *);
struct iop *io_iopfromfd(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/io_mask.c */

struct io_mask *iom_create(int);
int iom_getmask(struct io_mask *, int *, unsigned int **, unsigned int **);
int iom_set(struct io_mask *, int, int);
int iom_clear(struct io_mask *, int, int);
int iom_zero(struct io_mask *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/ioqueue.c */

struct ioqueue *ioq_create(int);
int ioq_destroy(struct ioqueue *);
int ioq_drain(struct ioqueue *);
int ioq_makeiov(struct ioqueue *, struct iovec *, int);
int ioq_peek(struct ioqueue *, char *, int);
int ioq_dequeue(struct ioqueue *, int);
int ioq_append(struct ioqueue *, char *, int);
int ioq_qsize(struct ioqueue *);
int ioq_gets(struct ioqueue *, char *, int);
int ioq_puts(struct ioqueue *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/lock.c */

int file_lock(int);
int file_unlock(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/mapdist.c */

int deltax(int, int);
int deltay(int, int);
int mapdist(int, int, int, int);
int mapdsq(int, int, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/minmax.c */

double dmax(double, double);
double dmin(double, double);
int max(int, int);
int min(int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/numstr.c */

char *numstr(char *, int);
char *effadv(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/onearg.c */

int onearg(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/parse.c */

int parse(char *, char **, char **, char *, char **);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/plur.c */

char *plur(int, char *, char *);
char *splur(int);
char *esplur(int);
char *iesplur(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/queue.c */

int insque(struct qelem *, struct qelem *);
int remque(struct qelem *);
int initque(struct qelem *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/round.c */

int round(int, int);
int ldround(double, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/same.c */

int same(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/scthash.c */

int scthash(int, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/send_mail.c */

int send_mail(char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/sendclient.c */

/*VARARGS*/
int sendclient(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/sendtext.c */

int sendtext(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/signal.c */

int blocksig(void);
int unblocksig(void);
char *signame(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/strscan.c */

int strscan(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/gen/vsprintf.c */

int vsprintf(char *, char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/constants.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/dir.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/file.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/item.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/land.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/misc.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/news.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/nsc.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/nuke.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/numnames.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/path.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/plane.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/product.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/sect.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/ship.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/global/treaty.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/lwp/arch.c */

void lwpInitContext(struct lwpProc *, void *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/lwp/lwp.c */

void lwpReschedule(void);
void lwpEntryPoint(void);
struct lwpProc *lwpCreate(int, void (*)(), int, int, char **, void *);
void lwpReady(struct lwpProc *);
void *lwpGetUD(struct lwpProc *);
void lwpSetUD(struct lwpProc *, char *);
void lwpYield(void);
void lwpExit(void);
void lwpTerminate(struct lwpProc *);
int lwpSetPriority(int);
struct lwpProc *lwpInitSystem(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/lwp/queue.c */

struct lwpProc *lwpGetFirst(struct lwpQueue *);
void lwpAddTail(struct lwpQueue *, struct lwpProc *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/lwp/sel.c */

void lwpSleepFd(int, int);
void lwpWakeupFd(struct lwpProc *);
void lwpSleepUntil(int);
void lwpSelect(int, char **);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/lwp/sem.c */

struct lwpSem *lwpCreateSem(int);
void lwpSignal(struct lwpSem *);
void lwpWait(struct lwpSem *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/player/accept.c */

int player_init(void);
struct player *player_new(int, struct sockaddr_in *);
struct player *player_delete(struct player *);
struct player *player_next(struct player *);
struct player *player_find_other(struct player *, unsigned char);
void player_accept(int, char **);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/player/dispatch.c */

int dispatch(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/player/empdis.c */

int getcommand(char *);
int explain(void);
int gamedown(void);
int daychange(int);
int getconstants(void);
int getminleft(int, int *, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/player/empmod.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/player/init_nats.c */

int init_nats(void);
int nat_cap(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/player/login.c */

void player_login(int, char **, void *);
int user_cmd(struct player *, int, char **);
int coun_cmd(struct player *, int, char **);
int pass_cmd(struct player *, int, char **);
int play_cmd(struct player *, int, char **);
int kill_cmd(struct player *, int, char **);
int list_cmd(struct player *, int, char **);
int quit_cmd(struct player *, int, char **);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/player/nat.c */

int natbyname(char *);
int natpass(int, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/player/player.c */

void player_main(struct player *);
int command(void);
int status(void);
int execute(void);
int show_motd(void);
int match_user(char *, char *, char *);
int quit(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/player/recvclient.c */

int recvclient(char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/aircombat.c */

int ac_encounter(struct qelem *, struct qelem *, short, short, char *, int, int);
int ac_intercept(struct qelem *, struct qelem *, struct qelem *, unsigned char, short, short);
int ac_airtoair(struct qelem *, struct qelem *, unsigned char);
int all_missiles(struct qelem *);
int ac_dog(struct plist *, struct plist *, int *, int *);
int ac_planedamage(struct plist *, unsigned char, int, unsigned char, int);
int ac_doflak(struct qelem *, struct sctstr *);
int ac_shipflak(struct qelem *, short, short);
int ac_landflak(struct qelem *, short, short);
int ac_fireflak(struct qelem *, unsigned char, int);
short rv_intercept(short, short, unsigned char);
int can_fly(int);
/*VARARGS*/
int PR(int);
int PRdate(unsigned char);
int do_evade(struct qelem *, struct qelem *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/askyn.c */

int confirm(char *);
int askyn(char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/aswplnsubs.c */

int have_looked(unsigned char, struct shiplook *);
int have_found(unsigned char, struct shiplook *);
int set_have_looked(unsigned char, struct shiplook *);
int set_have_found(unsigned char, struct shiplook *);
int print_found(struct shiplook *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/bigmap.c */

int setmap(char *, short, short, char, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/border.c */

int border(struct range *, char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/bsanct.c */

int bsanct(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/caploss.c */

int caploss(struct sctstr *, unsigned char, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/cnumb.c */

int cnumb(char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/comsub.c */

int commread(void);
int commwrite(void);
int commlock(void);
int communlock(void);
int commamt(unsigned char, int, float *);
int commset(unsigned char, int, int);
double multread(unsigned char, unsigned char);
int multset(unsigned char, double);
int commprice(int, float *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/control.c */

int military_control(struct sctstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/detonate.c */

int detonate(int, int, int, int, unsigned char);
int kaboom(int, int, int, unsigned char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/disloan.c */

int disloan(int, struct lonstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/distrea.c */

int distrea(int, struct trtstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/fileinit.c */

int ef_init(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/fortdef.c */

int fortdef(unsigned char, struct sctstr *, int, short, short);
int shipdef(unsigned char, unsigned char, int, short, short);
int sd(unsigned char, unsigned char, int, short, short, int, int, int);
int defdef(unsigned char, unsigned char, int, short, short);
int dd(unsigned char, unsigned char, int, short, short, int, int);
int shootback(unsigned char, struct sctstr *, int, short, short);
int sb(unsigned char, unsigned char, struct sctstr *, int, short, short, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/getbit.c */

int getbit(int, int, unsigned char *);
int setbit(int, int, unsigned char *);
int setbitmap(int, int, unsigned char *, int *);
int bitinit(struct nstr_sect *, unsigned char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/getele.c */

int getele(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/land.c */

int lnd_postread(int, char *);
int lnd_prewrite(int, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/landgun.c */

double landgun(int, int);
double seagun(int, int);
double landunitgun(int, int);
int landdef(int);
int seadef(int);
int landunitdef(int);
int shelldam(double, int);
int roundrange(double);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/list.c */

int shipsatxy(short, short, int, int);
int carriersatxy(short, short, int, int, unsigned char);
int unitsatxy(short, short, int, int);
int planesatxy(short, short, int, int);
int asw_shipsatxy(short, short, int, int, int, struct shiplook *);
int num_shipsatxy(short, short, int, int);
int islist(char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/lndsub.c */

int attack_val(struct lndstr *);
int defense_val(struct lndstr *);
int total_mil(struct lndstr *);
int take_casualty(struct llist *, int, int, int *, int, unsigned char);
int spyval(struct lndstr *);
int intelligence_report(int, struct lndstr *, int, char *);
int count_units(struct shpstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/missdef.c */

int missdef(struct shpstr *, unsigned char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/mission.c */

int interdict(int, int, int, char *);
int sub_interdict(int, int, int, char *);
int off_support(int, int, int, int);
int def_support(int, int, int, int);
int dosupport(struct genlist *, int, int, int, int);
int build_mission_list(struct genlist *, int, int, int);
int build_mission_list_type(struct genlist *, int, int, int, int);
int find_escorts(int, int, unsigned char, struct qelem *);
int perform_mission(int, int, int, struct qelem *, int, char *);
int cando(int, int);
char *nameofitem(char *, struct genitem *, int);
char *mission_short_name(int);
char *mission_name(int);
int show_mission(int, struct nstr_item *);
int oprange(struct genitem *, int, int *);
int mission_pln_sel(struct qelem *, int, int);
int mission_pln_arm(struct qelem *, int, int, int, struct ichrstr *, int, int, int *);
int mission_pln_equip(struct plist *, struct ichrstr *, int, char);
int find_airport(struct qelem *, int, int);
int add_airport(struct qelem *, int, int);
int divide(struct qelem *, struct qelem *, int, int);
int air_damage(struct qelem *, int, int, int, int, char *);
int air_defense(int, int, int, struct qelem *, struct qelem *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/move.c */

int move_ground(char *, struct sctstr *, struct sctstr *, double, double, char *, int (*)(), int, int *);
int move_map(char *, short, short, char *);
int fly_map(short, short);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/mtch.c */

int intmatch(int, int *, int);
int comtch(char *, struct comstr *, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/natarg.c */

int natarg(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/neigh.c */

int neigh(short, short, unsigned char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/nreport.c */

int nreport(unsigned char, int, unsigned char, int);
int filereport(int, int, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/nstr.c */

char *nstr_comp(struct nscstr *, int *, int, char *);
int encode(char *, int *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/nuke.c */

int nuk_postread(int, char *);
int nuk_prewrite(int, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/nxtitem.c */

int nxtitem(struct nstr_item *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/nxtsct.c */

int nxtsct(struct nstr_sect *, struct sctstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/paths.c */

int getdir(char *, char *, char *, char *);
int chkdir(char, int, int);
int direrr(char *, char *, char *);
char *getpath(char *, char *, short, short, int, int, int, int);
double mcost(struct sctstr *, int);
double fcost(struct sctstr *, unsigned char);
double ncost(struct sctstr *, unsigned char);
double pathtoxy(char *, short *, short *, double (*)());
int chkpath(unsigned char, char *, short, short);
int pathrange(short, short, char *, int, struct range *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/plane.c */

int pln_postread(int, char *);
int pln_prewrite(int, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/plnsub.c */

int pln_onewaymission(struct sctstr *, int *, int *);
int pln_newlanding(struct qelem *, short, short, int);
int pln_dropoff(struct qelem *, struct ichrstr *, short, short, char *, int);
int pln_sel(struct nstr_item *, struct qelem *, struct sctstr *, int, int, int, int);
int pln_arm(struct qelem *, int, struct ichrstr *, int, int, int *);
int pln_equip(struct plist *, struct ichrstr *, int, char);
int pln_put(struct qelem *);
int pln_removedupes(struct qelem *, struct qelem *);
int put_plane_on_ship(struct plnstr *, struct shpstr *);
int take_plane_off_ship(struct plnstr *, struct shpstr *);
int take_plane_off_land(struct plnstr *, struct lndstr *);
int can_be_on_ship(int, int);
int plane_sweep(struct qelem *, int, int);
int count_planes(struct shpstr *);
int count_land_planes(struct lndstr *);
int put_plane_on_land(struct plnstr *, struct lndstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/pr.c */

/*VARARGS*/
int pr(int);
int pr_id(int, char *);
int pr_hilite(char *);
int outid(int);
int prredir(char *);
int prexec(char *);
int prflush(char *);
int prprompt(int, int);
int showvers(int);
int prmptrd(char *, char *, int);
int prdate(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/radmap.c */

int radmap(int, int, int, int, double);
int radmapnopr(int, int, int, int, double);
int radmap2(int, int, int, int, double, int);
int deltx(struct range *, short);
int delty(struct range *, short);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/rej.c */

int setrel(unsigned char, unsigned char, int);
int setrej(unsigned char, unsigned char, int, int);
int tm_updatecheck(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/retreat.c */

int check_retreat_and_do_shipdamage(struct shpstr *, int);
int retreat_ship(struct shpstr *, char);
int retreat_ship1(struct shpstr *, char, int);
int findcondition(char);
int check_retreat_and_do_landdamage(struct lndstr *, int);
int retreat_land(struct lndstr *, char);
int retreat_land1(struct lndstr *, char, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/sarg.c */

int sarg_type(char *);
int sarg_xy(char *, short *, short *);
int sarg_getrange(char *, struct range *);
int sarg_area(char *, struct range *);
int sarg_range(char *, short *, short *, int *);
int sarg_list(char *, int *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/satmap.c */

int satmap(int, int, int, int, int);
int sathead(void);
int satdisp(struct sctstr *, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/scandir.c */


/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/sect.c */

int sct_postread(int, char *);
int sct_prewrite(int, char *);
int checksect(struct sctstr *);
int issector(char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/ship.c */

int shp_postread(int, char *);
int shp_prewrite(int, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/show.c */

int show_bridge(int);
int show_nuke_stats(int);
int show_nuke_build(int);
int show_nuke_capab(int);
int show_ship_build(int);
int show_ship_stats(int);
int show_ship_capab(int);
int show_plane_stats(int);
int show_plane_capab(int);
int show_plane_build(int);
int show_land_build(int);
int show_land_capab(int);
int show_land_stats(int);
int show_sect_build(void);
int show_sect_stats(void);
int show_sect_capab(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/snxtitem.c */

int snxtitem(struct nstr_item *, int, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/snxtsct.c */

int snxtsct(struct nstr_sect *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/supply.c */

int resupply_all(struct lndstr *);
int resupply_commod(struct lndstr *, int);
int supply_commod(int, int, int, int, int);
int try_supply_commod(int, int, int, int, int);
int s_commod(int, int, int, int, int, int);
char *itemname(int);
int at_minimum(struct lndstr *, int);
int get_minimum(struct lndstr *, int);
double supply_mob(int, int, double, double);
int has_supply(struct lndstr *);
int use_supply(struct lndstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/takeover.c */

int takeover(struct sctstr *, int);
int takeover_ship(struct shpstr *, unsigned char, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/trdsub.c */

char *trade_nameof(struct trdstr *, union trdgenstr *);
int trade_desc(struct trdstr *, union trdgenstr *);
int trade_getitem(struct trdstr *, union trdgenstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/trechk.c */

int trechk(unsigned char, unsigned char, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/whatitem.c */

struct ichrstr *whatitem(char *, char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/wire.c */

int typed_wire(unsigned char, unsigned char, char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/subs/wu.c */

/*VARARGS*/
int wu(int);
int typed_wu(unsigned char, unsigned char, char *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/age.c */

int age_levels(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/deliver.c */

int deliver(struct sctstr *, struct ichrstr *, int, int, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/distribute.c */

int dodistribute(struct sctstr *, int *, int, char *, double, double);
int assemble_dist_paths(char *(*)[32], double (*)[32], double (*)[32]);
int free_dist_paths(char *(*)[32]);
char *ReversePath(char *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/finish.c */

int finish_sects(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/human.c */

int grow_people(int *, int, double);
int infect_people(struct natstr *, int *, unsigned int, int);
int plague_people(struct natstr *, int *, int *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/land.c */

int prod_land(int, int, int);
int upd_land(struct lndstr *, int, int, struct natstr *, int);
int landrepair(struct lndstr *, int *, struct natstr *, int);
int feed_land(struct lndstr *, int *, int);
int plague_land(struct lndstr *, struct natstr *, int *, int *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/main.c */

void update_main(int, char **);
int do_prod(int, int, int, int *, int *, int *, int *, int *, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/mobility.c */

int mob_sect(int);
int mob_ship(int);
int mob_land(int);
int mob_plane(int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/move_sat.c */

int move_sat(struct plnstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/nat.c */

double logx(double, double);
double limit_level(double, int, int);
int prod_nat(int);
int share_incr(double *, double *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/nav_ship.c */

int swap(struct shpstr *);
int nav_ship(struct shpstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/nav_util.c */

char *nav_nameship(struct shpstr *, struct mchrstr *);
int check_nav(struct sctstr *);
int nav_chkdir(char, int, int);
int nav_shiprad(char *, struct shpstr *, int, int);
int load_it(struct shpstr *, struct sctstr *, int);
int unload_it(struct shpstr *);
int com_num(char *);
int auto_fuel_ship(struct shpstr *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/nxtitemp.c */

char *nxtitemp(struct nstr_item *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/nxtsctp.c */

struct sctstr *nxtsctp(struct nstr_sect *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/plane.c */

int prod_plane(int, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/populace.c */

double populace(struct natstr *, struct sctstr *, int *, int);
int starvation(struct sctstr *);
double total_work(struct sctstr *, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/prepare.c */

int prepare_sects(int);
int prep_update(struct sctstr *, int, struct natstr *, int *);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/produce.c */

int produce(struct natstr *, struct sctstr *, int *, int);
int materials_cost(struct pchrstr *, int *, int *);
int materials_charge(struct pchrstr *, int *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/removewants.c */

int update_removewants(void);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/revolt.c */

int revolt(struct sctstr *);
int guerrilla(struct sctstr *);
int take_casualties(struct sctstr *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/sail.c */

int sail_ship(unsigned char);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/sect.c */

int prod_sect(int);
int update(struct sctstr *, int, struct natstr *, int *);
int dodeliver(struct sctstr *, int *);
int upd_buildeff(struct sctstr *, int, int *);
int growfood(struct sctstr *, int *, int, int);
int enlist(int *, int);
int do_fallout(struct sctstr *, int);
int produce_sect(int, int, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/ship.c */

int prod_ship(int, int, int);
int upd_ship(struct shpstr *, int, int, struct natstr *, int);
int shiprepair(struct shpstr *, int *, struct natstr *, int);
int feed_ship(struct shpstr *, int *, int);

/* module: /net/midway/a/mr-frog/empire/CS3.4/lib/update/wu.c */

