.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject DISTRIBUTION
.in \w'distributeXX\0\0\0\0'u
.s1
.L "cutoff   "
List delivery thresholds
.L "deliver   "
Establish delivery routes for shells, ore, etc
.L "distribute * "
Establish distribution destination sector
.L "level * "
List distribution thresholds
.L "path   "
Show the distribution path of a sector
.L "route   "
Display delivery routes
.L "threshold * "
Set commodity distribution thresholds
.L "wipe   "
Remove all distribution thresholds
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
