.TH Introduction SUGGESTIONS
.NA Suggestions "Suggestions for enhancements to the game"
.LV Expert
.nf

	Whenever I think about new things for empire, I evaluate them in this
order:

		1) Is it fun?

	This is subjective, of course. The real question should be "Will the
majority of Empire players find this enjoyable?"

		2) Is is complicated?

	What sorts of new commands are needed? How will the player use the new
feature? Do new commands need to be added? How much will this change impact
the user?

		3) Is is code-able?

	How difficult is it to do? Does it involve minor changes, or a major
re-write? Many ideas have merit, but are prohibitively difficult to implement.

		4) Is it realistic?

	In general, realism is good, in that it makes the game more intuitive,
and easier for new players to learn.

	        5) Is it play-balanced?

	It is important that the delicate balance between offense and
defense not be tipped one way or the other.  For example, a stacking
limit for land units would tip the balance too far in favour of the
defender.  Or, allowing more than one ship to assault at a time would
tip the balance in favour of the attacker.

		6) Is it important?

	If the change involves adding detail to the game, is the detail 
important enough? Does the change go beyond the general level of Empire
abstraction? For example, a change to allow you to name each of your mil
would obviously be beyond Empire's general detail level. A command to name
ships is stretching it.
.fi
.SA "Introduction"
