.TH Command EXECUTE
.NA execute "Execute a batch file"
.LV Expert
.SY "execute <INPUT FILE>"
This command reads Empire commands from <INPUT FILE> and executes them.
.s1
Note: Not all clients support the execute protocol.
.SA "Playing"
