.TH Introduction "How to Play Empire"
.NA HowToPlayEmpire "How to play Empire"
.nf
ok, so you think you might want to play empire?

What is empire:

	empire is an military/economic simulation of make-believe
	countries in a made-up world.   In this version, the 
	military part is emphasized and the economic part is 
	still there but as prerequisite to a working military.

	each player runs a country.  there is no formal objective, 
	though most players set goals for themselves..  highest
	tech, most populous, largest, etc..  However, it is
	quite possible to lose. 

	the world is divided into sectors, the sectors are 
	laid out in a hexmap of 128x128.  Each sector has
	a type.  (see Sector-types)

time:

	the game goes on even when you don't play; if you ignore
	your country it gradually collapses.  There are limits
	on how much time you can play and how many commands
	you can give.

turns:
	
	there are no turns..  you give commands that change
	the configuration of your country (ie, move people
	around, re-designate sector types etc..) and the
	at regular intervals (whether you did anything or not)
	the world updates.   This happens ever x hours where
	x is usually between two and eight.  During an
	update, people are born, people starve, items are
	produced and consumed, etc.

length of games:

	one to four months.  expect to spend one to four hours
	a day playing.

what to read next:
	
	info Sector-types, capitol, designate, move, map, census and deliver

what to do at the beginning:

	"break" sanctuary, exposing your people to the
	ravages of time & the elements. You can't do
	anything until you abandon your protection.

	explore and try to build your population.

	change the name of your country witht the "change"
	command.  note: it uses lots of BTU's so you won't
	be able to play for a while after this, unless you
	do it before you "break", when it is free.

	read info Products, build, tech, education, and realm.

	try to make some cm's.  This requires building a mine
	(on an iron-rich sector), having it deliver to a cm 
	factory (either a j (light construction materials), or
	a k (heavy construction materials). Be sure to have an
	agribusiness supply food to all your sectors! (Although 
	the food you are given to start with will sustain you
	for a fair number of updates. Read info version, and run
	the "version" command to see how much your people will
	eat.
	
tools to help play:

	ve, or visual empire helps examine your
	country.   Note: ve is not easy to use, and
	if you have time paper is much better. 
	ve should be avail from the same place you got
	your empire client.
.fi
.SA "Overview, Introduction"
