.TH Concept "Sector ownership"
.NA Sector-ownership "Sector ownership"
.LV Basic
.s1
In order to own a sector, you must have at least one of the following
present in the sector:

.NF
1) mil
2) a land unit
3) non-captured civilians
.FI

.s1
If at any time you do not have at least one of those 3 things in a sector,
you will lose control of it.
If you are not the old owner at the time you lose the sector,
owner, it will revert to the old owner, otherwise it will
revert to the deity, country 0.
If there are no people at all in the sector, it will revert to the deity.
.s1
Note that this means that if you attack a sector and do not move in,
you will not gain possession of it. If there are civilians in the sector,
the sector will revert back to the original owner. If there are no civilians
in the sector (and no mil or units, because you just killed them), the sector
will revert back to the deity.
.s1
Similarly, if you abandon a sector, it'll revert immediately.
.s1
.SA "attack, Sectors, Occupation"
