.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject MAPS
.in \w'bestdistpathXX\0\0\0\0'u
.s1
.L "bdes   "
Manually change your bmap
.L "bestdistpath   "
Show the best distribution path from one sector to another
.L "bestpath   "
Show the best path from one sector to another
.L "bmap * "
Big map of all your worldly knowledge
.L "lmap   "
Map around a land unit
.L "map * "
Generate a map showing sector types, seas, etc
.L "origin   "
Change the origin of your country's coordinate system
.L "pmap   "
Get a map around a plane
.L "realm * "
Print out or modify one of your \*Qrealms\*U
.L "sect   "
Show only sectors owned by you in map form
.L "sharebmap   "
Share parts of your bmap with another country
.L "smap * "
Get a map around a ship
.L "survey   "
Show distributions in map form
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
