.TH Command SYNC
.NA sync "Synchronize the client database with the server"
.LV Expert
.SY "sync version"
Send information about the server aversion and C_SYNC version.
.SY "sync sum"
Send a checksum of the edb (Empire DataBase) structure.
.SY "sync read [yes|no]"
Read the C_SYNC messages your country received while you weren't logged in.
.SY "sync define"
Send a description of all data structures that the server can send the
client in the form of C_SYNC messages.
.SY "sync class  <sector|ship|land|plane|nuke|item|product|all>"
Send a list of all game constants (this corresponds to the 'version'
and 'show' command in the game).
.SY "sync object <sector|ship|land|plane|nuke|nation|bmap|all> <SECTS|SHIPS|UNITS|PLANES|NUKES>"
Send the client data about the objects requested (this corresponds to
the 'dump', 'ship', 'car', 'land', 'lcar', 'plane', 'nuke', 'nation',
and 'bmap' commands).
.s1
The sync command is used to send game data from the server to the
client.  It will only work if you have typed 'toggle sync on'.
.s1
For more details about how to use the 'sync' command, see the C_SYNC
RFC (located in the Empire archives in the deity/docs directory) or
the documentation that comes with the EmpireToolkit.
.SA "toggle, Clients, Communication"
