#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/commands/brea.c,v 2.0 1995/01/25 19:23:25 empire Exp $";
#endif /* not lint */

/*
 * brea.c
 *
 * break out of sanctuary
 *
 * Jeff Wallace, 1989
 */

#include "misc.h"
#include "player.h"
#include "file.h"
#include "nat.h"

brea()
{
	struct	natstr *natp;

	natp = getnatp(player->cnum);
	if ((natp->nat_stat & STAT_SANCT) == 0) {
		pr("You aren't in sanctuary!\n");
		return RET_SYN;
	}
	bsanct();
	natp->nat_stat &= ~STAT_SANCT;
	natp->nat_stat |= STAT_NORM;
	putnat(natp);
	player->nstat |= NORM;
	return RET_OK;
}
