.TH Server OPTIONS
.NA Options "Server options"
.LV Expert
.nf
The following options are from KSU code:

SHOWPLANE:	planes on ships up for trade are shown
PINPOINT(etc):	Missile exist which target ships instead of sectors
SAIL:		another wait to automatically move ships (may also be buggy)
NUKEFAIL(etc):	nukes on missiles that explode in launching may detonate
SHIPNAMES:	ships may be named
DEMANDUPDATE:	updates may be allowed on player demand
UPDATESC(etc):	updates can be controlled by the 'hours' file. NITP

The following options were introduced in the Chainsaw server:

EASY_BRIDGES:	bridges can be built from any sector
SUPER_BARS:	gold bars aren't destroyed by shelling or bombing
ALL_BLEED:	you get tech bleed from all countries, not just allies
DRNUKE:		research is required to make nukes
SLOW_WAR:	War declaring takes time. No land attacks unless at war.
SNEAK_ATTACK:	If SLOW_WAR, allows you to pay money and sneak one attack.
NOMOBCOST:	ships pay 0 mob to fire. Subs pay 1/2 a sect's movement cost
TRADESHIPS:	you can build/nav/scuttle trade ships to make money
FUEL:		ships need fuel to gain mobility
RES_POP:	Research affects max sector population.
NOFOOD		No food is required.
BLITZ:		Turns NOFOOD option on and players get infinite BTU's.
NONUKES:	No nuclear weapons
NEWPOWER:	New power formula.  See "info power".
NO_PLAGUE:	Plague is disabled.
NEW_STARVE:	UW's starve, then civs, then mil
NEW_WORK:	Work is changed in proportion to the # of civs moved
GRAB_THINGS:	Units will grab things they need to build
NEUTRON:	Enables neutron bombs
FALLOUT:	Sectors are damaged by radiation for a few updates after blast

The following options were introduced in the Empire2 Server:

HIDDEN:		Hides information about countries you haven't contacted
LOSE_CONTACT:	In HIDDEN, lose contact after a few updates
ORBIT:		Satellites can orbit the planet
BIG_CITY:	'c' sectors cost $, lcm, hcm to build and hold 10x civs
INTERDICT_ATT	Interdict units & mil as they move in after an attack
.fi

.SA "Hidden, Server"
