.TH Command TERRITORY
.NA territory "Assign various sectors to a specific territory"
.LV Expert
.SY "territory <SECTS> <NUMBER>"
In Empire, sectors may be given a territory id number.
This number may be used in conditional statements as in:
.EX census # ?territory=27
The program will then give you a census report for all the
sectors that have been assigned the territory number \*Q27\*U.
.s1
In this sense it is essentially an extended \*Qrealm\*U.
However, you are not limited to rectangular regions and you have 
99 values to choose from.
.s1
Some possible uses include;
all sectors distributing to a particular sector;
all coastal sectors;
all sectors that have armed missiles in them.
And probably thousands that I haven't thought of. ;-)
.s1
To \*Qunset\*U a territory, set its value to zero.
.s1
.SA "realm, distribute, Sectors"
