.TH Command DISABLE
.NA disable "Disable Updates"
.LV Expert
.SY "disable"
No updates will fire if you disable them.  "UPDATES ARE DISABLED" will
show up in the output of the "update" command.
.SA "update, enable, Deity"
