.TH Command EDIT
.NA edit "Change stats of country, ship, land unit, or plane"
.LV Expert
.SY "edit <country|unit|ship|plane|nuke>"
Once you specify what you want to edit, the server will tell you what
to do.  Hit return to get out of the prompter.
.SA "setsector, setresource, give, Deity"
