/*
 * item.h
 *
 * things having to do with item characteristics
 *
 * from PSL Empire, 1985
 * $Revision: 2.0 $ $Date: 1995/07/27 05:29:42 $
 */

#ifndef _ITEM_H_
#define _ITEM_H_

#define	NUMPKG	4		/* number of different kinds of packaging */

struct	ichrstr	{
	int	i_mnem;		/* usually the initial letter */
	int	i_vtype;	/* var type */
	int	i_value;	/* mortgage value */
	int	i_sell;		/* can this be sold? */
	int	i_lbs;		/* how hard to move */
	int	i_pkg[NUMPKG];	/* units for reg, ware, urb, bank */
	s_char	*i_name;	/* full name of item */
};

/* variables using this structure */

extern  struct ichrstr ichr[];
extern	int maxitem;

/* procedures using/returning this struct */

extern	struct ichrstr *whatitem();

extern	int itm_maxno;

#endif /* _ITEM_H_ */
