.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject DETECTION
.in \w'coastwatchXX\0\0\0\0'u
.s1
.L "coastwatch * "
Check from sectors for nearby ships
.L "llookout * "
Check from units for other units, planes and/or sector types
.L "lradar   "
Use a radar unit's radar
.L "radar * "
Perform radar scan from ship or sector
.L "recon   "
Use planes to take a look around
.L "satellite   "
Download data from a reconnaissance satellite
.L "skywatch   "
Check from sectors for nearby satellites
.L "sonar * "
Use sonar to look for ships
.L "spy * "
Snoop on adjacent enemy sectors
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
