/*
 * deity.h
 *
 * things associated with deity ownership
 *
 * $Revision: 2.0 $ $Date: 1995/07/27 05:27:40 $
 */

#ifndef _DEITY_H_
#define _DEITY_H_

extern	s_char *privname;
extern	s_char *privlog;
extern	int privuid;

#endif /* _DEITY_H_ */
