
#ifndef _RETREAT_H_
#define _RETREAT_H_

#define	MAX_RETREAT	2	/* Max number of sectors you can retreat */
#ifndef RET_LEN
#define	RET_LEN		10
#endif

/* Retreat conditions */
#define	RET_GROUP	1	/* Whole group retreats */
#define	RET_INJURED	2	/* Retreat when damaged at all */
#define	RET_TORPED	4	/* Retreat when torped */
#define	RET_SONARED	8	/* Retreat when sonared */
#define	RET_HELPLESS	16	/* Retreat when fired upon from beyond range */
#define	RET_BOMBED	32	/* Retreat when bombed */
#define	RET_DCHRGED	64	/* Retreat when depth-charged */
#define	RET_BOARDED	128	/* Retreat when unsuccessfully boarded */

#endif _RETREAT_H_
