.TH Command READ
.NA read "Read your telegrams"
.LV Basic
.SY "read"
The read command is used to read the telegrams sent you
by other countries and by the game,
(e.g. when you make a sale or are attacked).
.sp
When telegrams arrive you are informed with:
.NF
\*QYou have a new telegram waiting ...\*U   if there is just one new one, or
\*QYou have ten new telegrams waiting ...\*U   if there are ten of them, or
\*QYou have several new telegrams waiting ...\*U   if there are very many.
.FI
After reading all your telegrams you may discard them by answering \*Qyes\*U to
the question posed.  If you answer \*Qno\*U the telegrams will remain
pending but you will not be reminded of them.
.s1
This command reads only
telegrams & bulletins, use the 'wire' command to read announcements.
.s1
.SA "toggle, telegram, wire, flash, Communication"
