.TH Command ORIGIN
.NA origin "Change the origin of your country's coordinate system"
.LV Expert
.SY "origin <SECTOR>"
This command changes the origin of your coordinate system
(where 0,0 is located.)
.s1
This command does not change the location of your nation's capital,
though its coordinates, like the coordinates of all other sectors,
will be different after using the origin command.
.s1
Your \*Qrealms\*U will be automatically recalculated
to point to the same area on the map.
.s1
.SA "capital, Maps"
