#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emp2/client/handle.c,v 1.1 1994/11/30 22:51:52 empire Exp $";
#endif /* not lint */

/*
 * handle.c
 *
 * interrupt handler now just sends a message
 *
 * Dave Pare, 1989
 */

int
handleintr(s)
	int	s;
{
	extern	int interrupt;

	if (interrupt) {
		/* tacky, but it works */
		if (write(s, "\naborted\n", 1+7+1) <= 0)
			return 0;
		interrupt = 0;
	}
	return 1;
}
