static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/global/treaty.c,v 2.0 1995/07/27 05:34:36 empire Exp $";

/*
 * treaty.c
 *
 * treaty clause characteristics -- one entry
 * per possible treaty clause.
 * 
 */

#include "misc.h"
#include "treaty.h"

struct  tchrstr tchr[]  = {
	LNDATT,	"no attacks on any land units",
	SEAATT,	"no attacks on any ships",
	SEAFIR,	"no shelling any ships",
	LANATT,	"no sector attacks",
	LANFIR,	"no shelling any land",
	NEWSHP,	"no building ships",
	NEWNUK,	"no new nuclear weapons",
	NEWPLN,	"no building planes",
	TRTENL,	"no enlistment",
	0,      0,
};

int	trt_maxno   = (sizeof(tchr) / sizeof(struct tchrstr)) - 1;
