/*
 * xy.h
 *
 * constants having to do with locations
 *
 * $Revision: 2.0 $ $Date: 1995/07/27 05:29:42 $
 */

#ifndef _XY_H_
#define _XY_H_

struct range {
	coord lx;	/* low-range x,y */
	coord ly;
	coord hx;	/* high-range x,y */
	coord hy;
	int width;	/* range width, height */
	int height;
};

extern	s_char *ownxy();
extern	s_char *xyas();
extern	s_char *xyfmt();

coord	xnorm(), ynorm();
coord	xabs(), yabs();
coord	xrel(), yrel();

#endif /* _XY_H_ */

