/* Generated automatically from gamesdef.h.in by configure. */
/*
 * gamesdef.h
 *
 * Paths, and global defines.
 * Perhaps these should be in misc.h
 * 
 * $Revision: 2.1 $ $Date: 1995/06/16 16:29:37 $
 */

/* EMPPATH() must agree with GAMEDIR GNUmakefile variable */

/* both of these below are actually K&R. */
#ifdef linux
#define EMPPATH(xyz)    "/usr/brule/guest/empire/empire/test/" #xyz /* Proper ANSI - works under linux */
#else
#define EMPPATH(xyz)   "/usr/brule/guest/empire/empire/test/xyz" 
#endif

#define	PRVNAM	"Ken Huisman"
#define	PRVLOG	"ken@rr.ualberta.ca"
#define GET_SOURCE "using:\nftp://ftp.empire.net/pub/empire/deity/server or\nhttp://www.empire.net/~children/"
#define EMP_PORT "7777"

