/*
 * user.h
 *
 * Dave Pare, 1986
 * $Revision: 2.0 $ $Date: 1995/07/27 05:29:42 $
 */

#ifndef _USER_H_
#define _USER_H_

#include "queue.h"

struct user {
	struct qelem queue;
	struct iop *u_iop;
	int u_cnum;
	int u_pid;
};

/*
 * lock commandsx
 */
#define L_UNLOCK	bit(0)		/* command to unlock */
#define	L_LOCK		bit(1)		/* command to lock */
#define L_NOLOCK	bit(3)		/* allow no new locks */

#endif /* _USER_H_ */
