.TH Concept "Plane Types"
.NA Plane-types "Description of different kinds of planes"
.LV Basic
The general plane types currently available in Empire are:
.s1
.NF
fighter  A general offense/defense plane. Historical examples include
         the FE.2B, the Sopwith Snipe & Camel, the Nieuport V-XVII, the
         Spad, and the Fokker planes. From WWII are the Me-109, the
         FW-190, the English Spitfire & Hurricane, the Japanese Zero,
         the American P-39, P-40, P-38, and the Soviet Yak series.
         Later planes include the Me-262, the Gloster Meteor, P-80,
         Mig-15. Korean War vintage planes are the F-87 Sabre, F-100
         SuperSabre, and the Mig-17. Vietnam Era planes are the F-4 &
         Mig-21. Later, NATO & WP models include the F-16 & F-15 and the
         Mig-23, 25, and 29.

         The main points of similarity are: 1 or 2 high performance
         engines, a single pilot, and plenty of guns/missiles. Duties
         include patrol/interception, escort, and light bombing.

escort   These are planes optimized for escorting, with superior range,
         sometimes at the expense of fighting capacity. Examples are
         the Me-110 & the P-51. Note that this type is relatively rare,
         as long range heavy bombing was rare.

naval
fighter  These planes all sacrifice range and/or fighting power in order
         to fit on a carrier and carry the gear necessary to operate
         from one. Examples are the series of Short biplanes built in
         Britain, the Sopwith Baby & Cuckoo, the Gloster Gladiator, the
         American Wildcat & Corsair, versions of the Japanese Zero, the
         F8 Corsair, the F-4, F-14, and F-18. Many of the planes were
         multi-role, due to the relatively small plane capacity of their
         carriers. They were almost always inferior in performance to
         land fighters. Many of them carry dual engines.

light
bomber   These planes are tactical bombers, suited for strafing, combat
         support, etc. These range from the first trench bombers, such as
         the Junkers J-I and the Sopwith Snark & Dolphin, the Ju-87
         Stuka, the American P-47, various ground-attack versions of the
         Yaks, the Japanese Val and Kate, the British Typhoon, and many
         others.  Modern versions are the A-3 SkyWarrior, the A-4
         Skyhawk, the A-6 Intruder, the Su-22 Frogfoot, the Su-27, and
         various British models. A modern and most effective example is
         the A-10

         The common factors are maneuverability, the ability to take
         damage and still fly, and the ability to hit targets precisely.
         (Either through low-speed bombing, dive-bombing, or rocket or
         guided bombs/missiles) Their performance against fighters of
         any sort is poor, with few exceptions (notably the P-47, which
         was designed as a fighter, and used as a ground-attack plane
         due to its toughness) Many are naval, or have naval versions,
         since the requirements of a naval plane do not affect them as
         greatly as fighters.

heavy
bomber   These planes are build for long range and great load-carrying
         ability, and the ability to defend themselves against fighters.
         (Although that never worked more than middling well) Examples
         are the Handley-Paige bombers of WWI (especially the O/400), the
         German Gothas and Giants, the B-17 Flying Fortress, the B-24
         Liberator, the B-29 SuperFortress, the Avro Lancaster, the Short
         Sterling, and the Vickers Wellington, as well as the more modern
         B-36, B-47, B-50, B-52, B-1, and the Soviet Ant-4, Tu-20 Bear,
         Tu-2? Backfire, and others.

         The common factors are the extreme range, the ability to carry
         several tons of bombs, the wide range of defensive armament, and
         four engines.

medium
bombers  These were basically an intermediate stage between the light &
         heavy bomber, and were used for both purposes. Examples are the
         He-111, the Do-17, the B-25 Mitchell, B-26 Marauder, the A-20
         Havoc, the Avro Manchester, Armstrong Whitworth Whitely, the
         Russian Il-4 & I-15, and the Japanese Betty & Sally.

         These planes were essentially compromises, and were phased out
         as time went on. They could not bomb as precisely as a light
         bomber, nor as heavily as a heavy bomber.
      
transports

         Initially, these were basically similar to civilian airliners.
         They could carry supplies or troops. (In Norway, the Germans
         captured airports and flew in troops) Later, they were used for
         paratroop landings. Eventually paratrooping became too dangerous
         for these planes (with the introduction of SAMs) and they were
         replaced by helicopter assault, with the transports going back
         to carrying supplies and equipment.

transport
helicopters

         These were made to transport assault troops. They also carry
         supplies & wounded, but their main duty was to deliver troops
         with greater precision, rapidity, safety, and cohesion than was
         possible with paratrooping. (They were also to replace the
         landing craft, as the Marines looked at the odds of an invasion
         fleet standing up to nukes)

attack
helicopters

         These supplement the light bombers, and specialize in the very
         precise application of firepower, as well as evading
         interception, by use of terrain.

recon
planes &
satellites

         These provide precise information about enemy troop dispositions
         and movements. The first recon planes had no protection. Then,
         it was attempted to make them un-interceptable. This was done by
         simply being faster than anything the enemy had, such as the
         stripped down British Hurricanes, US P-38's & P-51's, or German
         FW-190's or Blitz-Bombers. Later, emphasis shifter to also being
         able to fly higher, as with the U-2 & SR-71. These planes are
         largely superseded by satellites now (for good or ill).

ssm's
& icbm's

         The first ssm's were used as strategic harassing weapons, and
         were almost useless. (German V-1 & V-2) There were also combat
         rockets, such as the Russian Katayusha's and the German
         Nebelwerfers, but these were essentially similar to artillery.
         The first true SSM's were the Russian missiles in the 1950's,
         such as the Frog. They were intended to deliver nuclear or
         chemical warheads at medium ranges, and to be un-interceptable.
         Later missiles increase payload & range.

         However, since we've artificially restricted the blast effects
         of nuclear weapons, I am merging these in with tactical
         missiles. (no need for an icbm unless you've got big nukes)

marine
missiles
         These are modern smart-missiles. They are naval weapons, such
         as the Harpoon, Penguin, Exocet. They are accurate missiles which
         may be launched at ships.

sam's
         The first sams were nuclear-tipped, and intended to break up
         large attacking bomber forces. Later, they were made smaller
         and more accurate, and were intended to hit single targets
         at any speed or altitude.

abm's    These are to shoot down missiles, and are mostly fantasy.

asw
planes   These are either long-range bomber type aircraft, with some
         sort of equipment for locating & killing submarines, or also
         helicopters, able to fly from most naval vessels.
.FI
.s1
These plane types differ in their fundamental capabilities;
some can fly bombing missions,
other carry cargo, others exist to shoot down other planes.
Missiles are special;
they are planes which fly one-way missions
and cannot be shot down by opposing planes.
.s1
The technology level at which the plane was built is very important.
The same model plane built at a higher tech level
will outperform the planes built at a lower tech level.
.s1
The particular planes available and their attributes
are given by the show command.
The fields given in the output are as follows.
For building:
.sp 1
.in \w'avail\0\0'u
.L lcm
the amount of lcm to build the unit,
.L hcm
the amount of hcm to build the unit,
.L crew
the number of military this plane has as crew
.L avail
the amount of avail used to build this plane
.L tech
minimum tech level to build this unit,
.L $
cost of the unit in dollars,
.s1
.in \\n(in
For the stats report the fields are:
.s1
.in \w'stealth\0\0'u
.L acc
bomb accuracy, low is best; a 0 accuracy implies no ability.
.L load
bomb load/cargo capacity.
.L att
air-to-air combat attack rating (reduced by low eff, can't go below 1/2 of base).
.L def
air-to-air combat defense rating (reduced by low eff, can't go below 1/2 of base).
.L ran
base range (in sectors).
.L fuel
amount of fuel used each trip.
.L stealth
the percentage chance this plane has of evading detection
.in \\n(in
.s1
The abilities are given as a set of attributes for each plane.
These include:
.s1
.in \w'intercept\0\0'u
.L tactical
Pinpoint bombing ability.  Can be put on interdiction and support
missions.  Tactical missiles may be launched at sectors unless they
have "marine" ability in which case they may only be fired at ships.
.L bomber
strategic bombing ability
.L intercept
Interception and escort ability.  May be put on escort or air defense missions.
.L cargo
cargo-carrying ability
.L VTOL
vertical take-off ability -- no need to use airports
.L missile
missile -- one shot, can be launched (see info launch).  "marine"
missiles may only be fired at ships, "tactical" missiles which don't
have "marine" capability may only be fired at sectors.
.L light
light, can land on carriers or be carried on a submarine
.L spy
spy ability, for recon missions (see info recon, info bomb, info satellite)
.L image
full imaging capability - satellites with this ability show much more
(see info satellite)
.L satellite
a satellite - stays in orbit until shot down
.L stealth
a stealth plane - has a chance of not triggering intercepts
.L SDI
Intercepts tactical missiles.
.L half-stealth
a stealth plane - has a smaller chance of not triggering intercepts
.L x-light
xtra-light, can be carried and used on any ship or land unit with a non-zero
xl capacity. (see info Ship-types)
.L helo
ship-helicopter, can be carried and used on any ship with a non-zero
hl capacity. (see info Ship-types)
.L ASW
Has ASW (anti-submarine warfare) ability. May use sonar & bomb subs.
.L para
may be used to paratroop
.L escort
Escort ability only.  May be put on escort missions.
.L mine
Can lay mines (see info mine).
.L sweep
Can sweep mines (see info sweep).
.L marine
Missiles with this ability may only be launched at ships.
.in \\n(in
.s1
Each plane has a stealth rating. The
stealth rating of a group of planes is that of the plane with the LOWEST
rating.
.sp 1
As an example of the output
.EX show plane build
.NF
                          lcm hcm crew avail tech  $
Zeppelin                    6   2   3     6   70 $1000
f1  fighter 1               8   2   1     7   90 $400
lb1 lt bomber 1            10   3   1     9  100 $550
nf1 naval fighter 1         8   2   1     7  100 $500
hb1 hvy bomber 1           20   6   2    17  110 $1100
as1 anti-sub plane 1       10   3   2     9  110 $550
f2  fighter 2               9   3   1     8  150 $600
es  escort                  9   3   1     8  150 $700
.FI
.s1
.EX show plane stats
.NF
                          acc load att def ran fuel stlth
Zeppelin                   60    2   0  -3  15    2    0%
f1  fighter 1              90    1   3   2   7    1    0%
lb1 lt bomber 1            50    2   1   2   7    1    0%
nf1 naval fighter 1        80    1   2   2   7    1    0%
hb1 hvy bomber 1           90    5   1   3  15    2    0%
as1 anti-sub plane 1       85    2   1   2  15    2    0%
f2  fighter 2              60    1   6   4   9    1    0%
es  escort                 60    1   4   5  15    2    0%
.FI
.s1
.EX show plane cap
.NF
                          capabilities
Zeppelin                  tactical cargo VTOL spy
f1  fighter 1             tactical intercept VTOL
lb1 lt bomber 1           bomber tactical VTOL
nf1 naval fighter 1       tactical intercept light
hb1 hvy bomber 1          bomber
as1 anti-sub plane 1      tactical ASW
f2  fighter 2             tactical intercept
es  escort                tactical escort
.FI
.SA "fly, build, show, Planes"
