/* $XConsortium: Graph.h,v 1.2 88/10/25 17:22:09 swick Exp $ */
/* Copyright	Massachusetts Institute of Technology	1987, 1988 */

/* Programmed by Dan Bennett                                       */

#ifndef _Graph_h
#define _Graph_h

/****************************************************************
 *
 * Graph widget
 *
 ****************************************************************/

/* Resources:

 Name		     Class		RepType		Default Value
 ----		     -----		-------		-------------
 background	     Background		Pixel		XtDefaultBackground
 border		     BorderColor	Pixel		XtDefaultForeground
 borderWidth	     BorderWidth	Dimension	1
 destroyCallback     Callback		Pointer		NULL
 height		     Height		Dimension	0
 mappedWhenManaged   MappedWhenManaged	Boolean		True
 sensitive	     Sensitive		Boolean		True
 width		     Width		Dimension	0
 x		     Position		Position	0
 y		     Position		Position	0
 font                Font               XFontStruct*    XtDefaultFont
 foreground          Foreground         Pixel           XtDefaultForeground
 buisy               Buisy              Callback        NULL
 response            Response           Callback        NULL
*/

/* define any special resource names here that are not in <X11/StringDefs.h> */

#ifndef XtNforeground
#define XtNforeground             "foreground"
#define XtNbackground             "background"
#endif

#ifndef XtCForeground
#define XtCForeground             "Foreground"
#define XtCBackground             "Background"
#endif

extern void displaypicture();

/* declare specific GraphWidget class and instance datatypes */

typedef struct _GraphClassRec*	GraphWidgetClass;
typedef struct _GraphRec*		GraphWidget;

/* declare the class constant */

extern WidgetClass graphWidgetClass;

#define even(x) ((x&1) != 1 )

#endif  _Graph_h
