
/* this stuff ought to be somewhere general... */
#ifndef _PROTOTYPE_H_
#define _PROTOTYPE_H_
#if defined(__cplusplus) || (defined(__STDC__) &&__STDC__)
#define _PROTO(x)       x
#else
#define _PROTO(x)       ()
#define const
#define volatile
#endif
#endif /* _PROTOTYPE_H_ */
