.TH Introduction Rules
.NA Rules "The rules for playing Empire"
.LV Basic
.s1
One player, one country.
You man NEVER use any country other than your own.
It is ok for two people to play one country
but it is NEVER ok for one person to play two countries.
If you are caught doing this, your countries will be removed
from the game.
In addition, your registrations for future games may be
declined.
DON'T DO IT.
.s1
Ok, but what do I do when I'm away?
.s1
.in +.5i
1) you may turn over your country to someone who has never
played anyone else's country in that game.
You MUST tell the deity if you do this
as he/she/it will be watching who is playing what.
.br
2) you may turn your country over to the deity.
.in -.5i
.s1
Bugs: if you find a bug,
you are REQUIRED to report it to the deity.
I will not let other people know about the bug 
and in most cases, you may exploit it until it is fixed.
Punishment for use without telling: at least $50,000 or
getting your country removed from the game. 
.s1
Denial-of-service attacks are forbidden.  Any form of attack that
prevents a player from connecting to the server is against the rules.
This includes letter bombing.
.s1
.SA "Introduction"
