/*
 * budg.h
 *
 * Budget related definitions
 *
 * Ville Virrankoski, 1995
 */

void fill_update_array();
int *get_wp();
int gt_bg_nmbr();
void pt_bg_nmbr();
void get_materials();

extern int mil_dbl_pay;
