.TH Command COLLECT
.NA collect "Foreclose an overdue loan"
.LV Expert
.SY "collect <LOAN>"
The collect command is the loan-shark's delight!
Through the collect command overdue loans can be \*Qcleared up\*U.
.s1
If you should find that you have a problem debtor who refuses
to pay up on your kind loan you can always seize one or more
of his/her sectors.
Perhaps the mere threat of a collection on
someone's capital may do the trick!
.s1
To settle up accounts on overdue loan #9 you would type:
.EX collect 9
The program would then ask which sector you would like to claim
as just and rightful compensation for the outstanding debt.
.NF
What sector do you wish to confiscate?
.FI
To which you reply with the coordinates of a sector owned by your
debtor to which you are adjacent.
The program then paws over the sector and assesses its value:
.NF
That sector (and its contents) is valued at $2345.00
.FI
If the amount you are owed exceeds this amount the sector
becomes yours!
If the value of the sector is close enough to the
amount you are owed the debt is considered to be repaid.
.s1
.SA "consider, ledger, offer, Obsolete"
