/*
 * match.h
 *
 * for use with PSL's string compare matcher
 *
 * $Revision: 2.0 $ $Date: 1995/07/27 05:29:42 $
 */

#ifndef _MATCH_H_
#define _MATCH_H_

/* returned by stmtch() */
#define M_NOTUNIQUE	-2
#define M_NOTFOUND	-1
/*#define M_INDEX [0...N-1] */

/* returned by mineq() */
#define ME_MISMATCH	0
#define ME_PARTIAL	1
#define ME_EXACT	2

#endif /* _MATCH_H_ */
