#
# See if there is a deity tele of the form:
#
# > BULLETIN from <DEITY> <DATE>
# <ENEMY> lost <#> troops taking <SECTOR>
#
# in the input. If so, print Attack. If not, do nothing.
#

BEGIN{
	bulletin = 0
}

/^>/{
#
# This checks everything beginning with a >, 
# which is all teles. If current tele is a bulletin,
# set the bulletin flag, otherwise turn it off.
#
	if ($2 == "BULLETIN")
		bulletin = 1;
	else
		bulletin = 0;
}

/troops taking/{

#
# If this was a deity bulletin, and not a player trying
# to spoof us, print the attack message.
#
	if (bulletin == 1)
		print $0
}
