.TH Command CHANGE
.NA change "Change country name or representative's name"
.LV Expert
.SY "change [country | representative] Newname"
This simple command enables you
to rename your country, or your representative name
associated with your country.
.s1
.s1
COUNTRY NAME
.s1
.EX change country Hodedo
This will change the name of your country to \*QHodedo\*U.
In order to change your name you must pay 10% of your cash on
hand and 254 btus.
These expenses reflect the trouble of changing all the national
emblems, stationary, flags, etc.
.s1
.s1
REPRESENTATIVE NAME
.s1
.EX change representative ho
Your representative's name will now be \*Qho\*U.
Note that the new name you
type WILL print out, (in case of a typing error).
As a consequence
you won't want to do this while your arch-enemy is watching.
.s1
.SA "nation, Nation"
