.TH Command MQUOTA
.NA mquota "Change the mobility quota of a ship with SAIL orders"
.LV Expert
.SY "mquota <SHIP/FLEET> <NUMBER>"
You use the \*Qmquota\*U command to limit the amount of mobility
that a ship a sailing path will use during an update.
.s1
.SA "sail, unsail, follow, Ships"
