.TH Command LRANGE
.NA lrange "Edit the reaction range of a unit"
.LV Expert
.SY "lrange <UNITS> <reaction-radius>"
The \*Qlrange\*U command is used to limit the maximum reaction radius of 
land units. This can be useful in restricting the area which a unit will
attempt to defend. (see info attack for details of the reaction process)
.s1
A unit with a radius of 0 will not react.
.s1
.SA "attack, LandUnits"
