#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emp2/client/dtable.c,v 1.1 1994/11/30 22:51:52 empire Exp $";
#endif /* not lint */

/*
 * dtable.c
 *
 * machine-dependent descriptor table management
 */

#ifdef hpux
#include <stdio.h>
#endif

/*ARGSUSED*/
setfdtablesize(min, start)
	int	min;
	int	start;
{
#ifdef sequent
	extern	int errno;

	while (start >= min) {
		if (setdtablesize(start) < 0)
			break;
		start -= 16;
	}
	errno = 0;
#endif
}

int
getfdtablesize()
{
#ifdef hpux
	return _NFILE;
#else
	return getdtablesize();
#endif
}
