#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/client/saveargv.c,v 2.1 1995/10/11 03:07:43 empire Exp $";
#endif /* not lint */

/*
 * saveargv.c
 *
 * routine to copy and clear argv
 *
 */

#include "misc.h"

int
saveargv(ac, src, dst)
	int	ac;
	s_char	**src;
	s_char	**dst;
{
#ifndef SVR4
	extern	s_char *strcpy();
	extern	s_char *malloc();
#endif /* SVR4 */
	register s_char *ptr;
	register int i;

	for (i = 0; i < ac; i++) {
		dst[i] = strcpy(malloc(strlen(src[i])+1), src[i]);
		ptr = src[i];
		while (*ptr)
		    *ptr++ = ' ';
	}
}
