#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/commands/disa.c,v 2.1 1995/07/09 21:12:59 empire Exp $";
#endif /* not lint */

/*
 * disa.c
 *
 * disable updates
 *
 */

#include <fcntl.h>
#include "misc.h"

disa()
{
	extern	s_char *disablefil;
	int	fd;

	if ((fd = open(disablefil, O_RDWR|O_CREAT|O_TRUNC, 0660)) < 0)
		return RET_FAIL;
	close(fd);
	pr("Updates are disabled\n");
	return RET_OK;
}
