#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/gen/iceil.c,v 2.0 1995/07/27 05:56:17 empire Exp $";
#endif

/*
 * iceil.c
 *
 *
 * integer ceiling/floor functions.
 *
 */

int
iceil(arg)
	double arg;
{
	register int i;

	i = arg;
	return(i >= arg ? i : i + 1);
}

int
ifloor(arg)
	double arg;
{
	register int i;

	i = arg;
	return(i <= arg ? i : i - 1);
}
