#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/commands/enab.c,v 2.1 1995/07/09 21:14:09 empire Exp $";
#endif /* not lint */

/*
 * enab.c
 *
 * enable updates
 *
 */

#include <stdio.h>
#include <fcntl.h>
#include "misc.h"

enab()
{
	extern	s_char *disablefil;

	(void) unlink(disablefil);
	pr("Updates are enabled\n");
	return RET_OK;
}
