.TH Command LRADAR
.NA lradar "Use a radar unit's radar"
.LV Expert
.SY "lradar [<UNIT/ARMY> | <SECTS>]"
The radar command bears some resemblance
to modern high-resolution radar.
It has a circular range dependent upon its efficiency.
.s1
An example of radar:
.EX lradar 5
.NF
radar truck #5 efficiency 100%, max range 6
       . a a - ^ ? ?       
      T k o ! - ^ ? ?      
     a h j a ^ ^ ^ ^ ^     
    h . a w a ^ - ? a ?    
   . . a m a b f a ^ ^ -   
  . . m c * a a - ^ - ^ -  
 . - . a + . 0 a - - ^ - . 
  - ^ ^ a + ) ^ a - - ^ .  
   - - a m + a f . . - ^   
    ^ a - a + a ^ - - -    
     - ^ - - ^ - - - -     
      - ^ - - - - - -      
       - - - - - - -       
.FI
.s1
.SA "census, map, nation, Ship-types, Technology, radar, LandUnits, Detection"
