.TH Command VERSION
.NA version "Display parameters of this world"
.LV Expert
.SY "version"
The version command prints out the current settings of parameters
affecting the Empire game.
Included are the creation date for this version,
the size of the world, (X by Y),
etc.
.s1
For example:
.s1
.EX version
.NF
Empire 2 beta 2 rev 5 (KSU distribution 1.04, Chainsaw version 4.00)

The following parameters have been set for this game:
World size is 68 by 76.
There can be up to 52 countries.
By default, countries use their own coordinate system.

An Empire time unit is 1440 seconds long.
Use the 'update' command to find out the time of the next update.
The current time is Thu Aug 10 01:43:09.
An update consists of 60 empire time units.
Each country is allowed to be logged in 1440 minutes a day.
It takes 25.00 civilians to produce a BTU in one time unit.

A non-aggi, 100 fertility sector can grow 0.12 food per etu.
1000 civilians will harvest 1.3 food per etu.
1000 civilians will give birth to 5.0 babies per etu.
1000 uncompensated workers will give birth to 2.5 babies.
In one time unit, 1000 people eat 1.0 units of food.
1000 babies eat 12.0 units of food becoming adults.

Banks pay $200.00 in interest per 1000 gold bars per etu.
1000 civilians generate $4.33, uncompensated workers $1.78 each time unit.
1000 active military cost $83.33, reserves cost $8.33.
Happiness p.e. requires 1 happy stroller per 5000 civ.
Education p.e. requires 1 class of graduates per 4000 civ.
Happiness is averaged over 48 time units.
Education is averaged over 192 time units.
The technology/research boost you get from the world is 50.00%.
Nation levels (tech etc.) decline 1% every 96 time units.
Tech Buildup is limited to logarithmic growth (base 1.50) after 3.00.

				Sectors	Ships	Planes	Units
Maximum mobility		127	127	127	127
Max mob gain per update		60	120	90	90
Max eff gain per update		--	100	100	100

Ships on autonavigation may use 6 cargo holds per ship.

In order to build a nuke, you need 0.33 times the tech level in research
	Example: In order to build a 300 tech nuke, you need 99 research


Options enabled in this game:
        FUEL, TRADESHIPS, NEWPOWER, NOMOBCOST, SUPER_BARS, 
        EASY_BRIDGES, ALL_BLEED, DRNUKE, NO_PLAGUE, NEW_STARVE, NEW_WORK, 
        RES_POP, GRAB_THINGS, SHOWPLANE, ORBIT, PINPOINTMISSILE, SAIL, 
        NUKEFAILDETONATE, SHIPNAMES, UPDATESCHED, DEMANDUPDATE, BIG_CITY

The person to annoy if something goes wrong is:
	Ken Stevens
	(children@empire.net).
You can get your own copy of the source using:
ftp://ftp.empire.net/pub/empire/deity/server or
http://www.empire.net/~children/
.FI
.s1
.SA "Innards, Rules, Playing"
