.TH Command ARM
.NA arm "Load nuclear weapons onto planes or missiles"
.LV Expert
.SY "arm <PLANE> <NUKETYPE> <airburst?>"
The \*Qarm\*U command loads nuclear devices
aboard delivery systems such as planes or missiles.
.s1
No nuclear weapons can be delivered unless they are first loaded
aboard delivery vehicles.
However, until they are residing in a plane or missile, they
are considered invulnerable to attack (buried inside of mountains),
and cannot be used by any potential conqueror (they don't know the
fail-safe codes).
.s1
You decide whether the warhead will airburst or groundburst at the
time you arm it.  If you'd like to change airburst/groundburst later
on, just arm the plane/missile again (in this case, the second
argument will be ignored).  You can see whether a nuke will air or
ground burst using the "plane" command.
.s1
.SA "disarm, plane, build, transport, launch, Damage, Planes"
