#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/commands/echo.c,v 2.0 1995/10/22 21:18:30 empire Exp $";
#endif /* not lint */

/*
 * echo.c
 *
 *
 * Ken Stevens, 1995
 */

#include "misc.h"
#include "player.h"

int
echo()
{
      pr("%s\n", player->argp[1]?player->argp[1]:(s_char *)"");

	return RET_OK;
}
