.TH Command SELL
.NA sell "Sell commodities on the world market"
.LV Expert
.SY "sell <COMMODITY> <SECTS> <AMOUNT> <PRICE>"
The sell command allows nations to sell commodities on the open market.
Not all commodities can be traded --
notably civilians and military.
Prices depend on the \*Qprice multiplier\*U set
by the selling nation with respect to the buying nation,
and the price set at the time of sale.
.s1
The <COMMODITY> is the type of commodity you are selling,
<SECTS> represents the range of sectors which will be selling items.
If negative,
the amount reflects the amount of food to be taken from each sector.
If positive,
the amount shows the \*Qlower limit\*U of food required to be
present in that sector and will only sell food in excess of that limit.
Price is the base price of the commodity to the world, modified by the
individual nation multipliers.
.s1
Typical output looks like:
.EX sell food #1 ?food>400 -100 2.5
.NF
sold 200 food in -7,-3 (100)
sold 501 food in -8,-2 (100)
sold 201 food in -4,-2 (100)
sold 662 food in -7,-1 (100)
sold 812 food in -3,-1 (100)
sold 411 food in -10,0 (100)
sold 571 food in -4,0 (100)
sold 721 food in -2,0 (100)
sold 126 food in -9,1 (100)
sold 172 food in -7,1 (100)
sold 842 food in 1,1 (100)
Total food put on the market : 5219
cost of the items :     5.00
That just cost you $521.90
.FI
.s1
Any sector can sell commodities.
There is a certain overhead on selling items, based on the difficulty
of moving the items in question.
.s1
.SA "buy, mult, Obsolete"
