.TH Command LTEND
.NA ltend "Transfer things between a unit and the ship carrying it"
.LV Expert
.SY "ltend <COMMODITY> <SHIP> <AMT> <to-UNIT/ARMY>"
The ltend command allows transfer of commodities
from a particular (supply) ship to a land unit it is carrying.
.s1
.SA "load, unload, lload, lunload, tend, Ships, LandUnits"
