.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject NATION
.in \w'TechnologyXX\0\0\0\0'u
.s1
.L "break * "
Break sanctuary and begin to play
.L "budget * "
Look at a national balance sheet & set priorities
.L "capital * "
Change the location of your capital
.L "change   "
Change country name or representative's name
.L "dissolve   "
Dissolve your government and country (suicide)
.L "nation * "
The state of your nation
.L "players   "
List players currently connected to the game
.L "power * "
Display arbitrarily measured strengths of all countries
.L "report * "
List all countries and their status
.s1
.L "Education   "
How Education is calculated at the update
.L "Happiness   "
How happiness is calculated at the update
.L "Research   "
How Research level is calculated each update
.L "Taxes   "
How taxes are calculated
.L "Technology   "
How technology level is calculated each update
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
