.TH Command ACCEPT
.NA accept "Find out who's accepting what communications from whom"
.LV Expert
.SY "accept [country]"
The accept command allows you to find out the communications status of
a country. With no argument, accept prints your status. With an argument,
it prints the acceptance status of the specified country.
.s1
.EX "accept 7"
.nf
Temekula Acceptance Status Report       Sun Feb 21 20:53:51 1993

Acceptance status            his                theirs
                     tel trty anno loan   tel trty anno loan
1) Gobu              YES  YES  YES  YES   YES  YES  YES  YES
2) Spectre           YES  YES  YES  YES   YES  YES  YES  YES
3) Rohan             YES  YES  YES  YES   YES  YES  YES  YES
4) Sioux             YES  YES  YES  YES   YES  YES  YES  YES
5) Tom_Servo         YES  YES  YES  YES   YES  YES  YES  YES
6) Horgoth           YES  YES  YES  YES   YES  YES  YES  YES
.fi
.s1
.SA "telegram, announce, read, wire, reject, Diplomacy, Communication"
