#ifndef lint
static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/gen/getstarg.c,v 2.0 1995/07/27 05:56:17 empire Exp $";
#endif

/*
 * getstarg.c
 *
 * get string arg
 *
 * from PSL Empire, 1985
 */

#include "misc.h"

s_char *
getstarg(input, prompt, buf)
	s_char *input;
	s_char *prompt;
	s_char	buf[1024];
{
	extern	s_char *getstring();

	*buf = '\0';
	if (input == 0 || *input == 0) {
		if (getstring(prompt, buf) == 0)
			return 0;
	} else {
		strcpy(buf, input);
	}
	return buf;
}
