.TH Command QUIT
.NA quit "Log out of Empire"
.LV Basic
.SY "quit"
You use the \*Qquit\*U command to close your connection to the Empire
Server.  In some clients, pressing control-D will do the same thing.

.SA "Playing"
