.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject DEITY
.in \w'setresourceXX\0\0\0\0'u
.s1
.L "add   "
Add/Remove a country in the game
.L "disable   "
Disable Updates
.L "edit   "
Change stats of country, ship, land unit, or plane
.L "enable   "
Enable updates
.L "force   "
Force an update
.L "give   "
Give(take) Commodities
.L "hidden   "
Display some deity-only statistics for sectors
.L "newcap   "
Place a pair of sanctuaries
.L "offset   "
Temporarily change coordinate system
.L "players   "
List players currently connected to the game
.L "setresource   "
Change resources of a sector
.L "setsector   "
Change stats of a sector
.L "shutdown   "
Shut down the server
.L "swapsector   "
Swap two sectors
.L "turn   "
Allow/disallow logins. Change login message.
.s1
.L "God   "
Tips on being God
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
