.TH Introduction "Welcome to Empire 2.0"
.NA Welcome "Things you should know from the start"
.s1
If this is your first time playing empire you should
read as many of the info files as possible.
.s1
Also if you are new to empire I hope you are ready to
commit many of hours of hard work.  In order to stay on
or even get close to the top of the power chart you will
need lots of time and luck to get there.
.s1
Other info files that you should read first before
starting the game are:
.s1
Newplayers, Kill, Rules
.s1
Failure to read any of these files could result in bad things
happening to your country.  Please take a couple of minutes
and read them.  It won't hurt your eyes.
.s1
Empire is a strange game.  A lot of things can happen.
I think its safe to say that Murphy's Law is the only law in the game.
From time to time events happen in the game that can cause a problem.
Sometimes its a bug.  If you suspect that you have discovered
a bug please inform the Deity as soon as possible.
.s1
I hope you all enjoy the game and Good Luck to everyone cause
your going to need it.
.s1

.SA "Introduction"
