.TH Command MAIL
.NA mail "interface for reading telegrams"
.SY "mail"
When you type \*Qmail\*U, you will enter an interface for reading your
telegrams which is much like the unix "mail" program.  If you type
\*Q?\*U at the mail prompt, you will be given the following help:
.NF
Commands are:
h                     print the list of headers
<n>                   print message number <n>
d <message list>      delete message list
q                     quit and save changes
x                     quit without saving changes\n
For delete, if no <message list> is specified, then the
current message is used.");
Other choices for <message list> are:\n
  <n>                 message number <n>
  <n>-<m>             messages <n> through <m>
  <n1> <n2> ... <nm>  messages <n1>, <n2>, ..., and <nm>
  p                   all Production Reports
  b                   all BULLETINS
  *                   all messages
.NI
.SA "telegram, read, wmail, Communication"
