.TH Command BYE
.NA bye "Log out of Empire"
.LV Basic
.SY "bye"
The bye command is how you go \*Qbye-bye\*Q to log out of the game.
.s1
This command costs zero BTU's.  You can use it often.
.s1
If, for some obscure reason,
you would like to end an Empire session
but prefer not to use the \*Qbye\*Q command
you may achieve the same result by typing the
EOT character, (control-D).
.s1
.SA "Playing"
