
/* module: workspace */


/* module: /lib/libc.sa.1.8 */


/* module: /home/chainsaw4/ts/E/tm/delaywrite.c */

int dw_queue(int, int);
int dw_flush(void);

/* module: /home/chainsaw4/ts/E/tm/initfiles.c */

int initfiles(void);

/* module: /home/chainsaw4/ts/E/tm/lock.c */

int initlock(void);
int lock(struct user *, int);
int unlock(struct user *, int);
int breaklock(int);
int listlock(int);
int unlock_clean(struct user *);

/* module: /home/chainsaw4/ts/E/tm/main.c */

int alarmhandler(void);
int child(void);
int cleanup(int);
int readhours(int);
int main(void);
int catch(int);

/* module: /home/chainsaw4/ts/E/tm/nat.c */

int natmod(char **, int *);

/* module: /home/chainsaw4/ts/E/tm/news.c */

int addfree(int);
int findfree(void);
int nextfree(void);
int makefree(int);
struct newscache *ncache(int, int, int, int, int);
int nreport(int, int, int, int);

/* module: /home/chainsaw4/ts/E/tm/schedule.c */

int schedule_update(void);
int execute(void);
int exec_done(void);
int doupdate(int, int);

/* module: /home/chainsaw4/ts/E/tm/send.c */

int sendnum(struct iop *, int, int);
int sendstr(struct iop *, char *);
int bcast(char *);
int mcast(char *, int);

/* module: /home/chainsaw4/ts/E/tm/sendclient.c */

void sendclient(struct iop *, int, char *);
int recvclient(struct iop *, char *, char *);

/* module: /home/chainsaw4/ts/E/tm/service.c */

int service(struct iop *, int, char *);

/* module: /home/chainsaw4/ts/E/tm/user.c */

int user_init(void);
int user_add(struct iop *, int, char *);
int user_remove(struct user *);

/* module: /home/chainsaw4/ts/E/tm/wu.c */

int wu(unsigned char, unsigned char, char *);
int flushwu(void);
int wwu(struct _iobuf *, struct msg *);
