.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject OBSOLETE
.in \w'financialXX\0\0\0\0'u
.s1
.L "buy   "
Purchase commodities from the world market
.L "collect   "
Foreclose an overdue loan
.L "consider   "
Accept, decline or postpone consideration of a loan or treaty
.L "financial   "
Show all the outstanding loans in the world
.L "ledger   "
Report on outstanding loans
.L "market   "
Report current selling prices in the world market
.L "mult   "
Set price multipliers of goods
.L "offer   "
Offer a loan or treaty to another country
.L "repay   "
Repay a loan (all or part)
.L "sell   "
Sell commodities on the world market
.L "set   "
Establish price for a ship
.L "trade   "
Generate a report on ships for sale and perhaps buy some
.L "treaty   "
Listing of all current and pending treaties
.L "wait   "
Wait for a telegram
.s1
.L "Innards   "
Some details about the inner workings of the server
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
