.TH Command CONSIDER
.NA consider "Accept, decline or postpone consideration of a loan or treaty"
.LV Expert
.SY "consider loan <loan #> accept|decline|postpone"
.SY "consider treaty <treaty #> accept|decline|postpone"
This command allows you to consider accepting a loan or treaty
offered by another country.
.s1
The program will list the various terms of the loan or treaty
under consideration and ask for your decision
as to whether to accept the terms, decline them,
or postpone making a decision.
.s1
If you accept a loan,
the money is immediately credited to your account
and the time period of the loan starts.
If at the time of your acceptance,
the lender does not have sufficient funds the size of the loan
will be diminished to fit the lender's cash on hand.
.s1
If you accept a treaty,
it goes into effect immediately but the time period of the treaty
is calculated based on the offer date
rather than the acceptance date.
.s1
Loan offers are withdrawn if not accepted within a number
of days equal to the proposed loan's duration.
.s1
Treaty offers expire at the time the proposed treaty would expire.
.s1
Warning: When the terms of a loan are printed out,
take note of the due date;
if you do not pay by the due date the interest will double
and you will be subject to \*Qcollection\*U,
(see \*Qinfo collect\*U).
.s1
.SA "collect, ledger, offer, treaty, Obsolete"
