static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/global/options.c,v 2.4 1995/09/13 05:30:30 empire Exp $";

/*
 * options.c
 *
 */

#include <stdio.h>
#include "misc.h"
#include "options.h"
#include "optlist.h"

/* there must be an easier way - but can't think of one off hand */

#ifdef NOFOOD
int opt_NOFOOD = 1;
#else
int opt_NOFOOD = 0;
#endif

#ifdef SNEAK_ATTACK
int opt_SNEAK_ATTACK = 1;
#else
int opt_SNEAK_ATTACK = 0;
#endif

#ifdef BLITZ
int opt_BLITZ = 1;
#else
int opt_BLITZ = 0;
#endif

#ifdef HIDDEN
int opt_HIDDEN = 1;
#else
int opt_HIDDEN = 0;
#endif

#ifdef LOSE_CONTACT
int opt_LOSE_CONTACT = 1;
#else
int opt_LOSE_CONTACT = 0;
#endif

#ifdef NONUKES
int opt_NONUKES = 1;
#else
int opt_NONUKES = 0;
#endif

#ifdef FUEL
int opt_FUEL = 1;
#else
int opt_FUEL = 0;
#endif

#ifdef TRADESHIPS
int opt_TRADESHIPS = 1;
#else
int opt_TRADESHIPS = 0;
#endif

#ifdef NEWPOWER
int opt_NEWPOWER = 1;
#else
int opt_NEWPOWER = 0;
#endif

#ifdef NOMOBCOST
int opt_NOMOBCOST = 1;
#else
int opt_NOMOBCOST = 0;
#endif

#ifdef SUPER_BARS
int opt_SUPER_BARS = 1;
#else
int opt_SUPER_BARS = 0;
#endif

#ifdef EASY_BRIDGES
int opt_EASY_BRIDGES = 1;
#else
int opt_EASY_BRIDGES = 0;
#endif

#ifdef ALL_BLEED
int opt_ALL_BLEED = 1;
#else
int opt_ALL_BLEED = 0;
#endif

#ifdef DRNUKE
int opt_DRNUKE = 1;
#else
int opt_DRNUKE = 0;
#endif

#ifdef SLOW_WAR
int opt_SLOW_WAR = 1;
#else
int opt_SLOW_WAR = 0;
#endif

#ifdef NO_PLAGUE
int opt_NO_PLAGUE = 1;
#else
int opt_NO_PLAGUE = 0;
#endif

#ifdef NEW_STARVE
int opt_NEW_STARVE = 1;
#else
int opt_NEW_STARVE = 0;
#endif

#ifdef NEW_WORK
int opt_NEW_WORK = 1;
#else
int opt_NEW_WORK = 0;
#endif

#ifdef RES_POP
int opt_RES_POP = 1;
#else
int opt_RES_POP = 0;
#endif

#ifdef GRAB_THINGS
int opt_GRAB_THINGS = 1;
#else
int opt_GRAB_THINGS = 0;
#endif

#ifdef SHOWPLANE
int opt_SHOWPLANE = 1;
#else
int opt_SHOWPLANE = 0;
#endif

#ifdef ORBIT
int opt_ORBIT = 1;
#else
int opt_ORBIT = 0;
#endif

#ifdef PINPOINTMISSILE
int opt_PINPOINTMISSILE = 1;
#else
int opt_PINPOINTMISSILE = 0;
#endif

#ifdef FALLOUT
int opt_FALLOUT = 1;
#else
int opt_FALLOUT = 0;
#endif

#ifdef SAIL
int opt_SAIL = 1;		/* not used currently */
#else
int opt_SAIL = 0;		/* not used currently */
#endif

#ifdef NUKEFAILDETONATE
int opt_NUKEFAILDETONATE = 1;
#else
int opt_NUKEFAILDETONATE = 0;
#endif

#ifdef SHIPNAMES
int opt_SHIPNAMES = 1;	/* not used currently */
#else
int opt_SHIPNAMES = 0;	/* not used currently */
#endif

#ifdef NEUTRON
int opt_NEUTRON = 1;
#else
int opt_NEUTRON = 0;
#endif

#ifdef UPDATESCHED
int opt_UPDATESCHED = 1;
#else
int opt_UPDATESCHED = 0;
#endif

#ifdef DEMANDUPDATE
int opt_DEMANDUPDATE = 1;
#else
int opt_DEMANDUPDATE = 0;
#endif

#ifdef BIG_CITY
int opt_BIG_CITY = 1;
#else
int opt_BIG_CITY = 0;
#endif

#ifdef INTERDICT_ATT
int opt_INTERDICT_ATT = 1;
#else
int opt_INTERDICT_ATT = 0;
#endif

struct option_list Options[] = {
{ "NOFOOD",		&opt_NOFOOD },
{ "SNEAK_ATTACK", 	&opt_SNEAK_ATTACK },
{ "BLITZ", 		&opt_BLITZ },
{ "HIDDEN",		&opt_HIDDEN },
{ "LOSE_CONTACT", 	&opt_LOSE_CONTACT },
{ "NONUKES", 		&opt_NONUKES },
{ "FUEL", 		&opt_FUEL },
{ "TRADESHIPS", 	&opt_TRADESHIPS },
{ "NEWPOWER", 		&opt_NEWPOWER },
{ "NOMOBCOST", 		&opt_NOMOBCOST },
{ "SUPER_BARS", 	&opt_SUPER_BARS },
{ "EASY_BRIDGES", 	&opt_EASY_BRIDGES },
{ "ALL_BLEED", 		&opt_ALL_BLEED },
{ "DRNUKE", 		&opt_DRNUKE },
{ "SLOW_WAR", 		&opt_SLOW_WAR },
{ "NO_PLAGUE", 		&opt_NO_PLAGUE },
{ "NEW_STARVE", 	&opt_NEW_STARVE },
{ "NEW_WORK", 		&opt_NEW_WORK },
{ "RES_POP", 		&opt_RES_POP },
{ "GRAB_THINGS", 	&opt_GRAB_THINGS },
{ "SHOWPLANE", 		&opt_SHOWPLANE },
{ "ORBIT", 		&opt_ORBIT },
{ "PINPOINTMISSILE", 	&opt_PINPOINTMISSILE },
{ "FALLOUT", 		&opt_FALLOUT },
{ "SAIL", 		&opt_SAIL },
{ "NUKEFAILDETONATE", 	&opt_NUKEFAILDETONATE },
{ "SHIPNAMES", 		&opt_SHIPNAMES },
{ "NEUTRON", 		&opt_NEUTRON },
{ "UPDATESCHED", 	&opt_UPDATESCHED },
{ "DEMANDUPDATE", 	&opt_DEMANDUPDATE },
{ "BIG_CITY",           &opt_BIG_CITY },
{ "INTERDICT_ATT",      &opt_INTERDICT_ATT },
{ NULL,			NULL },
};
