.TH Concept "Maintenance"
.NA Maintenance "The cost to maintain ships, planes, and land units."
.LV Expert
During each update, nations must pay to maintain their units, ships and planes.
.s1
The cost to maintain a ship, plane, or land-unit is:
.NF +8
	.001 * cost of thing * ETUs/update
.FI
.s1
Note that this cost can be changed by the deity.
.s1
If you can not afford to pay maintenance costs or you choose not to
pay them (see info budget) then your unit will lose ETU/5 points of
efficiency.  Thus, if you were playing in a 60 ETU game, and you did
not pay your maintenance costs for a 50% frigate, then the frigate
would drop to 38% efficiency.
.s1
.SA "Unit-types, Ship-types, Plane-types, Ships, LandUnits, Planes, Update"
