.TH Command DEMOBILIZE
.NA demobilize "Change military into civilians"
.LV Basic
.SY "demobilize <SECTS> <NUMBER>"
The demob command returns soldiers from the military
back to civilian life.
In addition,
you have the option of placing the returning GI's
into the nation's active reserve.
The active reserve provides a pool of available military
for a small salary (usually the same amount generated by a civilian)
and provides for quick mobilization of military
during a threat to national security.
.s1
As a result of demobilization,
and as a \*Qthank you\*U for serving their country in its time of need,
a \*QGI Bill\*U is given to each soldier to the tune of $5 each.
.s1
Troops can only be demobilized in sectors which have greater than
60% efficiency, and only in \*Qhome sectors\*U
(that is, not in occupied territory).
.s1
When troops are successfully demobilized in a given sector,
the number of new civilians is printed,
and the number in parentheses shows the total
number of military left in that sector.
.s1
You have the option of placing civilians on active reserve.
Civilians on active reserve can later be enlisted
but you must pay them to stay on.
Generally civilian on active reserve costs one tenth of what
a military costs.
.s1
.EX demob -2:0,0 1
.NF
New civilians on active reserve? (y/n) y
1 demobilized in -2,0 (19 mil left)
1 demobilized in 0,0 (9 mil left)
Total new civilians : 2
Military reserve stands at 2 (up 2)
.FI
.s1
.EX demob -2:0,0 1 y
.NF
1 demobilized in -2,0 (18 mil left)
1 demobilized in 0,0 (8 mil left)
Total new civilians : 2
Military reserve stands at 4 (up 2)
.FI
.s1
.SA "enlist, Populace"
