.TH Command LAND
.NA land "Report status of unit, army or units in a given area"
.LV Basic
.SY "land [<UNIT/ARMY> | <SECTS>]"
The unit report command is a census of your units and lists all the
info available in readable format.
.s1
The <UNIT/ARMY> and <SECTS> arguments are provided in case you only
wish to look at one unit or one army or all units within a given area.
.s1
Land expects an argument.  To see every unit you own, give it
the argument '*', i.e. type "land *".
.s1
The report format contains the following fields:
.s1
.in \w'unit-type\0\0'u
.L #
the unit number
.L unit type
the type of unit; \*Qwar band\*U, \*Qengineer\*U, etc,
.L x,y
the unit's current location (relative to your capital),
.L a
the army designation letter (set by \*Qarmy\*U command),
.L eff
the unit's efficiency,
.L fort
the unit's fortification level (0-127)
.L mu
the mobility of the unit
.L food
the amount of food on board
.L fuel
the amount of fuel on board (if the FUEL option is enabled)
.L tech
the tech level of the unit
.L retr
the retreat percentage of the unit (see info attack)
.L rad
the unit's reaction radius (see info attack)
.L xl
the number of extra-light planes on board (if the XLIGHT option is enabled)
.L ship
the ship the unit is on, if any
.in
.s1
For example:
.EX land *
.NF
  # unit type        x,y   a  eff fort  mu food fuel tech retr rad xl ship
  0 artillery 1      2,0   n 100%    0 127    0    0  962  75%   0  0
  1 GPG Commandos   -2,0      10%    0   0    5   10  940  75%   1  0
  2 War band         1,-1    100%    0  93    5    0  940  75%   1  0
3 units
.FI
.s1
.SA "build, cargo, army, march, attack, assault, lload, llookout, scrap, lmine, LandUnits"
