.TH Command DISSOLVE
.NA dissolve "Dissolve your government and country (suicide)"
.LV Expert
.SY "dissolve"
The dissolve command is the coward's way out of Empire.
It does several things:
it gives all your sectors back to The Deity,
pays off any debts that it can,
voids any treaties in which you were involved,
and allows your ships to decide their own fate.
Some ships riot, some go up for sale, and some are scuttled.
.s1
Using the dissolve command is simplicity itself:
.EX dissolve
You will be given one last chance to change your mind:
.NF
Are you SURE you want to do this?
.FI
And then it's curtains...
.s1
.SA "pray, Nation"
