static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/global/numnames.c,v 2.0 1995/07/27 05:34:36 empire Exp $";

/*
 * numnames.c
 *
 * used in converting numbers to strings
 *
 */

#include "misc.h"

s_char    *numnames[]  = {
	"zero", "one", "two", "three", "four", "five", "six",
	"seven", "eight", "nine", "ten", "eleven", "twelve",
	"thirteen", "fourteen", "fifteen", "sixteen",
	"seventeen", "eighteen", "nineteen",
};

s_char    *tennames[]  = {
	"", "", "twenty", "thirty", "forty", "fifty",
	"sixty", "seventy", "eighty", "ninety",
	"hundred", "hundred ten", "hundred twenty",
	"hundred thirty", 0,
};
