.TH Command GRIND
.NA grind "Grind bars back into dust"
.LV Expert
.SY "grind <SECTOR> <NUMBER>"
The \*Qgrind\*U command converts gold bars back into dust.
This costs 1 BTU plus 5 \*Qavailable work units\*U per bar and can be
done in any sector which is at least 60% efficient.
Due to inefficiencies in the conversion process, only 80% of
the dust can be recovered.
.SA "Commodities"
