/*
 * queue.h
 *
 * generic vax-like doubly-linked list queues.
 *
 */

#ifndef _QUEUE_H_
#define _QUEUE_H_

#define	QEMPTY(p)	((p)->q_forw == (p))

struct qelem {
	struct qelem *q_forw;
	struct qelem *q_back;
};

#endif /* _QUEUE_H_ */
