/*
 * io.h
 *
 * describes io pointers
 *
 */

#ifndef _IO_H_
#define _IO_H_

typedef struct iop *iop_t;

#define	IO_READ		0x1
#define IO_WRITE	0x2
#define IO_NEWSOCK	0x4
#define IO_NBLOCK	0x8
#define	IO_EOF		0x10
#define IO_CONN		0x20
#define IO_ERROR	0x40

#define IO_BUFSIZE	4096

#define IO_NOWAIT	0
#define IO_WAIT		1

iop_t	io_open();

#endif /* _IO_H_ */
