.TH Concept Time
.NA Time "Definitions of BTU and ETL"
.LV Expert
.s1
Because of the unique nature of Empire governments,
(i.e. the decision makers spend most of their time on vacation.
Hmmm, not so unique actually),
and the fact that ideally the Empire \*Qenvironment\*U
will mirror the \*Qreal\*U world,
various heuristics dealing with time have been implemented.
.s1
The first is the Bureaucratic Time Unit (BTU) concept
which keeps track of the potential for doing \*Qwork\*U
possessed by your government.
.s1
The second heuristic, (i.e. hack),
is the Elapsed Time Limit (ETL) which limits the amount of time
that players may be logged on each day.
The ETL is not cumulative and is reset to some particular value,
(often two hours, check the \*Qversion\*U command to be sure),
every night at midnight.
.s1
The ETL and BTU counts are displayed with each command prompt
as follows:
.EX
The first \*Q##\*U is the Elapsed Time today, in minutes.
This number starts at 0 every midnight.
The second \*Q##\*U is the number of BTU's remaining.
.s1
.SA "Innards, version, BTU, Playing"
