.TH Command UPDATE
.NA update "Find out when the next update will be"
.LV Basic
.SY "update"
The update command shows you when the next update will occur, and
describes the current update policies.
.sp
.SA "zdone, Update"
