.TH Command NAME
.NA name "Give a name to a ship"
.LV Expert
.SY "name <SHIPS> <NAME>"
The \*Qname\*U command allows individual ships to be give
names. A name of \*Q~\*U is used to remove the name.
.SA "Ships"
