.TH Command SCUTTLE
.NA scuttle "Destroy a ship, plane, or unit"
.LV Basic
.SY "scuttle <s|l|p> <SHIPS | UNITS | PLANES>"
This command allows you to destroy planes/units/ships when you no longer
need them.
.s1
Planes, units, and ships may be scuttled in any sector.
.s1
If you scuttle a ship or unit that has planes on board, the planes will either
be transferred to land (if a unit, or if the ship is in a harbor), or will die
(if the ship is elsewhere)
.s1
Units on ships may not be scuttled.
.s1
Scuttling trade-ships (if the TRADESHIPS option is enabled) has other effects.
See info Trade-ships.
.s1
.SA "scrap, Trade-ships, build, ship, plane, land, Ships, Planes, LandUnits"
