.\" DO NOT EDIT THIS FILE.  It was automatically generated by info.pl
.TH Subject SECTORS
.in \w'SectorMownershipXX\0\0\0\0'u
.s1
.L "build * "
Build ships, planes, bridges, land units or nuclear weapons
.L "cede   "
Give a ship or sector to a friend
.L "census * "
Report contents of sectors
.L "commodity * "
Report commodities in sectors
.L "designate * "
Specify sector utilization
.L "dump   "
Dump raw sector information
.L "explore * "
Claim unowned land
.L "neweff   "
Find out what the efficiency of a sector will be after the next update
.L "radar * "
Perform radar scan from ship or sector
.L "resource * "
Show the resources of sectors
.L "spy * "
Snoop on adjacent enemy sectors
.L "territory   "
Assign various sectors to a specific territory
.s1
.L "Bridges   "
Building and destroying bridges
.L "Mobility   "
How much mobility stuff costs
.L "Quick-ref * "
A quick reference card for sector types and production
.L "Sector-ownership * "
Sector ownership
.L "Sector-types * "
Description of different sector types
.s1
.in 0
For info on a particular subject, type "info <subject>" where <subject> is
one of the subjects listed above.  Subjects marked by * are the most
important and should be read by new players.
