.TH Command WIRE
.NA wire "Read announcements"
.LV Basic
.SY "wire [yes|no|<days>]"
The wire command is used to read the announcements sent you by other countries.
After reading all your announcements you may discard them by answering
\*Qyes\*U to the question posed.  If you answer \*Qno\*U the announcements
will remain pending but you will not be reminded of them.
.s1
You can read announcements that you have previously discarded by
specifying the <days> argument.  For example:
.EX "wire 3"
would print the announcements from the last three days.
.s1
In order to read telegrams, use the 'read' command.
.s1
.SA "telegram, read, Communication"
